-- ATE Tool database upgrade script 
-- From version: 1.0.2
-- To version: 1.0.3
-- Target DB engine: MySQL 5.1.x

SET SQL_MODE="NO_AUTO_VALUE_ON_ZERO";
SET time_zone = "+00:00";


/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;

-- --------------------------------------------------------

--
-- Table structure for table `ExchangeRate`
--
-- Defines currency exchange rates for every month in a year
-- Month should be integer in range <1,12>
-- Value is the ratio of SourceCurrency to TargetCurrency

CREATE TABLE IF NOT EXISTS `ExchangeRate` (
  `SourceCurrency` char(3) COLLATE utf8_unicode_ci NOT NULL,
  `TargetCurrency` char(3) COLLATE utf8_unicode_ci NOT NULL,
  `Year` int(11) NOT NULL,
  `Month` int(11) NOT NULL,
  `Value` decimal(8,2) NOT NULL,
  PRIMARY KEY (`SourceCurrency`,`TargetCurrency`,`Year`,`Month`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;


INSERT INTO `ExchangeRate` (`SourceCurrency`, `TargetCurrency`, `Year`, `Month`, `Value`) VALUES
('CZK', 'USD', 2011, 1, '19.9'),
('CZK', 'USD', 2011, 2, '19.9'),
('CZK', 'USD', 2011, 3, '19.9'),
('CZK', 'USD', 2011, 4, '19.9'),
('CZK', 'USD', 2011, 5, '19.9'),
('CZK', 'USD', 2011, 6, '19.9'),
('CZK', 'USD', 2011, 7, '19.9'),
('CZK', 'USD', 2011, 8, '19.9'),
('CZK', 'USD', 2011, 9, '19.9'),
('CZK', 'USD', 2011, 10, '19.9'),
('CZK', 'USD', 2011, 11, '19.9'),
('CZK', 'USD', 2011, 12, '19.9'),
('CZK', 'USD', 2012, 1, '19.9'),
('CZK', 'USD', 2012, 2, '19.9'),
('CZK', 'USD', 2012, 3, '19.9'),
('CZK', 'USD', 2012, 4, '19.9'),
('CZK', 'USD', 2012, 5, '19.9'),
('CZK', 'USD', 2012, 6, '19.9'),
('CZK', 'USD', 2012, 7, '19.9'),
('CZK', 'USD', 2012, 8, '19.9'),
('CZK', 'USD', 2012, 9, '19.9'),
('CZK', 'USD', 2012, 10, '19.9'),
('CZK', 'USD', 2012, 11, '19.9'),
('CZK', 'USD', 2012, 12, '19.9'),
('CZK', 'USD', 2013, 1, '19.9'),
('CZK', 'USD', 2013, 2, '19.9'),
('CZK', 'USD', 2013, 3, '19.9'),
('CZK', 'USD', 2013, 4, '19.9'),
('CZK', 'USD', 2013, 5, '19.9'),
('CZK', 'USD', 2013, 6, '19.9'),
('CZK', 'USD', 2013, 7, '19.9'),
('CZK', 'USD', 2013, 8, '19.9'),
('CZK', 'USD', 2013, 9, '19.9'),
('CZK', 'USD', 2013, 10, '19.9'),
('CZK', 'USD', 2013, 11, '19.9'),
('CZK', 'USD', 2013, 12, '19.9');

--
-- Table structure for table `GlobalSetting`
--
-- Defines global setting for whole application

CREATE TABLE IF NOT EXISTS `GlobalSetting` (
  `Key` varchar(200) COLLATE utf8_unicode_ci NOT NULL,
  `Value` text DEFAULT NULL,
  `Default` text NOT NULL,
  `DataType` ENUM('string', 'float', 'int', 'ufloat', 'uint', 'boolean') NOT NULL,
  PRIMARY KEY (`Key`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;

INSERT INTO `GlobalSetting` (`Key`, `Value`, `Default`, `DataType`) VALUES 
('menu.import.BackupAndRestore.sourcedb', NULL, '', 'string'),
('menu.import.BackupAndRestore.enabled', NULL, '0', 'boolean');

--
-- Triggers
--
-- DecideLabourTask
-- When importing TaskPlan IF SUM(JanHrs, FebHrs, ..., DecHrs) = 0 THEN SET LabourTask = TRUE
--
-- ProjectStateChangeTo1
-- When SETting Project.State = 'Resource Planning' check for people assigned to years that are no longer planned (consistency check)

DROP TRIGGER IF EXISTS `DecideLabourTask`;
DELIMITER $$
CREATE TRIGGER `DecideLabourTask` BEFORE INSERT ON `TaskPlan`
 FOR EACH ROW BEGIN
        IF (NEW.JanHrs + NEW.FebHrs + NEW.MarHrs + NEW.AprHrs + NEW.MayHrs + NEW.JunHrs + NEW.JulHrs + NEW.AugHrs + NEW.SepHrs + NEW.OctHrs + NEW.NovHrs + NEW.DecHrs > 0) THEN
            UPDATE Task SET LabourTask = true WHERE NEW.Task_ID = Task_ID;
        END IF;
    END
$$
DELIMITER ;

DROP TRIGGER IF EXISTS `ProjectStateChangeTo1`;
DELIMITER $$
CREATE TRIGGER `ProjectStateChangeTo1` BEFORE UPDATE ON `Project`
 FOR EACH ROW BEGIN
        DECLARE done INT DEFAULT 0;
        DECLARE PT, TID, Y INT;
        DECLARE cur CURSOR FOR SELECT Person_Task, Task_ID, Year FROM Person_Task;
        DECLARE CONTINUE HANDLER FOR NOT FOUND SET done = 1;
        IF (NEW.State = '1') THEN
            OPEN cur;
            read_loop: LOOP
                FETCH cur INTO PT, TID, Y;
                IF done THEN
                    LEAVE read_loop;
                END IF;
                IF (GetProjectIDFromTaskID(TID) = NEW.Project_ID) THEN
                    IF ((SELECT TaskPlan_ID FROM TaskPlan WHERE Task_ID = TID AND Year = Y) IS NULL) THEN
                        DELETE FROM Person_Task WHERE Task_ID = TID AND Year = Y;
                    END IF;
                END IF;
            END LOOP;
        END IF;
    END
$$
DELIMITER ;

--
-- Project Phase must not be null, default 'Planned'
--

ALTER TABLE `Project` MODIFY `Phase` ENUM('Planned', 'Closed', 'Active') NOT NULL DEFAULT 'Planned';

--
-- Person table - rename Location to CostCenter, add constraint (FK) and NOT NULL
--

UPDATE `Person` SET `Location` = 'EEEPZZA1' WHERE `Location` = 'Brno';
UPDATE `Person` SET `Location` = 'EEEPZZA2' WHERE `Location` = 'Prague';
ALTER TABLE `Person` CHANGE `Location` `CostCenter` VARCHAR(100) NOT NULL, ADD CONSTRAINT `fk_costcenter` FOREIGN KEY (`CostCenter`) REFERENCES `CostCenter` (`CostCenter_ID`);

-- 
-- Temporary table for setting access to some functionality by roles
--
ALTER TABLE `User` DROP INDEX `EID` ,
ADD UNIQUE `EID`( `EID` , `Role` );

--
-- Table structure for table `News`
--
-- Defines news for users of the application

CREATE TABLE IF NOT EXISTS `News` (
	`News_ID` int(11) NOT NULL AUTO_INCREMENT,
	`PublishDate` datetime DEFAULT NULL,
	`Title` varchar(100) COLLATE utf8_unicode_ci NOT NULL,
	`Annotation` varchar(250) COLLATE utf8_unicode_ci NOT NULL,
	`Text` TEXT COLLATE utf8_unicode_ci,
  PRIMARY KEY (`News_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;


---
--- Foreign key to table CostCenter after Person administration is rewritten
--- Default value of CostCenter must not be set
---
ALTER TABLE `Person` CHANGE `CostCenter` `CostCenter` VARCHAR(100) NOT NULL;

ALTER TABLE  `Person` ADD  `Person_ID` INT NOT NULL AUTO_INCREMENT FIRST ,
ADD PRIMARY KEY (  `Person_ID` )
