# FileName: atetool-db-backup.ps1
#=============================================================================
# Script Name: [ATE PLANNING TOOL database backup]
# Created: [26/3/2013]
# Version: [1.1]
# Author: [Martin Kotlar]
# Email: [martin.kotlar@honeywell.com]
# Company: [Honeywell]  
# Arguments: None
# =============================================================================
# Purpose: back-ups ATE Planning Tool database and compress it 
# deletes files older than 14 days. Should be planned in Windows 
# Task Scheduler to run regularly every hour of every working day at least 
# =============================================================================
#$my_backup_dir="C:\inetpub\wwwroot\ate-planning-tool\backup"

$my_mysqldump_cmd="c:\Program Files\MySQL\MySQL Server 5.6\bin\mysqldump.exe"
$my_mysqldump_params=@("-R","-u","tool","-ptool","tool")
# how many days back to keep backups of database
$my_backup_days=14

$my_backup_dir="C:\Backup\ate-planning-tool\db\"

$my_backup_file=$my_backup_dir + "tool-db-backup-" + (Get-Date -UFormat "%Y%m%d_%H%M%S")
$my_backup_archive=$my_backup_file+".zip"
$my_backup_file+=".sql" 
$my_7zip_cmd="c:\Program Files\7-Zip\7z.exe"
$my_7zip_params=@("a","-tzip","-y","$my_backup_archive","$my_backup_file")

$mail_sender="hon.planning.tool@honeywell.com"
$mail_smtp="smtp.honeywell.com"
# list of people who will be notified in case of backup fail
$mail_list="leos.navratil@honeywell.com","jiri.pirochta@honeywell.com","vojtech.sedlak@honeywell.com"

if (-not(Test-Path $my_backup_dir))
{
    Send-MailMessage -From $mail_sender -To $mail_list -SmtpServer $mail_smtp -Subject "Honeywell Planning Tool - Server Backup" -Body "Automatic check of DB backup failed. Folder in $my_backup_dir does not exist."
    exit 1
}

# create a database dump and compress it
& $my_mysqldump_cmd $my_mysqldump_params | Set-Content -Path $my_backup_file
& $my_7zip_cmd $my_7zip_params | out-null
Remove-Item $my_backup_file

# ensure the backup file exists and is larger than 2MB
if (-not((Test-Path $my_backup_archive) -and ((Get-Item $my_backup_archive).length -ge 2MB)))
{
    # alert the administrators
    Send-MailMessage -From $mail_sender -To $mail_list -SmtpServer $mail_smtp -Subject "Honeywell Planning Tool - Server Backup" -Body "Automatic check of DB backup failed. Backup file either doesn't exist or is smaller than expected (2MB)."
    exit 2
}

# delete older ZIP files than defined in $my_backup_days 
$my_last_backup_date = (Get-Date).AddDays(-$my_backup_days)
$my_backups_to_delete = Get-ChildItem $my_backup_dir -include *.zip -recurse | Where {$_.LastWriteTime -le "$my_last_backup_date"}
if ($my_backups_to_delete -ne $null)
{
    foreach ($file in $my_backups_to_delete)
    {
        #Write-Host "Deleting File $file" -foregroundcolor "Red" 
        Remove-Item $file | out-null
    }
}

exit
