<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters
 */

/**
 * Presenter for operations with costcenters.
 *
 * @author Jiri Zajic <jiri.zajic@honeywell.com>
 */
class CostCenterPresenter extends SecuredPresenter
{

    /**
     * List of Cost Centers for defined years.
     */
    public function renderDefault()
    {
		$this->template->form = $this['filterCostCenterForm'];
		$filtered_costCenters = array();
		if ($this->isAjax()) // is ajax request
		{
			$filter = new CostCenterFilter();
			if (isset($this->payload->filter)) // filter is defined
			{
				$entry = $this->payload->filter; // $entry contains content of filterProjectForm

				$filter->ID = $entry->WorkCenterID;
				$filter->Name = $entry->WorkCenterName;
				$filter->Plant = $entry->Plant;
				$filter->Status = $entry->FilterStatus;
			}
			
			$this->context->formStateRepository->save('filterCostCenterForm', $this->template->form); // save filter state
			$filtered_costCenters = $this->context->costCenterRepository->findByFilter($filter);
		}
		else
		{
			if ($this->context->formStateRepository->exists('filterCostCenterForm')) // exists saved filter
				$this->context->formStateRepository->load('filterCostCenterForm', $this->template->form);
		}
		
        $this->template->costcenters = $filtered_costCenters;
    }
    
    /**
     * Shows detail of a labour rate with id $id for year $year.
     * 
     * @param type $id Cost Center ID.
     * @param type $year Year.
     */
    public function renderShowDetailLabourRate($id, $year)
    {
        $costCenter_ID = $id;
        $costCenter = $this->context->costCenterRepository->findCostCenter($costCenter_ID);
        $rates = $this->context->costCenterRepository->findCostCenterLabourRates($costCenter_ID, $year);
		if(is_null($rates))
		{
			$this->flashMessage('Labour rates for Work Center with id: ' . $costCenter_ID . ' and year: ' . $year . ' was not found!', 'error');
			$this->redirect('default');
		}
        $form_defaults = array();
        $form_defaults['CostCenterID'] = $costCenter->ID;
        $form_defaults['Year'] = $rates->getYear();
        $form_defaults['Name'] = $costCenter->getName();
        $form_defaults['Jan'] = $rates->getMonthlyHourRate(1);
        $form_defaults['Feb'] = $rates->getMonthlyHourRate(2);
        $form_defaults['Mar'] = $rates->getMonthlyHourRate(3);
        $form_defaults['Apr'] = $rates->getMonthlyHourRate(4);
        $form_defaults['May'] = $rates->getMonthlyHourRate(5);
        $form_defaults['Jun'] = $rates->getMonthlyHourRate(6);
        $form_defaults['Jul'] = $rates->getMonthlyHourRate(7);
        $form_defaults['Aug'] = $rates->getMonthlyHourRate(8);
        $form_defaults['Oct'] = $rates->getMonthlyHourRate(9);
        $form_defaults['Sep'] = $rates->getMonthlyHourRate(10);
        $form_defaults['Nov'] = $rates->getMonthlyHourRate(11);
        $form_defaults['Dec'] = $rates->getMonthlyHourRate(12);
        $this->template->form = $this['detailLabourRateForm'];
        $this->template->form->setDefaults($form_defaults);
    }
	
    /**
     * Shows detail of a Cost Center with id $id.
     * 
     * @param type $id Cost Center ID.
     */
    public function renderShowDetailCostCenter($id)
    {
        $costCenter_ID = $id;
        $costCenter = $this->context->costCenterRepository->findCostCenter($costCenter_ID);
		if(is_null($costCenter))
		{
			$this->flashMessage('Work Center with id: ' . $costCenter_ID . ' was not found!', 'error');
			$this->redirect('default');
		}
        $form_defaults = array();
		$this->template->form = $this['detailCostCenterForm'];
        $form_defaults['CostCenterID'] = $costCenter->ID;
        $form_defaults['Name'] = $costCenter->getName();
//		$form_defaults['TaskNamePrefix'] = $costCenter->getTaskNamePrefix();
		$form_defaults['Plant'] = $costCenter->Plant;
		
		if($costCenter->Status)
			$form_defaults['Status'] = 'Active';
		else
			$form_defaults['Status'] = 'Inactive';

        $this->template->form->setDefaults($form_defaults);
    }
	
    /**
     * Renders form for work center creation.
     */
	public function renderCreateCostCenter($wcID = null)
	{
		if($wcID != null)
		{
			$defaults = array();
			$defaults['CostCenterID'] = $wcID;
			$this['createCostCenterForm']->setDefaults($defaults);
		}
		$this->template->form = $this['createCostCenterForm'];
	}
	
    /**
     * Renders form for labour rate creation.
     */
	public function renderCreateLabourRate($wcID = null)
	{
		$form = $this['createLabourRateForm'];
		$defaults = array();
        $defaults['Jan'] =  0.0;
        $defaults['Feb'] =  0.0;
        $defaults['Mar'] =  0.0;
        $defaults['Apr'] =  0.0;
        $defaults['May'] =  0.0;
        $defaults['Jun'] =  0.0;
        $defaults['Jul'] =  0.0;
        $defaults['Aug'] =  0.0;
        $defaults['Sep'] =  0.0;
        $defaults['Oct'] =  0.0;
        $defaults['Nov'] =  0.0;
        $defaults['Dec'] =  0.0;
		if($wcID != null)
		{
			$defaults['CostCenterID'] = $wcID;
		}
		$form->setDefaults($defaults);
		$this->template->form = $form;
	}

	/**
     * Creates form for filtering Cost Centers.
     * 
     * @param string $name FilterCostCenterForm.
     * @return AppForm FilterCostCenterForm.
     */
    public function createComponentFilterCostCenterForm($name)
    {
        $form = new AppForm($this, $name);

		$form->addText('WorkCenterName', 'Work Center Name');
		$form->addText('Plant', 'Plant');
		$form->addText('WorkCenterID', 'Work Center ID');
		
		$form->addCheckboxList('FilterStatus', 'Status', array('Active' => 'Active', 'Inactive' => 'Inactive'));
        $form['FilterStatus']->setDefaultValue(array('Active', 'Inactive'));
		$form['FilterStatus']->getSeparatorPrototype()->setName(NULL);
		
        $form->addSubmit('reset', 'Reset Filter')
            ->onClick[] = callback($this, 'filterFormResetClicked');
		
		$form->addSubmit('createCC', 'Create Work Centrum')
            ->onClick[] = callback($this, 'createCCClicked');
		if (!$this->isAllowed(self::RESOURCE_WORK_CENTER, self::ACTION_CREATE))
			$form['createCC']->setDisabled(true);
		
		$form->addSubmit('createLR', 'Add Labour Rate')
			->setValidationScope(FALSE)
            ->onClick[] = callback($this, 'createLRClicked');
		if (!$this->isAllowed(self::RESOURCE_LABOUR_RATE, self::ACTION_CREATE))
			$form['createLR']->setDisabled(true);
		
        $form->getElementPrototype()->class('ajax');

        $form->onSuccess[] = array($this, 'filterCostCentertFormSubmitted');

        return $form;
    }
	
	
    /**
     * FilterCostCenterForm submitted.
     * 
     * @param AppForm $form FilterCostCenterForm submitted.
     */
    public function filterCostCentertFormSubmitted(AppForm $form)
    {
		$this->payload->filter = $form->getValues();
		$this->invalidateControl('costCenters');
    }
	
    /**
     * Creates CostCenterForm for editing Cost Centers.
     * 
     * @param string $name CostCenterForm.
     * @return AppForm CostCenterForm.
     */
    public function createComponentCostCenterForm($name)
    {
        $form = new AppForm($this, $name);
        
        $form->addText('Name', 'Name', 30)
				->setRequired('Please set Work Center name!');

        $form->addText('CostCenterID', 'Work Center ID', 25)
			->setRequired('Please set Work Center ID!');

//        $form->addText('TaskNamePrefix', 'Task Name Prefix')
//            ->setRequired('Please set Task Name Prefix!');
		
        $form->addText('Plant', 'Plant')
            ->setRequired('Please set Plant!')
			->addRule(Form::INTEGER, 'Plant must be number!');
        
		$form->addRadioList('Status', 'Status', array('Active' => 'Active', 'Inactive' => 'Inactive'));
		$form['Status']->getSeparatorPrototype()->setName(NULL);
		
        $form->addSubmit('back', 'Go back')
            ->setValidationScope(FALSE)
            ->onClick[] = callback($this, 'backClicked');
		
        $submit_button = $form->addSubmit('save', 'Save');
		if (!$this->isAllowed(self::RESOURCE_WORK_CENTER, self::ACTION_CREATE))
			$submit_button->setDisabled(true);

        return $form;
    }
	
    /**
     * Creates CreateCostCenterForm for editing Cost Centers.
     * 
     * @param string $name CreateCostCenterForm.
     * @return AppForm CreateCostCenterForm.
     */
    public function createComponentCreateCostCenterForm($name)
    {
        $form = $this->createComponentCostCenterForm($name);
        
		$width = 3;
		
        $form->addText('Jan', 'January', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [January]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [January]', array(0, 999))
			->setRequired('Labour Rate is mandatory!');
        $form->addText('Feb', 'February', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [February]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [February]', array(0, 999))
			->setRequired('Labour Rate is mandatory!');
        $form->addText('Mar', 'March', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [March]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [March]', array(0, 999))
			->setRequired('Labour Rate is mandatory!');
        $form->addText('Apr', 'April', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [April]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [April]', array(0, 999))
			->setRequired('Labour Rate is mandatory!');
        $form->addText('May', 'May', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [May]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [May]', array(0, 999))
			->setRequired('Labour Rate is mandatory!');
        $form->addText('Jun', 'June', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [June]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [June]', array(0, 999))
			->setRequired('Labour Rate is mandatory!');
        $form->addText('Jul', 'July', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [July]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [July]', array(0, 999))
			->setRequired('Labour Rate is mandatory!');
        $form->addText('Aug', 'August', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [August]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [August]', array(0, 999))
			->setRequired('Labour Rate is mandatory!');
        $form->addText('Sep', 'September', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [September]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [September]', array(0, 999))
			->setRequired('Labour Rate is mandatory!');
        $form->addText('Oct', 'October', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [October]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [October]', array(0, 999))
			->setRequired('Labour Rate is mandatory!');
        $form->addText('Nov', 'November', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [November]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [November]', array(0, 999))
			->setRequired('Labour Rate is mandatory!');
        $form->addText('Dec', 'December', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [December]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [December]', array(0, 999))
			->setRequired('Labour Rate is mandatory!');
		
        $form->onSuccess[] = array($this, 'createCostCenterFormSubmitted');

        return $form;
    }
	
    /**
     * CreateCostCenterForm submitted.
     * 
     * @param AppForm $form CreateCostCenterForm submitted.
     */
    public function createCostCenterFormSubmitted(AppForm $form)
    {
        $entry = $form->getValues();
		if ($this->isAllowed(self::RESOURCE_WORK_CENTER, self::ACTION_CREATE))
		{
			if ($form->isValid())
			{
				if($this->context->costCenterRepository->findCostCenter($entry['CostCenterID']))
				{
					$this->flashMessage("Work Center with ID: " . $entry['CostCenterID'] . " already exists.", 'error');
					$this->redirect('CostCenter:createCostCenter');
				}
//				if($this->context->costCenterRepository->findCostCenterByTaskNamePrefix($entry['TaskNamePrefix']))
//				{
//					$this->flashMessage("Work Center with Task Name Prefix: " . $entry['TaskNamePrefix'] . " already exists.", 'error');
//					$this->redirect('CostCenter:createCostCenter');
//				}
				$costCenter = new CostCenter();
				$costCenter->ID = $entry['CostCenterID'];
				$costCenter->Name = $entry['Name'];
//				$costCenter->TaskNamePrefix = $entry['TaskNamePrefix'];
				$costCenter->Plant = $entry['Plant'];
				if ($this->context->costCenterRepository->save($costCenter))
				{
					$this->flashMessage("Work Center " . $costCenter->Name . " saved successfully.", 'success');
				}
				else
				{
					$this->flashMessage("Work Center " . $costCenter->Name . " saved unsuccessfully.", 'error');
					$this->redirect('CostCenter:createCostCenter');
				}
			}
			else
			{
				$this->flashMessage("Invalid form values.");
			}
		}
		else
		{
			$this->flashMessage("You are not authorized to save work center. ADMIN role required.", 'error');
		}
		// Labour rate for current year
		if ($this->isAllowed(self::RESOURCE_LABOUR_RATE, self::ACTION_CREATE))
		{
			if ($form->isValid())
			{
				$year = Date('Y');
				$costCenterLabourRates = new CostCenterLabourRates();
				$costCenterLabourRates->setID($costCenter->ID);
				$costCenterLabourRates->setYear($year);
				$costCenterLabourRates->setMonthlyHourRate( 1, $entry['Jan']);
				$costCenterLabourRates->setMonthlyHourRate( 2, $entry['Feb']);
				$costCenterLabourRates->setMonthlyHourRate( 3, $entry['Mar']);
				$costCenterLabourRates->setMonthlyHourRate( 4, $entry['Apr']);
				$costCenterLabourRates->setMonthlyHourRate( 5, $entry['May']);
				$costCenterLabourRates->setMonthlyHourRate( 6, $entry['Jun']);
				$costCenterLabourRates->setMonthlyHourRate( 7, $entry['Jul']);
				$costCenterLabourRates->setMonthlyHourRate( 8, $entry['Aug']);
				$costCenterLabourRates->setMonthlyHourRate( 9, $entry['Sep']);
				$costCenterLabourRates->setMonthlyHourRate(10, $entry['Oct']);
				$costCenterLabourRates->setMonthlyHourRate(11, $entry['Nov']);
				$costCenterLabourRates->setMonthlyHourRate(12, $entry['Dec']);
				if ($this->context->costCenterRepository->saveRates($costCenterLabourRates))
				{
					$this->flashMessage("Work Center " . $costCenter->Name . " rates for year " . Date('Y') . " saved successfully.", 'success');
				}
				else
				{
					$this->flashMessage("Work Center " . $costCenter->Name . " rates saved unsuccessfully.", 'error');
				}
			}
			else
			{
				$this->flashMessage("Invalid form values.");
			}
		}
		else
		{
			$this->flashMessage("You are not authorized to update cost center rates. ADMIN role required.", 'error');
		}
        $this->redirect('CostCenter:showDetailCostCenter', $costCenter->ID);
    }
	
    /**
     * Creates DetailCostCenterForm for editing Cost Centers.
     * 
     * @param string $name DetailCostCenterForm.
     * @return AppForm DetailCostCenterForm.
     */
    public function createComponentDetailCostCenterForm($name)
    {
        $form = $this->createComponentCostCenterForm($name);
		
		$form['CostCenterID']->setAttribute('readonly', 'readonly');
        
		$form->addSubmit('createLR', 'Add Labour Rate')
			->setValidationScope(FALSE)
            ->onClick[] = callback($this, 'createLRClicked');
		if (!$this->isAllowed(self::RESOURCE_LABOUR_RATE, self::ACTION_CREATE))
			$form['createLR']->setDisabled(true);
		
        $form->onSuccess[] = array($this, 'detailCostCenterFormSubmitted');

        return $form;
    }
    
    /**
     * DetialCostCenterForm submitted.
     * 
     * @param AppForm $form DetailCostCenterForm submitted.
     */
    public function detailCostCenterFormSubmitted(AppForm $form)
    {
        $entry = $form->getValues();
		if ($this->isAllowed(self::RESOURCE_WORK_CENTER, self::ACTION_EDIT))	
		{
			if ($form->isValid())
			{
				$costCenter = $this->context->costCenterRepository->findCostCenter($entry['CostCenterID']);
//				$prefixCostCenter = $this->context->costCenterRepository->findCostCenterByTaskNamePrefix($entry['TaskNamePrefix']);
//				if(isset($prefixCostCenter))
//				{
//					if($prefixCostCenter->ID != $costCenter->ID)
//					{
//						$this->flashMessage("Work Center with Task Name Prefix: " . $entry['TaskNamePrefix'] . " already exists.", 'error');
//						$this->redirect('CostCenter:showDetailCostCenter', $entry['CostCenterID']);
//					}
//				}
				$costCenter->Name = $entry['Name'];
//				$costCenter->TaskNamePrefix = $entry['TaskNamePrefix'];
				$costCenter->Plant = $entry['Plant'];
				$canBeDeactivated = true;
				if($entry['Status'] == 'Active')
				{
					$costCenter->Status = 1;
				}
				else
				{
					$persons = $this->context->personRepository->findAllByWorkCenter($costCenter->ID);
					foreach ($persons as $eid => $person)
					{
						if($person->Status == 1)
						{
							$canBeDeactivated = false;
//							$listOfpersons[] = $person->getReversedFullNameWithEID();
						}
					}
					if($canBeDeactivated)
					{
						$costCenter->setStatus(0);
					}
				}
				if ($this->context->costCenterRepository->update($costCenter))
				{
					if($canBeDeactivated)
					{
						$this->flashMessage("Work Center " . $costCenter->Name . " updated successfully.", 'success');
					}
					else
					{
						$this->flashMessage("Work Center was updated, however update was not fully completed!", 'success');
						$this->flashMessage("Work Center " . $costCenter->ID . " cannot be deactivated. There is/are active worker/workers.", 'error');
					}
				}
				else
				{
					$this->flashMessage("Work Center " . $costCenter->Name . " updated unsuccessfully.", 'error');
				}
			}
			else
			{
				$this->flashMessage("Invalid form values.");
			}
		}
		else
		{
			$this->flashMessage("You are not authorized to update work center. ADMIN role required.", 'error');
		}
        $this->redirect('CostCenter:showDetailCostCenter', $entry['CostCenterID']);
    }

    /**
     * Creates LabourRateForm for editing Cost Centers.
     * 
     * @param string $name LabourRateForm.
     * @return AppForm LabourRateForm.
     */
    public function createComponentLabourRateForm($name)
    {
        $form = new AppForm($this, $name);
        
        $width = 3;
        
        $form->addText('Name', 'Name')
            ->setAttribute('readonly', 'readonly');

        $form->addText('Jan', 'January', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [January]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [January]', array(0, 999));
        $form->addText('Feb', 'February', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [February]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [February]', array(0, 999));
        $form->addText('Mar', 'March', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [March]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [March]', array(0, 999));
        $form->addText('Apr', 'April', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [April]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [April]', array(0, 999));
        $form->addText('May', 'May', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [May]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [May]', array(0, 999));
        $form->addText('Jun', 'June', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [June]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [June]', array(0, 999));
        $form->addText('Jul', 'July', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [July]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [July]', array(0, 999));
        $form->addText('Aug', 'August', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [August]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [August]', array(0, 999));
        $form->addText('Sep', 'September', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [September]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [September]', array(0, 999));
        $form->addText('Oct', 'October', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [October]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [October]', array(0, 999));
        $form->addText('Nov', 'November', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [November]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [November]', array(0, 999));
        $form->addText('Dec', 'December', $width)
            ->addRule(Form::FLOAT, 'Rate must be float. [December]')
            ->addRule(Form::RANGE, 'Rate must be positive number 0 - 999. [December]', array(0, 999));
        
        $form->addSubmit('back', 'Go back')
            ->setValidationScope(FALSE)
            ->onClick[] = callback($this, 'backClicked');
        $submit_button = $form->addSubmit('save', 'Save');
		if (!$this->isAllowed(self::RESOURCE_LABOUR_RATE, self::ACTION_CREATE))
			$submit_button->setDisabled(true);

        return $form;
    }
	
    /**
     * Creates CreateLabourRateForm for editing Cost Centers.
     * 
     * @param string $name CreateLabourRateForm.
     * @return AppForm CreateLabourRateForm.
     */
    public function createComponentCreateLabourRateForm($name)
    {
        $form = $this->createComponentLabourRateForm($name);
		
		$costCenterIDs = array();
		$costCenters = $this->context->costCenterRepository->findAllCostCenters();
		foreach($costCenters as $center)
		{
			$costCenterIDs[$center->ID] = $center->Name . ' (' .$center->ID . ')';
		}
        $form->addSelect('CostCenterID', 'Work Center', $costCenterIDs)
			->setPrompt('-- Choose Wrok Center --')
            ->setRequired('Please select Work Center!');

		$yearArr = Array();
		for($i = Date('Y') - 1; $i <= Date('Y') + 2; $i++)
		{
			$yearArr[$i] = $i;
		}
        $form->addSelect('Year', 'Year', $yearArr)
			->setDefaultValue(Date('Y'))
            ->setRequired('Please select year!');
        
        $form->onSuccess[] = array($this, 'createLabourRateFormSubmitted');

        return $form;
    }
	
    /**
     * Creates DetialLabourRateForm for editing Cost Centers.
     * 
     * @param string $name CreateLabourRateForm.
     * @return AppForm CreateLabourRateForm.
     */
    public function createComponentDetailLabourRateForm($name)
    {
        $form = $this->createComponentLabourRateForm($name);
        
        $form->addText('CostCenterID', 'Work Center ID', 8)
            ->setAttribute('readonly', 'readonly');

        $form->addText('Year', 'Year', 2)
            ->setAttribute('readonly', 'readonly');
		
        $form->onSuccess[] = array($this, 'detailLabourRateFormSubmitted');

        return $form;
    }
    
    /**
     * DetailLabourRateForm submitted.
     * 
     * @param AppForm $form DetailLabourRateForm submitted.
     */
    public function createLabourRateFormSubmitted(AppForm $form)
    {
        $entry = $form->getValues();
		if ($this->isAllowed(self::RESOURCE_LABOUR_RATE, self::ACTION_CREATE))
		{
			if ($form->isValid())
			{
				$costCenter = $this->context->costCenterRepository->findCostCenter($entry['CostCenterID']);
				if(is_null($costCenter))
				{
					$this->flashMessage("Work Center with ID: " . $entry['CostCenterID'] . " not found.", 'error');
					$this->redirect('CostCenter:createLabourRate');
				}
				$year = (int)$entry['Year'];
				if(!$costCenter->labourRateExists($year))
				{
					$costCenterLabourRates = new CostCenterLabourRates();
					$costCenterLabourRates->setID($costCenter->ID);
					$costCenterLabourRates->setYear($year);
					$costCenterLabourRates->setMonthlyHourRate( 1, $entry['Jan']);
					$costCenterLabourRates->setMonthlyHourRate( 2, $entry['Feb']);
					$costCenterLabourRates->setMonthlyHourRate( 3, $entry['Mar']);
					$costCenterLabourRates->setMonthlyHourRate( 4, $entry['Apr']);
					$costCenterLabourRates->setMonthlyHourRate( 5, $entry['May']);
					$costCenterLabourRates->setMonthlyHourRate( 6, $entry['Jun']);
					$costCenterLabourRates->setMonthlyHourRate( 7, $entry['Jul']);
					$costCenterLabourRates->setMonthlyHourRate( 8, $entry['Aug']);
					$costCenterLabourRates->setMonthlyHourRate( 9, $entry['Sep']);
					$costCenterLabourRates->setMonthlyHourRate(10, $entry['Oct']);
					$costCenterLabourRates->setMonthlyHourRate(11, $entry['Nov']);
					$costCenterLabourRates->setMonthlyHourRate(12, $entry['Dec']);
				}
				else
				{
					$this->flashMessage("Work Center with ID: " . $entry['CostCenterID'] . " has already labour rate for year: " . $year . ".", 'error');
					$this->redirect('CostCenter:createLabourRate');
				}
				if ($this->context->costCenterRepository->saveRates($costCenterLabourRates))
				{
					$this->flashMessage("Work Center " . $costCenter->Name . " rates saved successfully.", 'success');
				}
				else
				{
					$this->flashMessage("Work Center " . $costCenter->Name . " rates saved unsuccessfully.", 'error');
				}
			}
			else
			{
				$this->flashMessage("Invalid form values.");
			}
		}
		else
		{
			$this->flashMessage("You are not authorized to create work center rates. ADMIN role required.", 'error');
		}
        $this->redirect('CostCenter:showDetailLabourRate', $entry['CostCenterID'], $year);
    }
	
    /**
     * DetailLabourRateForm submitted.
     * 
     * @param AppForm $form DetailLabourRateForm submitted.
     */
    public function detailLabourRateFormSubmitted(AppForm $form)
    {
        $entry = $form->getValues();
		if ($this->isAllowed(self::RESOURCE_LABOUR_RATE, self::ACTION_EDIT))
		{
			if ($form->isValid())
			{
				$costCenter = $this->context->costCenterRepository->findCostCenter($entry['CostCenterID']);
				$costCenterLabourRates = $costCenter->getYearLabourRate($entry['Year']);
				$costCenterLabourRates->setMonthlyHourRate( 1, $entry['Jan']);
				$costCenterLabourRates->setMonthlyHourRate( 2, $entry['Feb']);
				$costCenterLabourRates->setMonthlyHourRate( 3, $entry['Mar']);
				$costCenterLabourRates->setMonthlyHourRate( 4, $entry['Apr']);
				$costCenterLabourRates->setMonthlyHourRate( 5, $entry['May']);
				$costCenterLabourRates->setMonthlyHourRate( 6, $entry['Jun']);
				$costCenterLabourRates->setMonthlyHourRate( 7, $entry['Jul']);
				$costCenterLabourRates->setMonthlyHourRate( 8, $entry['Aug']);
				$costCenterLabourRates->setMonthlyHourRate( 9, $entry['Sep']);
				$costCenterLabourRates->setMonthlyHourRate(10, $entry['Oct']);
				$costCenterLabourRates->setMonthlyHourRate(11, $entry['Nov']);
				$costCenterLabourRates->setMonthlyHourRate(12, $entry['Dec']);
				if ($this->context->costCenterRepository->update($costCenter))
				{
					$this->flashMessage("Work Center " . $costCenter->Name . " updated successfully.", 'success');
				}
				else
				{
					$this->flashMessage("Work Center " . $costCenter->Name . " updated unsuccessfully.", 'error');
				}
			}
			else
			{
				$this->flashMessage("Invalid form values.");
			}
		}
		else
		{
			$this->flashMessage("You are not authorized to update work center. ADMIN role required.", 'error');
		}
        $this->redirect('CostCenter:showDetailLabourRate', $entry['CostCenterID'], $entry['Year']);
    }
    
    /**
     * Go back button redirects back to WorkCenter:default.
     * 
     * @param SubmitButton $button Go back button.
     */
    public function backClicked(SubmitButton $button)
    {
        $this->redirect('default');
    }
	
    /**
     * button filterLabourRateFormReset clicked.
     * 
     * @param SubmitButton $button Go back button.
     */
    public function filterFormResetClicked(SubmitButton $button)
    {
        $this->redirect('default');
    }
	
    /**
     * button Create Work Center clicked.
     * 
     * @param SubmitButton $button Go back button.
     */
    public function createCCClicked(SubmitButton $button)
    {
        $this->redirect('createCostCenter');
    }
	
    /**
     * button Create Labour Rate clicked.
     * 
     * @param SubmitButton $button Go back button.
     */
    public function createLRClicked(SubmitButton $button)
    {
		$form = $button->getForm();
		$values = $form->getValues();
		if(isset($values['CostCenterID']))
		{
			$this->redirect('createLabourRate', $values['CostCenterID']);
		}
		else
		{
			$this->redirect('createLabourRate');
		}
    }
}
