<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters
 */

/**
 * Presenter for auto generation of eac details report.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class EACAutoGenerationPresenter extends TokenAccessPresenter
{
	/* authentication token setup */
	const AUTH_TOKEN_NAME = 'token',
		  AUTH_TOKEN_KEY = 'EACReport.credentials.cronToken';
	
    /**
     * Returns http parameter name with authentication token.
     * 
     * @return string
     */
	protected function getAuthTokenName()
	{
		return self::AUTH_TOKEN_NAME;
	}

    /**
     * Returns http parameter name with authentication token.
	 * 
     * @return string
     */
	protected function getAuthTokenSettingsKey()
	{
		return self::AUTH_TOKEN_KEY;
	}
	
    /**
     * Nette default render method 
     */
	public function renderDefault()
	{
	}
    
	/**
     * Generate method 
     */
    public function renderGenerateReport()
    {
		$year = date('Y');
		$sbe = $this->context->organizationUnitRepository->findAllOrgUnitByType(OrganizationUnit::ORG_UNIT_TYPE_SBE);
		$multilog = new MultiLogger();
		$batch_id = 'EAC-'.time().'-'. rand(1, 9);
		$multilog->add($this->context->createLogger($batch_id, "EAC auto generation"));
		if(count($sbe) <= 0)
		{
			$multilog->log('EAC auto generation failed: No SBE to report was found.', ILogger::ERROR);
			exit;
		}
		$EACReportService = new EACReportService($this->context, $multilog, $year, $sbe);
		$importResult = true;
		try
		{
			$EACReportService->runEACDetailsGeneration();
		}
		catch (EeacReportServiceException $e)
		{
			$importResult = false;
			Debugger::log('EAC auto generation failed: ' . $e->getMessage(), Debugger::ERROR);
			
		}
		$this->template->result = $importResult;
		if($importResult)
			$multilog->log('EAC auto generation completed.', ILogger::NOTICE);
    }
}

