<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2013 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters
 */

/**
 * Presenter for exporting project charters.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class ProjectCharterReportPresenter extends SecuredPresenter
{
    
    /**
     * Nette default render method.
     */
    public function renderDefault()
    {
        $formDefaultReport = array();
        $downloadReport = $this['downloadForm'];
        $downloadReport->setDefaults($formDefaultReport);
        $this->template->downloadReport = $downloadReport;
    }
    
    /**
     * Generates Project chartes report as a XLSX (MS-EXCEL file).
	 *
     * @param Array $projectCharters Array of project charter objects.
	 * @param Array $values Year and OrganizationUnit ID from input form.
     * @param objPHPExcel $objPHPExcel Output file.
     */
    public function generateReport($projectCharters, $values, $objPHPExcel)
    {
		//increase executon time limit
        $exec_time = 90;
	    if (!ini_set("max_execution_time", $exec_time)) 
		{
			$this->flashMessage('Setup of maximum execution time failed. Contact administrator.', 'error');
			trigger_error('Unable to setup maximum execution time to '.$exec_time.'.', E_USER_ERROR);
		}
		/*** LEGEND SHEET ***/
		// as first sheet
        $sheet4 = $objPHPExcel->getActiveSheet();
        $sheet4->setTitle("Legend");
		
        // First sheet of excel file - Owned projects
        // Data preparation
        $finalSUMRows = array();
        $finalSUMRows['first'] = 0;
		$hrsSumRows = array();
        $arrayF = $arrayG = $arrayH = $arrayI = $arrayM = $arrayN = $arrayO = $arrayP = array();
        $columnF = '';
        $columnG = '';
        $columnH = '';
        $columnI = '';
		$columnM = '';
		$columnN = '';
		$columnO = '';
		$columnP = '';
        $orgUnit = $this->context->organizationUnitRepository->find($values['OrgUnit']);
        $sheet = $objPHPExcel->createSheet(1); 
		$sheet->getTabColor()->setRGB('D7E4BC');
        $rowIterator = $sheet->getRowIterator();
        $cellIterator = $rowIterator->current()->getCellIterator();
		
        //Format setting
        $sheet->setTitle('Owned projects - total budget');
		$sheet->freezePane('A7');
        $sheet->getStyle('A1')->getFont()->setBold(true);
        $sheet->getStyle('A6:S6')->getFont()->setBold(true);
        $sheet->getStyle('A6:S6')->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
        $sheet->getColumnDimension('A')->setWidth(30);
        $sheet->getColumnDimension('B')->setWidth(30);
        $sheet->getColumnDimension('C')->setWidth(30);
        $sheet->getColumnDimension('D')->setWidth(25);
        $sheet->getColumnDimension('E')->setWidth(35);
		$sheet->getColumnDimension('F')->setWidth(20);
		$borderMediumTop = array(
        	'borders' => array(
                'top' => array(
                    'style' => PHPExcel_Style_Border::BORDER_MEDIUM,
                    'color' => array('rgb' => '000000')
                ),
            ),
        );
        
        $borderMediumBottom = array(
        	'borders' => array(
                'bottom' => array(
                    'style' => PHPExcel_Style_Border::BORDER_MEDIUM,
                    'color' => array('rgb' => '000000')
                ),
            ),
        );
        $borderMediumLeft = array(
        	'borders' => array(
                'left' => array(
                    'style' => PHPExcel_Style_Border::BORDER_MEDIUM,
                    'color' => array('rgb' => '000000')
                ),
            ),
        );
        $borderMediumRight = array(
        	'borders' => array(
                'right' => array(
                    'style' => PHPExcel_Style_Border::BORDER_MEDIUM,
                    'color' => array('rgb' => '000000')
                ),
            ),
        );
        $borderThinTop = array(
        	'borders' => array(
                'top' => array(
                    'style' => PHPExcel_Style_Border::BORDER_THIN,
                    'color' => array('rgb' => '000000')
                ),
            ),
        );
        $borderThinRight = array(
        	'borders' => array(
                'right' => array(
                    'style' => PHPExcel_Style_Border::BORDER_THIN,
                    'color' => array('rgb' => '000000')
                ),
            ),
        );
		
        // Collapsing columns 
        $sheet->getColumnDimension('C')->setOutlineLevel(1);
        $sheet->getColumnDimension('C')->setVisible(true);
        $sheet->getColumnDimension('C')->setCollapsed(false);
        $sheet->getColumnDimension('D')->setOutlineLevel(1);
        $sheet->getColumnDimension('D')->setVisible(true);
        $sheet->getColumnDimension('D')->setCollapsed(false);
        $sheet->getColumnDimension('E')->setOutlineLevel(1);
        $sheet->getColumnDimension('E')->setVisible(true);
        $sheet->getColumnDimension('E')->setCollapsed(false);
		$sheet->getColumnDimension('F')->setOutlineLevel(1);
        $sheet->getColumnDimension('F')->setVisible(true);
        $sheet->getColumnDimension('F')->setCollapsed(false);
        
        $sheet->getColumnDimension('M')->setOutlineLevel(1);
        $sheet->getColumnDimension('M')->setVisible(true);
        $sheet->getColumnDimension('M')->setCollapsed(false);
        $sheet->getColumnDimension('N')->setOutlineLevel(1);
        $sheet->getColumnDimension('N')->setVisible(true);
        $sheet->getColumnDimension('N')->setCollapsed(false);
        $sheet->getColumnDimension('O')->setOutlineLevel(1);
        $sheet->getColumnDimension('O')->setVisible(true);
        $sheet->getColumnDimension('O')->setCollapsed(false);
        $sheet->getColumnDimension('P')->setOutlineLevel(1);
        $sheet->getColumnDimension('P')->setVisible(true);
        $sheet->getColumnDimension('P')->setCollapsed(false);
        $sheet->getColumnDimension('Q')->setOutlineLevel(1);
        $sheet->getColumnDimension('Q')->setVisible(true);
        $sheet->getColumnDimension('Q')->setCollapsed(false);
        $sheet->getColumnDimension('R')->setOutlineLevel(1);
        $sheet->getColumnDimension('R')->setVisible(true);
        $sheet->getColumnDimension('R')->setCollapsed(false);
        $sheet->getColumnDimension('S')->setOutlineLevel(1);
        $sheet->getColumnDimension('S')->setVisible(true);
        $sheet->getColumnDimension('S')->setCollapsed(false);
        
        // Header     
        $cellIterator->current()->setValue("Project Charters for " . OrganizationUnit::getFullTypeName($orgUnit->Type) . ": " . $orgUnit->Name);
        $cellIterator->next();
        $rowIterator->next();
        $cellIterator = $rowIterator->current()->getCellIterator();
        $cellIterator->current()->setValue('Projects which are owned by ' . OrganizationUnit::getFullTypeName($orgUnit->Type) . " " . $orgUnit->Name . '. Ownership is determined by Cluster leader stated in project charter.');
        $rowIterator->next();
		$cellIterator = $rowIterator->current()->getCellIterator();
        $cellIterator->current()->setValue('This report shows all resources that will be required for those projects.');
        $rowIterator->next();
		$rowIterator->next();
		$cellIterator = $rowIterator->current()->getCellIterator();
        $cellIterator->current()->setValue('HINT: to see resources of other units working at projects of ' . OrganizationUnit::getFullTypeName($orgUnit->Type) . " " . $orgUnit->Name . ', use filter in "Resource" column.');
        $rowIterator->next();
        $cellIterator = $rowIterator->current()->getCellIterator();
        $cellIterator->current()->setValue("Project name");
        $cellIterator->next();
        $cellIterator->current()->setValue("Resource");
        $cellIterator->next();
        $cellIterator->current()->setValue("Cluster");
        $cellIterator->next();
        $cellIterator->current()->setValue("Program");
        $cellIterator->next();
        $cellIterator->current()->setValue("RTC");
        $cellIterator->next();
        $cellIterator->current()->setValue("Status");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q1");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q2");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q3");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q4");
        $cellIterator->next();
        $cellIterator->current()->setValue("Total");
        $cellIterator->next();
        $cellIterator->current()->setValue("Unit");
        $cellIterator->next();
        $cellIterator->current()->setValue("CostShare");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q1");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q2");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q3");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q4");
        $cellIterator->next();
        $cellIterator->current()->setValue("Total");
        $cellIterator->next();
        $cellIterator->current()->setValue("Unit");
        $cellIterator->next();
        $row = $cellIterator->current()->getRow();
        $sheet->getStyle('A' . $row . ':' . 'S' . $row)->applyFromArray($borderMediumBottom);
        $rowIterator->next();
        $cellIterator = $rowIterator->current()->getCellIterator();
                                
        // Data export
        $colorValue = 1;
		foreach($projectCharters as $charter)
		{
			if($charter->status != Projectcharter::PROJECT_CHARTER_STATUS_CANCELLED)
			{
				$TGs = $this->context->organizationUnitRepository->findAllTechnicalGroupOnCharter($charter->ID);
				$SUBs = $this->context->subcontractorRepository->findAllSubcontractorsOnCharter($charter->ID);
				$totalCharterSUMFirstRow = $cellIterator->current()->getRow();
				$travel_Q1 = $travel_Q2 = $travel_Q3 = $travel_Q4 = 0;
				$material_Q1 = $material_Q2 = $material_Q3 = $material_Q4 = 0;
				$projectCharetrBudgetHistory = $this->context->projectCharterBudgetHistoryRepository->findLatestVersion($charter->ID);
				if($projectCharetrBudgetHistory != null)
				{
					$projectCharterBudgets = $this->context->projectCharterBudgetRepository->findByProjecCharterIDAndVersion($charter->ID, $projectCharetrBudgetHistory->version);
					foreach($projectCharterBudgets as $projectCharterBudget)
					{
						foreach($TGs as $tg)
						{
							if($projectCharterBudget->technicalGroup == $tg->ID AND $projectCharterBudget->resourceType == 'HRS')
							{
								$row = $cellIterator->current()->getRow();
								if($finalSUMRows['first'] == 0)
									$finalSUMRows['first'] = $row;
								$hrsSumRows[] = $row;
								$cellIterator->current()->setValue($charter->name);
								$cellIterator->next();
								$cellIterator->current()->setValue($tg->name);
								$cellIterator->next();
								if(strlen($tg->Path) == 12)
								{
									$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($tg->Parent_ID)->name);
								}
								else
								{
									$cellIterator->current()->setValue($tg->name);
								}
								$cellIterator->next();
								$cellIterator->current()->setValue($this->context->customerRepository->find($charter->customerID)->name);
								$cellIterator->next();
								$cellIterator->current()->setValue($this->context->responsibilityRepository->find($charter->responsibilityID)->name);
								$cellIterator->next();
								$cellIterator->current()->setValue($charter->status);
								$cellIterator->next();          
								$rate = $projectCharterBudget->rate;
								$cellIterator->current()->setValue(round($projectCharterBudget->budgetQ1 * $rate));
								$sheet->getStyle('G' . $row)->applyFromArray($borderMediumLeft);
								$cellIterator->next();
								$cellIterator->current()->setValue(round($projectCharterBudget->budgetQ2 * $rate));
								$cellIterator->next();
								$cellIterator->current()->setValue(round($projectCharterBudget->budgetQ3 * $rate));
								$cellIterator->next();
								$cellIterator->current()->setValue(round($projectCharterBudget->budgetQ4 * $rate));
								$sheet->getStyle('J' . $row)->applyFromArray($borderMediumRight);
								$cellIterator->next();
								$cellIterator->current()->setValue("=SUM(G" . $row . ":J" . $row . ")");
								$cellIterator->next();
								$cellIterator->current()->setValue("USD");
								$sheet->getStyle('L' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
								$sheet->getStyle('L' . $row)->applyFromArray($borderThinRight);
								$cellIterator->next();
								$cellIterator->next();
								$cellIterator->current()->setValue(round($projectCharterBudget->budgetQ1));
								$cellIterator->next();
								$cellIterator->current()->setValue(round($projectCharterBudget->budgetQ2));
								$cellIterator->next();
								$cellIterator->current()->setValue(round($projectCharterBudget->budgetQ3));
								$cellIterator->next();
								$cellIterator->current()->setValue(round($projectCharterBudget->budgetQ4));
								$cellIterator->next();
								$cellIterator->current()->setValue("=SUM(N" . $row . ":Q" . $row . ")");
								$cellIterator->next();
								$cellIterator->current()->setValue("hrs");
								$sheet->getStyle('S' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
								$cellIterator->next();
								$sheet->getRowDimension($row)->setOutlineLevel(1);
								$sheet->getRowDimension($row)->setVisible(false);
								if($colorValue/2 != floor($colorValue/2))
									$sheet->getStyle('A' . $row . ':S' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('DBE5F1');
								else
									$sheet->getStyle('A' . $row . ':S' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('F2F2F2');
								$rowIterator->next();
								$cellIterator = $rowIterator->current()->getCellIterator();
							}
							if($projectCharterBudget->resourceType == 'TRV')
							{
								$travel_Q1 = $projectCharterBudget->budgetQ1;
								$travel_Q2 = $projectCharterBudget->budgetQ2;
								$travel_Q3 = $projectCharterBudget->budgetQ3;
								$travel_Q4 = $projectCharterBudget->budgetQ4;
							}
							if($projectCharterBudget->resourceType == 'MAT')
							{
								$material_Q1 = $projectCharterBudget->budgetQ1;
								$material_Q2 = $projectCharterBudget->budgetQ2;
								$material_Q3 = $projectCharterBudget->budgetQ3;
								$material_Q4 = $projectCharterBudget->budgetQ4;
							}
						}
					}
					// Travel
					$row = $cellIterator->current()->getRow();
					$cellIterator->current()->setValue($charter->name);
					$cellIterator->next();
					$cellIterator->current()->setValue('Travel');
					$cellIterator->next();
					$cellIterator->next();
					$cellIterator->current()->setValue($this->context->customerRepository->find($charter->customerID)->name);
					$cellIterator->next();
					$cellIterator->current()->setValue($this->context->responsibilityRepository->find($charter->responsibilityID)->name);
					$cellIterator->next();
					$cellIterator->current()->setValue($charter->status);
					$cellIterator->next();
					$cellIterator->current()->setValue(round($travel_Q1));
					$sheet->getStyle('G' . $row)->applyFromArray($borderMediumLeft);
					$cellIterator->next();
					$cellIterator->current()->setValue(round($travel_Q2));
					$cellIterator->next();
					$cellIterator->current()->setValue(round($travel_Q3));
					$cellIterator->next();
					$cellIterator->current()->setValue(round($travel_Q4));
					$sheet->getStyle('J' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(G" . $row . ":J" . $row . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue("USD");
					$sheet->getStyle('L' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
					$sheet->getStyle('L' . $row)->applyFromArray($borderThinRight);
					$cellIterator->next();
					$sheet->getStyle('A' . $row . ':' . 'S' . $row)->applyFromArray($borderThinTop);
					$sheet->getRowDimension($row)->setOutlineLevel(1);
					$sheet->getRowDimension($row)->setVisible(false);
					if($colorValue/2 != floor($colorValue/2))
						$sheet->getStyle('A' . $row . ':S' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('DBE5F1');
					else
						$sheet->getStyle('A' . $row . ':S' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('F2F2F2');
					$rowIterator->next();
					$cellIterator = $rowIterator->current()->getCellIterator();
					// Material
					$row = $cellIterator->current()->getRow();
					$cellIterator->current()->setValue($charter->name);
					$cellIterator->next();
					$cellIterator->current()->setValue('Material');
					$cellIterator->next();
					$cellIterator->next();
					$cellIterator->current()->setValue($this->context->customerRepository->find($charter->customerID)->name);
					$cellIterator->next();
					$cellIterator->current()->setValue($this->context->responsibilityRepository->find($charter->responsibilityID)->name);
					$cellIterator->next();
					$cellIterator->current()->setValue($charter->status);
					$cellIterator->next();
					$cellIterator->current()->setValue(round($material_Q1));
					$sheet->getStyle('G' . $row)->applyFromArray($borderMediumLeft);
					$cellIterator->next();
					$cellIterator->current()->setValue(round($material_Q2));
					$cellIterator->next();
					$cellIterator->current()->setValue(round($material_Q3));
					$cellIterator->next();
					$cellIterator->current()->setValue(round($material_Q4));
					$sheet->getStyle('J' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(G" . $row . ":J" . $row . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue("USD");
					$sheet->getStyle('L' . $row)->applyFromArray($borderThinRight);
					$sheet->getStyle('L' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
					$cellIterator->next();
					$sheet->getRowDimension($row)->setOutlineLevel(1);
					$sheet->getRowDimension($row)->setVisible(false);
					if($colorValue/2 != floor($colorValue/2))
						$sheet->getStyle('A' . $row . ':S' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('DBE5F1');
					else
						$sheet->getStyle('A' . $row . ':S' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('F2F2F2');
					$rowIterator->next();
					$cellIterator = $rowIterator->current()->getCellIterator();
					// Subcontracting
					foreach($projectCharterBudgets as $projectCharterBudget)
					{
						foreach($SUBs as $sub)
						{
							if($projectCharterBudget->subcontractor == $sub->ID AND $projectCharterBudget->resourceType == 'SUB')
							{
								$row = $cellIterator->current()->getRow();
								$finalSUMRows['last'] = $row;
								$cellIterator->current()->setValue($charter->name);
								$cellIterator->next();
								$cellIterator->current()->setValue('Subcontracting - ' . $sub->short);
								$cellIterator->next();
								$cellIterator->next();
								$cellIterator->current()->setValue($this->context->customerRepository->find($charter->customerID)->name);
								$cellIterator->next();
								$cellIterator->current()->setValue($this->context->responsibilityRepository->find($charter->responsibilityID)->name);
								$cellIterator->next();
								$cellIterator->current()->setValue($charter->status);
								$cellIterator->next();
								$cellIterator->current()->setValue(round($projectCharterBudget->budgetQ1));
								$sheet->getStyle('G' . $row)->applyFromArray($borderMediumLeft);
								$cellIterator->next();
								$cellIterator->current()->setValue(round($projectCharterBudget->budgetQ2));
								$cellIterator->next();
								$cellIterator->current()->setValue(round($projectCharterBudget->budgetQ3));
								$cellIterator->next();
								$cellIterator->current()->setValue(round($projectCharterBudget->budgetQ4));
								$sheet->getStyle('J' . $row)->applyFromArray($borderMediumRight);
								$cellIterator->next();
								$cellIterator->current()->setValue("=SUM(G" . $row . ":J" . $row . ")");
								$cellIterator->next();
								$cellIterator->current()->setValue("USD");
								$sheet->getStyle('L' . $row)->applyFromArray($borderThinRight);
								$sheet->getStyle('L' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
								$cellIterator->next();
								$sheet->getRowDimension($row)->setOutlineLevel(1);
								$sheet->getRowDimension($row)->setVisible(false);
								if($colorValue/2 != floor($colorValue/2))
									$sheet->getStyle('A' . $row . ':S' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('DBE5F1');
								else
									$sheet->getStyle('A' . $row . ':S' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('F2F2F2');
								$rowIterator->next();                
								$cellIterator = $rowIterator->current()->getCellIterator();
							}
						}
					}
					// Total
					$finalSUMRows['last'] = $totalCharterSUMLastRow = $row;
					$row = $cellIterator->current()->getRow();
					$cellIterator->current()->setValue($charter->name);
					$cellIterator->next();
					$cellIterator->current()->setValue('(Total)');
					$cellIterator->next();
					$cellIterator->next();
					$cellIterator->current()->setValue($this->context->customerRepository->find($charter->customerID)->name);
					$cellIterator->next();
					$cellIterator->current()->setValue($this->context->responsibilityRepository->find($charter->responsibilityID)->name);
					$cellIterator->next();
					$cellIterator->current()->setValue($charter->status);
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(G" . $totalCharterSUMFirstRow . ":G" . $totalCharterSUMLastRow . ")");
					$sheet->getStyle('G' . $row)->applyFromArray($borderMediumLeft);
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(H" . $totalCharterSUMFirstRow . ":H" . $totalCharterSUMLastRow . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(I" . $totalCharterSUMFirstRow . ":I" . $totalCharterSUMLastRow . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(J" . $totalCharterSUMFirstRow . ":J" . $totalCharterSUMLastRow . ")");
					$sheet->getStyle('J' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(G" . $row . ":J" . $row . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue("USD");
					$sheet->getStyle('L' . $row)->applyFromArray($borderThinRight);
					$sheet->getStyle('S' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
					$sheet->getStyle('L' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
					$cellIterator->next();
					$cellIterator->current()->setValue($charter->CostShare);
					$sheet->getStyle($cellIterator->current()->getColumn() . $cellIterator->current()->getRow())->getNumberFormat()->setFormatCode('##0%');
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(N" . $totalCharterSUMFirstRow . ":N" . $totalCharterSUMLastRow . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(O" . $totalCharterSUMFirstRow . ":O" . $totalCharterSUMLastRow . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(P" . $totalCharterSUMFirstRow . ":P" . $totalCharterSUMLastRow . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(Q" . $totalCharterSUMFirstRow . ":Q" . $totalCharterSUMLastRow . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(N" . $row . ":Q" . $row . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue("hrs");
	//                $sheet->getStyle('A' . $row . ':R' . $row)->getFont()->setBold(true);
					$sheet->getStyle('A' . $row . ':' . 'S' . $row)->applyFromArray($borderMediumBottom);
					if($colorValue/2 != floor($colorValue/2))
						$sheet->getStyle('A' . $row . ':S' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('B8CCE4');
					else
						$sheet->getStyle('A' . $row . ':S' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('D8D8D8');
					$rowIterator->next();
					$cellIterator = $rowIterator->current()->getCellIterator();
					if($finalSUMRows['first'] != 0)
					{
						$arrayG[] = 'G' . $finalSUMRows['first'] . ':G' . $finalSUMRows['last'];
						$arrayH[] = 'H' . $finalSUMRows['first'] . ':H' . $finalSUMRows['last'];
						$arrayI[] = 'I' . $finalSUMRows['first'] . ':I' . $finalSUMRows['last'];
						$arrayM[] = 'J' . $finalSUMRows['first'] . ':J' . $finalSUMRows['last'];
						$arrayN[] = 'N' . $finalSUMRows['first'] . ':N' . $finalSUMRows['last'];
						$arrayO[] = 'O' . $finalSUMRows['first'] . ':O' . $finalSUMRows['last'];
						$arrayP[] = 'P' . $finalSUMRows['first'] . ':P' . $finalSUMRows['last'];
						$arrayF[] = 'Q' . $finalSUMRows['first'] . ':Q' . $finalSUMRows['last'];
					}
					$finalSUMRows['first'] = 0;
					$finalSUMRows['last'] = 0;
				}
				$colorValue++;
			}
		}
        $rowIterator->next();
        $cellIterator = $rowIterator->current()->getCellIterator();
        //final total sum
        if($arrayF != null)
        {
            $columnF = join(',', $arrayF);
            $columnG = join(',', $arrayG);
            $columnH = join(',', $arrayH);
            $columnI = join(',', $arrayI);
			$columnM = join(',', $arrayM);
			$columnN = join(',', $arrayN);
			$columnO = join(',', $arrayO);
			$columnP = join(',', $arrayP);
            $row = $cellIterator->current()->getRow();
            $cellIterator->current()->setValue('Projects total');
            $cellIterator->next();
			$cellIterator->next();
            $cellIterator->next();
            $cellIterator->next();
            $cellIterator->next();
            $cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnG . ')');
            $cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnH . ')');
            $cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnI . ')');
			$cellIterator->next();
			$cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnM . ')');
            $cellIterator->next();
            $cellIterator->current()->setValue("=SUM(G" . $row . ":J" . $row . ")");
            $cellIterator->next();
            $cellIterator->current()->setValue("USD");
			$cellIterator->next();
			$cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnN . ')');
            $cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnO . ')');
            $cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnP . ')');
            $cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnF . ')');
            $cellIterator->next();
            $cellIterator->current()->setValue("=SUM(N" . $row . ":Q" . $row . ")");
			$cellIterator->next();
            $cellIterator->current()->setValue("hrs");
			$sheet->getStyle('S' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
            $sheet->getStyle('L' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
            $cellIterator->next();
            $sheet->getStyle('A' . $row . ':S' . $row)->getFont()->setBold(true);
            $rowIterator->next();
            $cellIterator = $rowIterator->current()->getCellIterator();
        }


        // Second sheet of excel file - Own projects - Hon investment
        //Format setting
        $sheet2 = $objPHPExcel->createSheet(2);
		$sheet2->freezePane('A8');
		$sheet2->getTabColor()->setRGB('D7E4BC');
        $sheet2->setTitle("Owned projects - HON investment");
        $rowIterator = $sheet2->getRowIterator();
        $cellIterator = $rowIterator->current()->getCellIterator();
        $sheet2->getStyle('A1')->getFont()->setBold(true);
        $sheet2->getStyle('A7:S7')->getFont()->setBold(true);
        $sheet2->getStyle('A7:S7')->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
        $sheet2->getColumnDimension('A')->setWidth(30);
        $sheet2->getColumnDimension('B')->setWidth(30);
        $sheet2->getColumnDimension('C')->setWidth(30);
        $sheet2->getColumnDimension('D')->setWidth(25);
        $sheet2->getColumnDimension('E')->setWidth(35);
		$sheet2->getColumnDimension('F')->setWidth(20);
        
        // Collapsing columns 
        $sheet2->getColumnDimension('C')->setOutlineLevel(1);
        $sheet2->getColumnDimension('C')->setVisible(true);
        $sheet2->getColumnDimension('C')->setCollapsed(false);
        $sheet2->getColumnDimension('D')->setOutlineLevel(1);
        $sheet2->getColumnDimension('D')->setVisible(true);
        $sheet2->getColumnDimension('D')->setCollapsed(false);
        $sheet2->getColumnDimension('E')->setOutlineLevel(1);
        $sheet2->getColumnDimension('E')->setVisible(true);
        $sheet2->getColumnDimension('E')->setCollapsed(false);
		$sheet2->getColumnDimension('F')->setOutlineLevel(1);
        $sheet2->getColumnDimension('F')->setVisible(true);
        $sheet2->getColumnDimension('F')->setCollapsed(false);
        
        $sheet2->getColumnDimension('M')->setOutlineLevel(1);
        $sheet2->getColumnDimension('M')->setVisible(true);
        $sheet2->getColumnDimension('M')->setCollapsed(false);
        $sheet2->getColumnDimension('N')->setOutlineLevel(1);
        $sheet2->getColumnDimension('N')->setVisible(true);
        $sheet2->getColumnDimension('N')->setCollapsed(false);
        $sheet2->getColumnDimension('O')->setOutlineLevel(1);
        $sheet2->getColumnDimension('O')->setVisible(true);
        $sheet2->getColumnDimension('O')->setCollapsed(false);
        $sheet2->getColumnDimension('P')->setOutlineLevel(1);
        $sheet2->getColumnDimension('P')->setVisible(true);
        $sheet2->getColumnDimension('P')->setCollapsed(false);
        $sheet2->getColumnDimension('Q')->setOutlineLevel(1);
        $sheet2->getColumnDimension('Q')->setVisible(true);
        $sheet2->getColumnDimension('Q')->setCollapsed(false);
        $sheet2->getColumnDimension('R')->setOutlineLevel(1);
        $sheet2->getColumnDimension('R')->setVisible(true);
        $sheet2->getColumnDimension('R')->setCollapsed(false);
        $sheet2->getColumnDimension('S')->setOutlineLevel(1);
        $sheet2->getColumnDimension('S')->setVisible(true);
        $sheet2->getColumnDimension('S')->setCollapsed(false);
        
        // Header     
        $cellIterator->current()->setValue("Project Charters for " . OrganizationUnit::getFullTypeName($orgUnit->Type) . ": " . $orgUnit->Name);
        $cellIterator->next();
        $rowIterator->next();
        $cellIterator = $rowIterator->current()->getCellIterator();
        $cellIterator->current()->setValue('Projects which are owned by ' . OrganizationUnit::getFullTypeName($orgUnit->Type) . ' ' . $orgUnit->Name . '. Ownership is determined by Cluster leader stated in project charter.');
        $rowIterator->next();
		$cellIterator = $rowIterator->current()->getCellIterator();
        $cellIterator->current()->setValue('This report shows all resources that will be required for those projects.');
        $rowIterator->next();
		$cellIterator = $rowIterator->current()->getCellIterator();
        $cellIterator->current()->setValue('Values shown in this sheet are an expected Honeywell investment - RD&E funding (determined by total costs and cost share stated in project charter).');
		$rowIterator->next();
		$rowIterator->next();
		$cellIterator = $rowIterator->current()->getCellIterator();
        $cellIterator->current()->setValue('HINT: to see resources of other units working at projects of ' . OrganizationUnit::getFullTypeName($orgUnit->Type) . " " . $orgUnit->Name . ', use filter in "Resource" column.');
        $rowIterator->next();
        $cellIterator = $rowIterator->current()->getCellIterator();
        $cellIterator->current()->setValue("Project name");
        $cellIterator->next();
        $cellIterator->current()->setValue("Resource");
        $cellIterator->next();
		$cellIterator->current()->setValue("Cluster");
		$cellIterator->next();
        $cellIterator->current()->setValue("Program");
        $cellIterator->next();
        $cellIterator->current()->setValue("RTC");
        $cellIterator->next();
        $cellIterator->current()->setValue("Status");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q1");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q2");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q3");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q4");
        $cellIterator->next();
        $cellIterator->current()->setValue("Total");
        $cellIterator->next();
        $cellIterator->current()->setValue("Unit");
        $cellIterator->next();
        $cellIterator->current()->setValue("CostShare");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q1");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q2");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q3");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q4");
        $cellIterator->next();
        $cellIterator->current()->setValue("Total");
        $cellIterator->next();
        $cellIterator->current()->setValue("Unit");
        $cellIterator->next();
        $row = $cellIterator->current()->getRow();
        $sheet2->getStyle('A' . $row . ':' . 'S' . $row)->applyFromArray($borderMediumBottom);
        $rowIterator->next();
        $cellIterator = $rowIterator->current()->getCellIterator();
                                
        // Data export
        $colorValue = 1;
        $finalSUMRows = array();
        $finalSUMRows['first'] = 0;
        $arrayF = $arrayG = $arrayH = $arrayI = $arrayM = $arrayN = $arrayO = $arrayP = array();
		foreach($projectCharters as $charter)
		{
			if($charter->status != Projectcharter::PROJECT_CHARTER_STATUS_CANCELLED)
			{
				$TGs = $this->context->organizationUnitRepository->findAllTechnicalGroupOnCharter($charter->ID);
				$SUBs = $this->context->subcontractorRepository->findAllSubcontractorsOnCharter($charter->ID);
				$totalCharterSUMFirstRow = $cellIterator->current()->getRow();
				$travel_Q1 = $travel_Q2 = $travel_Q3 = $travel_Q4 = 0;
				$material_Q1 = $material_Q2 = $material_Q3 = $material_Q4 = 0;
				$projectCharetrBudgetHistory = $this->context->projectCharterBudgetHistoryRepository->findLatestVersion($charter->ID);
				if($projectCharetrBudgetHistory != null)
				{
					$projectCharterBudgets = $this->context->projectCharterBudgetRepository->findByProjecCharterIDAndVersion($charter->ID, $projectCharetrBudgetHistory->version);
					foreach($projectCharterBudgets as $projectCharterBudget)
					{
						foreach($TGs as $tg)
						{
							if($projectCharterBudget->technicalGroup == $tg->ID AND $projectCharterBudget->resourceType == 'HRS')
							{
								$row = $cellIterator->current()->getRow();
								if($finalSUMRows['first'] == 0)
									$finalSUMRows['first'] = $row;
								$cellIterator->current()->setValue($charter->name);
								$cellIterator->next();
								$cellIterator->current()->setValue($tg->name);
								$cellIterator->next();
								if(strlen($tg->Path) == 12)
								{
									$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($tg->Parent_ID)->name);
								}
								else
								{
									$cellIterator->current()->setValue($tg->name);
								}
								$cellIterator->next();
								$cellIterator->current()->setValue($this->context->customerRepository->find($charter->customerID)->name);
								$cellIterator->next();
								$cellIterator->current()->setValue($this->context->responsibilityRepository->find($charter->responsibilityID)->name);
								$cellIterator->next();
								$cellIterator->current()->setValue($charter->status);
								$cellIterator->next();
								$rate = $projectCharterBudget->rate;
								$cellIterator->current()->setValue(round($projectCharterBudget->budgetQ1 * $rate  * (1 - $charter->CostShare)));
								$sheet2->getStyle('G' . $row)->applyFromArray($borderMediumLeft);
								$cellIterator->next();
								$cellIterator->current()->setValue(round($projectCharterBudget->budgetQ2 * $rate  * (1 - $charter->CostShare)));
								$cellIterator->next();
								$cellIterator->current()->setValue(round($projectCharterBudget->budgetQ3 * $rate  * (1 - $charter->CostShare)));
								$cellIterator->next();
								$cellIterator->current()->setValue(round($projectCharterBudget->budgetQ4 * $rate  * (1 - $charter->CostShare)));
								$sheet2->getStyle('J' . $row)->applyFromArray($borderMediumRight);
								$cellIterator->next();
								$cellIterator->current()->setValue("=SUM(G" . $row . ":J" . $row . ")");
								$cellIterator->next();
								$cellIterator->current()->setValue("USD");
								$sheet2->getStyle('L' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
								$sheet2->getStyle('L' . $row)->applyFromArray($borderThinRight);
								$cellIterator->next();
								$cellIterator->next();
								$cellIterator->current()->setValue(round(($projectCharterBudget->budgetQ1)));
								$cellIterator->next();
								$cellIterator->current()->setValue(round(($projectCharterBudget->budgetQ2)));
								$cellIterator->next();
								$cellIterator->current()->setValue(round(($projectCharterBudget->budgetQ3)));
								$cellIterator->next();
								$cellIterator->current()->setValue(round(($projectCharterBudget->budgetQ4)));
								$cellIterator->next();
								$cellIterator->current()->setValue("=SUM(N" . $row . ":Q" . $row . ")");
								$cellIterator->next();
								$cellIterator->current()->setValue("hrs");
								$sheet2->getStyle('S' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
								$cellIterator->next();
								$sheet2->getRowDimension($row)->setOutlineLevel(1);
								$sheet2->getRowDimension($row)->setVisible(false);
								if($colorValue/2 != floor($colorValue/2))
									$sheet2->getStyle('A' . $row . ':S' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('DBE5F1');
								else
									$sheet2->getStyle('A' . $row . ':S' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('F2F2F2');
								$rowIterator->next();
								$cellIterator = $rowIterator->current()->getCellIterator();
							}
							if($projectCharterBudget->resourceType == 'TRV')
							{
								$travel_Q1 = $projectCharterBudget->budgetQ1;
								$travel_Q2 = $projectCharterBudget->budgetQ2;
								$travel_Q3 = $projectCharterBudget->budgetQ3;
								$travel_Q4 = $projectCharterBudget->budgetQ4;
							}
							if($projectCharterBudget->resourceType == 'MAT')
							{
								$material_Q1 = $projectCharterBudget->budgetQ1;
								$material_Q2 = $projectCharterBudget->budgetQ2;
								$material_Q3 = $projectCharterBudget->budgetQ3;
								$material_Q4 = $projectCharterBudget->budgetQ4;
							}
						}
					}
					// Travel
					$row = $cellIterator->current()->getRow();
					$cellIterator->current()->setValue($charter->name);
					$cellIterator->next();
					$cellIterator->current()->setValue('Travel');
					$cellIterator->next();
					$cellIterator->next();
					$cellIterator->current()->setValue($this->context->customerRepository->find($charter->customerID)->name);
					$cellIterator->next();
					$cellIterator->current()->setValue($this->context->responsibilityRepository->find($charter->responsibilityID)->name);
					$cellIterator->next();
					$cellIterator->current()->setValue($charter->status);
					$cellIterator->next();
					$cellIterator->current()->setValue(round($travel_Q1 * (1 - $charter->CostShare)));
					$sheet2->getStyle('G' . $row)->applyFromArray($borderMediumLeft);
					$cellIterator->next();
					$cellIterator->current()->setValue(round($travel_Q2 * (1 - $charter->CostShare)));
					$cellIterator->next();
					$cellIterator->current()->setValue(round($travel_Q3 * (1 - $charter->CostShare)));
					$cellIterator->next();
					$cellIterator->current()->setValue(round($travel_Q4 * (1 - $charter->CostShare)));
					$sheet2->getStyle('J' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(G" . $row . ":J" . $row . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue("USD");
					$sheet2->getStyle('L' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
					$sheet2->getStyle('L' . $row)->applyFromArray($borderThinRight);
					$cellIterator->next();
					$sheet2->getStyle('A' . $row . ':' . 'S' . $row)->applyFromArray($borderThinTop);
					$sheet2->getRowDimension($row)->setOutlineLevel(1);
					$sheet2->getRowDimension($row)->setVisible(false);
					if($colorValue/2 != floor($colorValue/2))
						$sheet2->getStyle('A' . $row . ':S' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('DBE5F1');
					else
						$sheet2->getStyle('A' . $row . ':S' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('F2F2F2');
					$rowIterator->next();
					$cellIterator = $rowIterator->current()->getCellIterator();
					// Material
					$row = $cellIterator->current()->getRow();
					$cellIterator->current()->setValue($charter->name);
					$cellIterator->next();
					$cellIterator->current()->setValue('Material');
					$cellIterator->next();
					$cellIterator->next();
					$cellIterator->current()->setValue($this->context->customerRepository->find($charter->customerID)->name);
					$cellIterator->next();
					$cellIterator->current()->setValue($this->context->responsibilityRepository->find($charter->responsibilityID)->name);
					$cellIterator->next();
					$cellIterator->current()->setValue($charter->status);
					$cellIterator->next();
					$cellIterator->current()->setValue(round($material_Q1 * (1 - $charter->CostShare)));
					$sheet2->getStyle('G' . $row)->applyFromArray($borderMediumLeft);
					$cellIterator->next();
					$cellIterator->current()->setValue(round($material_Q2 * (1 - $charter->CostShare)));
					$cellIterator->next();
					$cellIterator->current()->setValue(round($material_Q3 * (1 - $charter->CostShare)));
					$cellIterator->next();
					$cellIterator->current()->setValue(round($material_Q4 * (1 - $charter->CostShare)));
					$sheet2->getStyle('J' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(G" . $row . ":J" . $row . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue("USD");
					$sheet2->getStyle('L' . $row)->applyFromArray($borderThinRight);
					$sheet2->getStyle('L' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
					$cellIterator->next();
					$sheet2->getRowDimension($row)->setOutlineLevel(1);
					$sheet2->getRowDimension($row)->setVisible(false);
					if($colorValue/2 != floor($colorValue/2))
						$sheet2->getStyle('A' . $row . ':S' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('DBE5F1');
					else
						$sheet2->getStyle('A' . $row . ':S' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('F2F2F2');
					$rowIterator->next();
					$cellIterator = $rowIterator->current()->getCellIterator();
					// Subcontracting
					foreach($projectCharterBudgets as $projectCharterBudget)
					{
						foreach($SUBs as $sub)
						{
							if($projectCharterBudget->subcontractor == $sub->ID AND $projectCharterBudget->resourceType == 'SUB')
							{
								$row = $cellIterator->current()->getRow();
								$finalSUMRows['last'] = $row;
								$cellIterator->current()->setValue($charter->name);
								$cellIterator->next();
								$cellIterator->current()->setValue('Subcontracting - ' . $sub->short);
								$cellIterator->next();
								$cellIterator->next();
								$cellIterator->current()->setValue($this->context->customerRepository->find($charter->customerID)->name);
								$cellIterator->next();
								$cellIterator->current()->setValue($this->context->responsibilityRepository->find($charter->responsibilityID)->name);
								$cellIterator->next();
								$cellIterator->current()->setValue($charter->status);
								$cellIterator->next();
								$cellIterator->current()->setValue(round($projectCharterBudget->budgetQ1 * (1 - $charter->CostShare)));
								$sheet2->getStyle('G' . $row)->applyFromArray($borderMediumLeft);
								$cellIterator->next();
								$cellIterator->current()->setValue(round($projectCharterBudget->budgetQ2 * (1 - $charter->CostShare)));
								$cellIterator->next();
								$cellIterator->current()->setValue(round($projectCharterBudget->budgetQ3 * (1 - $charter->CostShare)));
								$cellIterator->next();
								$cellIterator->current()->setValue(round($projectCharterBudget->budgetQ4 * (1 - $charter->CostShare)));
								$sheet2->getStyle('J' . $row)->applyFromArray($borderMediumRight);
								$cellIterator->next();
								$cellIterator->current()->setValue("=SUM(G" . $row . ":J" . $row . ")");
								$cellIterator->next();
								$cellIterator->current()->setValue("USD");
								$sheet2->getStyle('L' . $row)->applyFromArray($borderThinRight);
								$sheet2->getStyle('L' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
								$cellIterator->next();
								$sheet2->getRowDimension($row)->setOutlineLevel(1);
								$sheet2->getRowDimension($row)->setVisible(false);
								if($colorValue/2 != floor($colorValue/2))
									$sheet2->getStyle('A' . $row . ':S' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('DBE5F1');
								else
									$sheet2->getStyle('A' . $row . ':S' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('F2F2F2');
								$rowIterator->next();                
								$cellIterator = $rowIterator->current()->getCellIterator();
							}
						}
					}
					// Total
					$finalSUMRows['last'] = $totalCharterSUMLastRow = $row;
					$row = $cellIterator->current()->getRow();
					$cellIterator->current()->setValue($charter->name);
					$cellIterator->next();
					$cellIterator->current()->setValue('(Total)');
					$cellIterator->next();
					$cellIterator->next();
					$cellIterator->current()->setValue($this->context->customerRepository->find($charter->customerID)->name);
					$cellIterator->next();
					$cellIterator->current()->setValue($this->context->responsibilityRepository->find($charter->responsibilityID)->name);
					$cellIterator->next();
					$cellIterator->current()->setValue($charter->status);
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(G" . $totalCharterSUMFirstRow . ":G" . $totalCharterSUMLastRow . ")");
					$sheet2->getStyle('G' . $row)->applyFromArray($borderMediumLeft);
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(H" . $totalCharterSUMFirstRow . ":H" . $totalCharterSUMLastRow . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(I" . $totalCharterSUMFirstRow . ":I" . $totalCharterSUMLastRow . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(J" . $totalCharterSUMFirstRow . ":J" . $totalCharterSUMLastRow . ")");
					$sheet2->getStyle('J' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(G" . $row . ":J" . $row . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue("USD");
					$sheet2->getStyle('L' . $row)->applyFromArray($borderThinRight);
					$sheet2->getStyle('L' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
					$cellIterator->next();
					$cellIterator->current()->setValue($charter->CostShare);
					$sheet2->getStyle($cellIterator->current()->getColumn() . $cellIterator->current()->getRow())->getNumberFormat()->setFormatCode('##0%');
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(N" . $totalCharterSUMFirstRow . ":N" . $totalCharterSUMLastRow . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(O" . $totalCharterSUMFirstRow . ":O" . $totalCharterSUMLastRow . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(P" . $totalCharterSUMFirstRow . ":P" . $totalCharterSUMLastRow . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(Q" . $totalCharterSUMFirstRow . ":Q" . $totalCharterSUMLastRow . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(N" . $row . ":Q" . $row . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue("hrs");
					$sheet2->getStyle('S' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
					//$sheet2->getStyle('A' . $row . ':R' . $row)->getFont()->setBold(true);
					$sheet2->getStyle('A' . $row . ':' . 'S' . $row)->applyFromArray($borderMediumBottom);
					if($colorValue/2 != floor($colorValue/2))
						$sheet2->getStyle('A' . $row . ':S' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('B8CCE4');
					else
						$sheet2->getStyle('A' . $row . ':S' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('D8D8D8');
					$rowIterator->next();
					$cellIterator = $rowIterator->current()->getCellIterator();
					if($finalSUMRows['first'] != 0)
					{
						$arrayG[] = 'G' . $finalSUMRows['first'] . ':G' . $finalSUMRows['last'];
						$arrayH[] = 'H' . $finalSUMRows['first'] . ':H' . $finalSUMRows['last'];
						$arrayI[] = 'I' . $finalSUMRows['first'] . ':I' . $finalSUMRows['last'];
						$arrayM[] = 'J' . $finalSUMRows['first'] . ':J' . $finalSUMRows['last'];
						$arrayN[] = 'N' . $finalSUMRows['first'] . ':N' . $finalSUMRows['last'];
						$arrayO[] = 'O' . $finalSUMRows['first'] . ':O' . $finalSUMRows['last'];
						$arrayP[] = 'P' . $finalSUMRows['first'] . ':P' . $finalSUMRows['last'];
						$arrayF[] = 'Q' . $finalSUMRows['first'] . ':Q' . $finalSUMRows['last'];
					}
					else
					{
						$arrayG[] = 'G' . ($finalSUMRows['last'] - 3) . ':G' . $finalSUMRows['last'];
						$arrayH[] = 'H' . ($finalSUMRows['last'] - 3) . ':H' . $finalSUMRows['last'];
						$arrayI[] = 'I' . ($finalSUMRows['last'] - 3) . ':I' . $finalSUMRows['last'];
						$arrayM[] = 'J' . ($finalSUMRows['last'] - 3) . ':J' . $finalSUMRows['last'];
						$arrayN[] = 'N' . ($finalSUMRows['last'] - 3) . ':N' . $finalSUMRows['last'];
						$arrayO[] = 'O' . ($finalSUMRows['last'] - 3) . ':O' . $finalSUMRows['last'];
						$arrayP[] = 'P' . ($finalSUMRows['last'] - 3) . ':P' . $finalSUMRows['last'];
						$arrayF[] = 'Q' . ($finalSUMRows['last'] - 3) . ':Q' . $finalSUMRows['last'];
					}
					$finalSUMRows['first'] = 0;
					$finalSUMRows['last'] = 0;
				}
				$colorValue++;
			}
        }
        $rowIterator->next();
        $cellIterator = $rowIterator->current()->getCellIterator();
        //final total sum
        if($arrayF != null)
        {
            $columnF = join(',', $arrayF);
            $columnG = join(',', $arrayG);
            $columnH = join(',', $arrayH);
            $columnI = join(',', $arrayI);
			$columnM = join(',', $arrayM);
			$columnN = join(',', $arrayN);
			$columnO = join(',', $arrayO);
			$columnP = join(',', $arrayP);
            $row = $cellIterator->current()->getRow();
            $cellIterator->current()->setValue('Projects total');
            $cellIterator->next();
			$cellIterator->next();
            $cellIterator->next();
            $cellIterator->next();
            $cellIterator->next();
            $cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnG . ')');
            $cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnH . ')');
            $cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnI . ')');
			$cellIterator->next();
			$cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnM . ')');
            $cellIterator->next();
            $cellIterator->current()->setValue("=SUM(G" . $row . ":J" . $row . ")");
            $cellIterator->next();
            $cellIterator->current()->setValue("USD");
			$cellIterator->next();
			$cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnN . ')');
            $cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnO . ')');
            $cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnP . ')');
            $cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnF . ')');
            $cellIterator->next();
            $cellIterator->current()->setValue("=SUM(N" . $row . ":Q" . $row . ")");
			$cellIterator->next();
            $cellIterator->current()->setValue("hrs");
			$sheet2->getStyle('S' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
            $sheet2->getStyle('L' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
            $cellIterator->next();
            $sheet2->getStyle('A' . $row . ':S' . $row)->getFont()->setBold(true);
            $rowIterator->next();
            $cellIterator = $rowIterator->current()->getCellIterator();
        }
        
        

        // Third sheet of excel file
        // Data preparation
        $OrgUnitTechGroups = array();
        $allTechGroups = $this->context->organizationUnitRepository->findAllOrgUnitByType(OrganizationUnit::ORG_UNIT_TYPE_TG);
        foreach ($allTechGroups as $techGroup)
		if (preg_match('#^' . $orgUnit->Path . '#', $techGroup->Path))
		{
			$OrgUnitTechGroups[$techGroup->ID]['values'] = $this->context->projectCharterBudgetRepository->findProjectCharterBudgetHRSByOrgUnitId($techGroup->ID);
			$OrgUnitTechGroups[$techGroup->ID]['avaiableHours'] = 0;
		}
		$clusArray = array();
		$clusArray = $this->sortTechGroupToClusters($OrgUnitTechGroups);

        $sheet3 = $objPHPExcel->createSheet(3);
		$sheet3->getTabColor()->setRGB('75923C');
        $sheet3->setTitle("Owned resources");
        $rowIterator = $sheet3->getRowIterator();
        $cellIterator = $rowIterator->current()->getCellIterator();

        //Format setting
        $sheet3->getStyle('A1')->getFont()->setBold(true);
        $sheet3->getStyle('A3:H3')->getFont()->setBold(true);
        $sheet3->getStyle('A3:H3')->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
        $sheet3->getColumnDimension('A')->setWidth(40);
		$sheet3->getColumnDimension('B')->setWidth(30);

        // Header - Owned 
        $cellIterator->current()->setValue("Project Charters for " . OrganizationUnit::getFullTypeName($orgUnit->Type) . ": " . $orgUnit->Name);
        $cellIterator->next();
        $rowIterator->next();
        $cellIterator = $rowIterator->current()->getCellIterator();
        $cellIterator->current()->setValue("Resources belonging to the selected organization unit required by projects of selected organization unit.");
        $rowIterator->next();
        $cellIterator = $rowIterator->current()->getCellIterator();
        $cellIterator->current()->setValue("Owned");
        $cellIterator->next();
        $cellIterator->current()->setValue("Cluster");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q1");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q2");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q3");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q4");
        $cellIterator->next();
        $cellIterator->current()->setValue("Total");
        $cellIterator->next();
        $cellIterator->current()->setValue("Unit");
        $cellIterator->next();
        $row = $cellIterator->current()->getRow();
        $sheet3->getStyle('A' . $row . ':' . 'H' . $row)->applyFromArray($borderMediumBottom);
        $rowIterator->next();
        $cellIterator = $rowIterator->current()->getCellIterator();

        // Data export
        $colorValue = 1;
        $finalSUMRowsTotal = array();
        $finalSUMRowsYield = array();
		$OrgUnitTechGroupsFinalSum = array();
        $arrayYieldSum = $arrayYieldQ1Sum = $arrayYieldQ2Sum = $arrayYieldQ3Sum = $arrayYieldQ4Sum = array();
        $row = $cellIterator->current()->getRow();
        $firstRowForGeneralCollapse = $row;
        $rowForProjectCharterCollapse = $subtotalColumnC = $subtotalColumnD = $subtotalColumnE = $subtotalColumnF = array();
		foreach($clusArray as $clus_ID => $OrgUnitTechGroup)
		{
			$worableHours = null;
			$worableHours = $this->getWorkableHours($clus_ID, $values['Year']);
			foreach($OrgUnitTechGroup as $TG_ID => $TG)
			{
				if($TG['values'] != null)
				{
					$totalFirstRowSum = 0;
					foreach($TG['values'] as $budget)
					{
						$currentPath = $this->context->organizationUnitRepository->find($this->context->personRepository->find($this->context->projectCharterRepository->find($budget->projectCharterID)->lineManager)->organizationUnitID)->path;
						$selectedPath = $orgUnit->Path;
						if(strlen($currentPath) < strlen($selectedPath))
						{
							$selectedPath = $currentPath;
							$currentPath = $orgUnit->Path;
						}
						if($this->context->projectCharterRepository->find($budget->projectCharterID)->year == $values['Year'] && $this->context->projectCharterRepository->find($budget->projectCharterID)->status != ProjectCharter::PROJECT_CHARTER_STATUS_CANCELLED)
							if(strpos($currentPath, $selectedPath) === 0)
							{
								$row = $cellIterator->current()->getRow();
								if($totalFirstRowSum == 0)
									$totalFirstRowSum = $row;
								$rowForProjectCharterCollapse[$budget->projectCharterID][] = $row;
								$cellIterator->current()->setValue($this->context->projectCharterRepository->find($budget->projectCharterID)->name);
								$sheet3->getStyle('B' . $row)->applyFromArray($borderMediumRight);
								$cellIterator->next();
								$LM_OrgUnit = $this->context->organizationUnitRepository->findByLeader($this->context->projectCharterRepository->find($budget->ProjectCharterID)->LineManager);
								if($LM_OrgUnit)
									$cellIterator->current()->setValue(current($LM_OrgUnit)->Name);
								else
									$cellIterator->current()->setValue('NOT FOUND');
								$cellIterator->next();
								$cellIterator->current()->setValue(round($budget->budgetQ1));
								$cellIterator->next();
								$cellIterator->current()->setValue(round($budget->budgetQ2));
								$cellIterator->next();
								$cellIterator->current()->setValue(round($budget->budgetQ3));
								$cellIterator->next();
								$cellIterator->current()->setValue(round($budget->budgetQ4));
								$sheet3->getStyle('F' . $row)->applyFromArray($borderMediumRight);
								$cellIterator->next();
								$cellIterator->current()->setValue("=SUM(C" . $row . ":F" . $row . ")");
								$cellIterator->next();
								$cellIterator->current()->setValue('hrs');
								$sheet3->getStyle('H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
								if($colorValue/2 != floor($colorValue/2))
									$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('DBE5F1');
								else
									$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('F2F2F2');
								$rowIterator->next();
								$cellIterator = $rowIterator->current()->getCellIterator();
							}
					}
					// Total
					$totalLastRowSum = $row = $cellIterator->current()->getRow();
					$OrgUnitTechGroupsFinalSum[$TG_ID]['owned']['row'] = $row;
					$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($TG_ID)->name . ' - total');
					$sheet3->getStyle('B' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					if($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($TG_ID)->Parent_ID)->Path == 12)
						$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($TG_ID)->Parent_ID)->Name);
					else
						$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($TG_ID)->Name);
					$cellIterator->next();
					if($totalFirstRowSum == 0)
						$cellIterator->current()->setValue("0");
					else
					{
						$finalSUMRowsTotal[] = $row;
						$OrgUnitTechGroupsFinalSum[$TG_ID]['owned']['C'] = "C" . $totalFirstRowSum . ":C" . ($totalLastRowSum-1);
						$subtotalColumnC[] = "C" . $totalFirstRowSum . ":C" . ($totalLastRowSum-1);
						$cellIterator->current()->setValue("=SUBTOTAL(9,C" . $totalFirstRowSum . ":C" . ($totalLastRowSum-1) . ")");
					}
					$cellIterator->next();
					if($totalFirstRowSum == 0)
						$cellIterator->current()->setValue("0");
					else
					{
						$OrgUnitTechGroupsFinalSum[$TG_ID]['owned']['D'] = "D" . $totalFirstRowSum . ":D" . ($totalLastRowSum-1);
						$subtotalColumnD[] = "D" . $totalFirstRowSum . ":D" . ($totalLastRowSum-1);
						$cellIterator->current()->setValue("=SUBTOTAL(9,D" . $totalFirstRowSum . ":D" . ($totalLastRowSum-1) . ")");
					}
					$cellIterator->next();
					if($totalFirstRowSum == 0)
						$cellIterator->current()->setValue("0");
					else
					{
						$OrgUnitTechGroupsFinalSum[$TG_ID]['owned']['E'] = "E" . $totalFirstRowSum . ":E" . ($totalLastRowSum-1);
						$subtotalColumnE[] = "E" . $totalFirstRowSum . ":E" . ($totalLastRowSum-1);
						$cellIterator->current()->setValue("=SUBTOTAL(9,E" . $totalFirstRowSum . ":E" . ($totalLastRowSum-1) . ")");
					}
					$cellIterator->next();
					if($totalFirstRowSum == 0)
						$cellIterator->current()->setValue("0");
					else
					{
						$OrgUnitTechGroupsFinalSum[$TG_ID]['owned']['F'] = "F" . $totalFirstRowSum . ":F" . ($totalLastRowSum-1);
						$subtotalColumnF[] = "F" . $totalFirstRowSum . ":F" . ($totalLastRowSum-1);
						$cellIterator->current()->setValue("=SUBTOTAL(9,F" . $totalFirstRowSum . ":F" . ($totalLastRowSum-1) . ")");
					}
					$sheet3->getStyle('F' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(C" . $row . ":F" . $row . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue('hrs');
					$sheet3->getStyle('H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
					//$sheet3->getStyle('A' . $row . ':G' . $row)->getFont()->setBold(true);
					if($colorValue/2 != floor($colorValue/2))
						$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('B8CCE4');
					else
						$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('D8D8D8');
					$rowIterator->next();
					
					// WH hours
					$arrayYieldSum[] = $worableHours[$TG_ID]['arrayYieldSum'];
					$arrayYieldQ1Sum[] = $worableHours[$TG_ID]['arrayYieldQ1Sum'];
					$arrayYieldQ2Sum[] = $worableHours[$TG_ID]['arrayYieldQ2Sum'];
					$arrayYieldQ3Sum[] = $worableHours[$TG_ID]['arrayYieldQ3Sum'];
					$arrayYieldQ4Sum[] = $worableHours[$TG_ID]['arrayYieldQ4Sum'];
					$cellIterator = $rowIterator->current()->getCellIterator();
					$row = $cellIterator->current()->getRow();
					$finalSUMRowsYield[] = $row;
					$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($TG_ID)->name . ' - group coverage');
					$sheet3->getStyle('B' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					if($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($TG_ID)->Parent_ID)->Path == 12)
						$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($TG_ID)->Parent_ID)->Name);
					else
						$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($TG_ID)->Name);
					$cellIterator->next();
					if($worableHours[$TG_ID]['arrayYieldQ1Sum'] == 0)
						$cellIterator->current()->setValue('0');
					else
					{
		//                $cellIterator->current()->setValue('=(B'. ($row-1) . '/' . $q1 . ')*100');
						$cellIterator->current()->setValue('=(C'. ($row-1) . '/' . $worableHours[$TG_ID]['arrayYieldQ1Sum'] . ')');
						$sheet3->getStyle("C" . $row)->getNumberFormat()->setFormatCode('##0%');
					}
					$cellIterator->next();
					if($worableHours[$TG_ID]['arrayYieldQ2Sum'] == 0)
						$cellIterator->current()->setValue('0');
					else
					{
		//                $cellIterator->current()->setValue('=(C'. ($row-1) . '/' . $q2 . ')*100');
						$cellIterator->current()->setValue('=(D'. ($row-1) . '/' . $worableHours[$TG_ID]['arrayYieldQ2Sum'] . ')');
						$sheet3->getStyle("D" . $row)->getNumberFormat()->setFormatCode('##0%');
					}
					$cellIterator->next();
					if($worableHours[$TG_ID]['arrayYieldQ3Sum'] == 0)
						$cellIterator->current()->setValue('0');
					else
					{
		//                $cellIterator->current()->setValue('=(D'. ($row-1) . '/' . $q3 . ')*100');
						$cellIterator->current()->setValue('=(E'. ($row-1) . '/' . $worableHours[$TG_ID]['arrayYieldQ3Sum'] . ')');
						$sheet3->getStyle("E" . $row)->getNumberFormat()->setFormatCode('##0%');
					}
					$cellIterator->next();
					if($worableHours[$TG_ID]['arrayYieldQ4Sum'] == 0)
						$cellIterator->current()->setValue('0');
					else
					{
		//                $cellIterator->current()->setValue('=(E'. ($row-1) . '/' . $q4 . ')*100');
						$cellIterator->current()->setValue('=(F'. ($row-1) . '/' . $worableHours[$TG_ID]['arrayYieldQ4Sum'] . ')');
						$sheet3->getStyle("F" . $row)->getNumberFormat()->setFormatCode('##0%');
					}
					$sheet3->getStyle('F' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					if($worableHours[$TG_ID]['arrayYieldSum'] == 0)
						$cellIterator->current()->setValue('0');
					else
					{
						$cellIterator->current()->setValue("=(G" . ($row-1) . "/" . $worableHours[$TG_ID]['arrayYieldSum'] . ')');
					}
					$sheet3->getStyle("G" . $row)->getNumberFormat()->setFormatCode('##0%');
					$cellIterator->next();
	//                $cellIterator->current()->setValue('hrs');
					$sheet3->getStyle('H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
					$sheet3->getStyle('A' . $row . ':' . 'H' . $row)->applyFromArray($borderMediumBottom);
					//$sheet3->getStyle('A' . $row . ':G' . $row)->getFont()->setBold(true);
					if($colorValue/2 != floor($colorValue/2))
						$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('B8CCE4');
					else
						$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('D8D8D8');
					$cellIterator->next();
					$lastRowForGeneralCollapse = $row;
					$rowIterator->next();
					$cellIterator = $rowIterator->current()->getCellIterator();
					$colorValue++;
				}
				else
				{
					// Total
					$row = $cellIterator->current()->getRow();
					$OrgUnitTechGroupsFinalSum[$TG_ID]['owned']['row'] = $row;
					$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($TG_ID)->name . ' - total');
					$sheet3->getStyle('B' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					if($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($TG_ID)->Parent_ID)->Path == 12)
						$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($TG_ID)->Parent_ID)->Name);
					else
						$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($TG_ID)->Name);
					$cellIterator->next();
					$cellIterator->current()->setValue("0");
					$cellIterator->next();
					$cellIterator->current()->setValue("0");
					$cellIterator->next();
					$cellIterator->current()->setValue("0");
					$cellIterator->next();
					$cellIterator->current()->setValue("0");
					$sheet3->getStyle('F' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					$cellIterator->current()->setValue("0");
					$cellIterator->next();
					$cellIterator->current()->setValue('hrs');
					$sheet3->getStyle('H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
					if($colorValue/2 != floor($colorValue/2))
						$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('B8CCE4');
					else
						$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('D8D8D8');
					$rowIterator->next();

					// Yield
					$cellIterator = $rowIterator->current()->getCellIterator();
					$row = $cellIterator->current()->getRow();
					$finalSUMRowsYield[] = $row;
					$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($TG_ID)->name . ' - group coverage');
					$sheet3->getStyle('B' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					if($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($TG_ID)->Parent_ID)->Path == 12)
						$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($TG_ID)->Parent_ID)->Name);
					else
						$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($TG_ID)->Name);
					$cellIterator->next();
					$cellIterator->current()->setValue('0');
					$cellIterator->next();
					$cellIterator->current()->setValue('0');
					$cellIterator->next();
					$cellIterator->current()->setValue('0');
					$cellIterator->next();
					$cellIterator->current()->setValue('0');
					$sheet3->getStyle('F' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					$cellIterator->current()->setValue('0');
					$sheet3->getStyle("G" . $row)->getNumberFormat()->setFormatCode('##0%');
					$cellIterator->next();
					$sheet3->getStyle('H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
					$sheet3->getStyle('A' . $row . ':' . 'H' . $row)->applyFromArray($borderMediumBottom);
					if($colorValue/2 != floor($colorValue/2))
						$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('B8CCE4');
					else
						$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('D8D8D8');
					$cellIterator->next();
					$lastRowForGeneralCollapse = $row;
					$rowIterator->next();
					$cellIterator = $rowIterator->current()->getCellIterator();
					$colorValue++;
				}
			}
		}
        for ($i = $firstRowForGeneralCollapse; $i <= $lastRowForGeneralCollapse; $i++)
        {
            $sheet3->getRowDimension($i)->setOutlineLevel(1);
            $sheet3->getRowDimension($i)->setVisible(false);
        }
        foreach ($rowForProjectCharterCollapse as $ProjectCharterRows)
            foreach ($ProjectCharterRows as $row)
            {
                $sheet3->getRowDimension($row)->setOutlineLevel(2);
                $sheet3->getRowDimension($row)->setVisible(false);
            }

        $columnOwnedC = '';
        $columnOwnedD = '';
        $columnOwnedE = '';
        $columnOwnedF = '';
        //final total sum
        if($finalSUMRowsTotal != null)
        {
            $columnOwnedC = join(',', $subtotalColumnC);
            $columnOwnedD = join(',', $subtotalColumnD);
            $columnOwnedE = join(',', $subtotalColumnE);
            $columnOwnedF = join(',', $subtotalColumnF);

            $ownedFinalTotal =  $row = $cellIterator->current()->getRow();
            $cellIterator->current()->setValue('Owned Total');
            $sheet3->getStyle('B' . $row)->applyFromArray($borderMediumRight);
            $cellIterator->next();
			$cellIterator->current()->setValue('-');
			$cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnOwnedC . ')');
            $cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnOwnedD . ')');
            $cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnOwnedE . ')');
            $cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnOwnedF . ')');
            $sheet3->getStyle('F' . $row)->applyFromArray($borderMediumRight);
            $cellIterator->next();
            $cellIterator->current()->setValue("=SUM(C" . $row . ":F" . $row . ")");
            $cellIterator->next();
            $cellIterator->current()->setValue("hrs");
            $sheet3->getStyle('H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
            $cellIterator->next();
            $sheet3->getStyle('A' . $row . ':H' . $row)->getFont()->setBold(true);
            $rowIterator->next();
            $cellIterator = $rowIterator->current()->getCellIterator();
        }
		else
		{
			$ownedFinalTotal = $row = $cellIterator->current()->getRow();
            $cellIterator->current()->setValue('Provided total');
            $sheet3->getStyle('B' . $row)->applyFromArray($borderMediumRight);
            $cellIterator->next();
			$cellIterator->current()->setValue('-');
			$cellIterator->next();
            $cellIterator->current()->setValue('0');
            $cellIterator->next();
            $cellIterator->current()->setValue('0');
            $cellIterator->next();
            $cellIterator->current()->setValue('0');
            $cellIterator->next();
            $cellIterator->current()->setValue('0');
            $sheet3->getStyle('F' . $row)->applyFromArray($borderMediumRight);
            $cellIterator->next();
            $cellIterator->current()->setValue("0");
            $cellIterator->next();
            $cellIterator->current()->setValue("hrs");
            $sheet3->getStyle('H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
            $cellIterator->next();
            $sheet3->getStyle('A' . $row . ':H' . $row)->getFont()->setBold(true);
            $rowIterator->next();
            $cellIterator = $rowIterator->current()->getCellIterator();
		}
		
        //final total yield sum
        if($finalSUMRowsYield != null)
        {
            $ownedFinalYield =  $row = $cellIterator->current()->getRow();
            $cellIterator->current()->setValue('Owned total group coverage');
            $sheet3->getStyle('B' . $row)->applyFromArray($borderMediumRight);
            $cellIterator->next();
			$cellIterator->current()->setValue('-');
			$cellIterator->next();
            $cellIterator->current()->setValue("=(C" . ($row-1) . "/" . array_sum($arrayYieldQ1Sum) . ')');
            $sheet3->getStyle("C" . $row)->getNumberFormat()->setFormatCode('##0%');
            $cellIterator->next();
            $cellIterator->current()->setValue("=(D" . ($row-1) . "/" . array_sum($arrayYieldQ2Sum) . ')');
            $sheet3->getStyle("D" . $row)->getNumberFormat()->setFormatCode('##0%');
            $cellIterator->next();
            $cellIterator->current()->setValue("=(E" . ($row-1) . "/" . array_sum($arrayYieldQ3Sum) . ')');
            $sheet3->getStyle("E" . $row)->getNumberFormat()->setFormatCode('##0%');
            $cellIterator->next();
            $cellIterator->current()->setValue("=(F" . ($row-1) . "/" . array_sum($arrayYieldQ4Sum) . ')');
            $sheet3->getStyle("F" . $row)->getNumberFormat()->setFormatCode('##0%');
            $sheet3->getStyle('F' . $row)->applyFromArray($borderMediumRight);
            $cellIterator->next();
            $cellIterator->current()->setValue("=(G" . ($row-1) . "/" . array_sum($arrayYieldSum) . ')');
            $sheet3->getStyle("G" . $row)->getNumberFormat()->setFormatCode('##0%');
            $cellIterator->next();
//            $cellIterator->current()->setValue("hrs");
            $sheet3->getStyle('H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
            $cellIterator->next();
            $sheet3->getStyle('A' . $row . ':H' . $row)->getFont()->setBold(true);
            $sheet3->getStyle('A' . $row . ':' . 'H' . $row)->applyFromArray($borderMediumBottom);
            $rowIterator->next();
            $rowIterator->next();
			$rowIterator->next();
            $cellIterator = $rowIterator->current()->getCellIterator();
        }
		
        // Header - Provided Support 
        $cellIterator->current()->setValue("Resources belonging to the selected organization unit as required in charters of other organization units.");
        $rowIterator->next();
        $cellIterator = $rowIterator->current()->getCellIterator();
        $cellIterator->current()->setValue("Support provided to others");
        $cellIterator->next();
        $cellIterator->current()->setValue("Cluster");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q1");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q2");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q3");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q4");
        $cellIterator->next();
        $cellIterator->current()->setValue("Total");
        $cellIterator->next();
        $cellIterator->current()->setValue("Unit");
        $cellIterator->next();
        $row = $supProvOthersStartRow = $cellIterator->current()->getRow();
        $sheet3->getStyle('A' . $row . ':' . 'H' . $row)->getFont()->setBold(true);
        $sheet3->getStyle('A' . $row . ':' . 'H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
        $sheet3->getStyle('A' . $row . ':' . 'H' . $row)->applyFromArray($borderMediumBottom);
        $rowIterator->next();
        $cellIterator = $rowIterator->current()->getCellIterator();

        // Data export
        $colorValue = 1;
        $finalSUMRowsTotal = array();
        $finalSUMRowsYield = array();
        $row = $cellIterator->current()->getRow();
        $firstRowForGeneralCollapse = $row;
        $rowForProjectCharterCollapse = $subtotalColumnC = $subtotalColumnD = $subtotalColumnE = $subtotalColumnF = array();
		foreach($clusArray as $clus_ID => $OrgUnitTechGroup)
		{
			$worableHours = null;
			$worableHours = $this->getWorkableHours($clus_ID, $values['Year']);
			foreach($OrgUnitTechGroup as $TG_ID => $TG)
			{
				if($TG['values'] != null)
				{
					$totalFirstRowSum = 0;
					foreach($TG['values'] as $budget)
					{
						$currentPath = $this->context->organizationUnitRepository->find($this->context->personRepository->find($this->context->projectCharterRepository->find($budget->projectCharterID)->lineManager)->organizationUnitID)->path;
						$selectedPath = $orgUnit->Path;
						if(strlen($currentPath) < strlen($selectedPath))
						{
							$selectedPath = $currentPath;
							$currentPath = $orgUnit->Path;
						}
						if($this->context->projectCharterRepository->find($budget->projectCharterID)->year == $values['Year'] && $this->context->projectCharterRepository->find($budget->projectCharterID)->status != ProjectCharter::PROJECT_CHARTER_STATUS_CANCELLED)
							if(!(strpos($currentPath, $selectedPath) === 0))
							{
								$row = $cellIterator->current()->getRow();
								if($totalFirstRowSum == 0)
									$totalFirstRowSum = $row;
								$rowForProjectCharterCollapse[$budget->projectCharterID][] = $row;
								$cellIterator->current()->setValue($this->context->projectCharterRepository->find($budget->projectCharterID)->name);
								$sheet3->getStyle('B' . $row)->applyFromArray($borderMediumRight);
								$cellIterator->next();
								$LM_OrgUnit = $this->context->organizationUnitRepository->findByLeader($this->context->projectCharterRepository->find($budget->ProjectCharterID)->LineManager);
								if($LM_OrgUnit)
									$cellIterator->current()->setValue(current($LM_OrgUnit)->Name);
								else
									$cellIterator->current()->setValue('NOT FOUND');
								$cellIterator->next();
								$cellIterator->current()->setValue(round($budget->budgetQ1));
								$cellIterator->next();
								$cellIterator->current()->setValue(round($budget->budgetQ2));
								$cellIterator->next();
								$cellIterator->current()->setValue(round($budget->budgetQ3));
								$cellIterator->next();
								$cellIterator->current()->setValue(round($budget->budgetQ4));
								$sheet3->getStyle('F' . $row)->applyFromArray($borderMediumRight);
								$cellIterator->next();
								$cellIterator->current()->setValue("=SUM(C" . $row . ":F" . $row . ")");
								$cellIterator->next();
								$cellIterator->current()->setValue('hrs');
								$sheet3->getStyle('H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
								if($colorValue/2 != floor($colorValue/2))
									$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('DBE5F1');
								else
									$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('F2F2F2');
								$rowIterator->next();
								$cellIterator = $rowIterator->current()->getCellIterator();
							}
					}

					// Total
					$totalLastRowSum = $row = $cellIterator->current()->getRow();
					$OrgUnitTechGroupsFinalSum[$TG_ID]['provided']['row'] = $row;
					$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($TG_ID)->name . ' - total');
					$sheet3->getStyle('B' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					if($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($TG_ID)->Parent_ID)->Path == 12)
						$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($TG_ID)->Parent_ID)->Name);
					else
						$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($TG_ID)->Name);
					$cellIterator->next();
					if($totalFirstRowSum == 0)
						$cellIterator->current()->setValue("0");
					else
					{
						$finalSUMRowsTotal[] = $row;
						$OrgUnitTechGroupsFinalSum[$TG_ID]['provided']['C'] = "C" . $totalFirstRowSum . ":C" . ($totalLastRowSum-1);
						$subtotalColumnC[] = "C" . $totalFirstRowSum . ":C" . ($totalLastRowSum-1);
						$cellIterator->current()->setValue("=SUBTOTAL(9,C" . $totalFirstRowSum . ":C" . ($totalLastRowSum-1) . ")");
					}
					$cellIterator->next();
					if($totalFirstRowSum == 0)
						$cellIterator->current()->setValue("0");
					else
					{
						$OrgUnitTechGroupsFinalSum[$TG_ID]['provided']['D'] = "D" . $totalFirstRowSum . ":D" . ($totalLastRowSum-1);
						$subtotalColumnD[] = "D" . $totalFirstRowSum . ":D" . ($totalLastRowSum-1);
						$cellIterator->current()->setValue("=SUBTOTAL(9,D" . $totalFirstRowSum . ":D" . ($totalLastRowSum-1) . ")");
					}
					$cellIterator->next();
					if($totalFirstRowSum == 0)
						$cellIterator->current()->setValue("0");
					else
					{
						$OrgUnitTechGroupsFinalSum[$TG_ID]['provided']['E'] = "E" . $totalFirstRowSum . ":E" . ($totalLastRowSum-1);
						$subtotalColumnE[] = "E" . $totalFirstRowSum . ":E" . ($totalLastRowSum-1);
						$cellIterator->current()->setValue("=SUBTOTAL(9,E" . $totalFirstRowSum . ":E" . ($totalLastRowSum-1) . ")");
					}
					$cellIterator->next();
					if($totalFirstRowSum == 0)
						$cellIterator->current()->setValue("0");
					else
					{
						$OrgUnitTechGroupsFinalSum[$TG_ID]['provided']['F'] = "F" . $totalFirstRowSum . ":F" . ($totalLastRowSum-1);
						$subtotalColumnF[] = "F" . $totalFirstRowSum . ":F" . ($totalLastRowSum-1);
						$cellIterator->current()->setValue("=SUBTOTAL(9,F" . $totalFirstRowSum . ":F" . ($totalLastRowSum-1) . ")");
					}
					$sheet3->getStyle('F' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					$cellIterator->current()->setValue("=SUM(C" . $row . ":F" . $row . ")");
					$cellIterator->next();
					$cellIterator->current()->setValue('hrs');
					$sheet3->getStyle('H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
					//$sheet3->getStyle('A' . $row . ':G' . $row)->getFont()->setBold(true);
					if($colorValue/2 != floor($colorValue/2))
						$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('B8CCE4');
					else
						$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('D8D8D8');
					$rowIterator->next();

					//Yield
					$cellIterator = $rowIterator->current()->getCellIterator();
					$row = $cellIterator->current()->getRow();
					$finalSUMRowsYield[] = $row;
					$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($TG_ID)->name . ' - group coverage');
					$sheet3->getStyle('B' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					if($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($TG_ID)->Parent_ID)->Path == 12)
						$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($TG_ID)->Parent_ID)->Name);
					else
						$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($TG_ID)->Name);
					$cellIterator->next();
					if($worableHours[$TG_ID]['arrayYieldQ1Sum'] == 0)
						$cellIterator->current()->setValue('0');
					else
					{
		//                $cellIterator->current()->setValue('=(B'. ($row-1) . '/' . $q1 . ')*100');
						$cellIterator->current()->setValue('=(C'. ($row-1) . '/' . $worableHours[$TG_ID]['arrayYieldQ1Sum'] . ')');
						$sheet3->getStyle("C" . $row)->getNumberFormat()->setFormatCode('##0%');
					}
					$cellIterator->next();
					if($worableHours[$TG_ID]['arrayYieldQ2Sum'] == 0)
						$cellIterator->current()->setValue('0');
					else
					{
		//                $cellIterator->current()->setValue('=(C'. ($row-1) . '/' . $q2 . ')*100');
						$cellIterator->current()->setValue('=(D'. ($row-1) . '/' . $worableHours[$TG_ID]['arrayYieldQ2Sum'] . ')');
						$sheet3->getStyle("D" . $row)->getNumberFormat()->setFormatCode('##0%');
					}
					$cellIterator->next();
					if($worableHours[$TG_ID]['arrayYieldQ3Sum'] == 0)
						$cellIterator->current()->setValue('0');
					else
					{
		//                $cellIterator->current()->setValue('=(D'. ($row-1) . '/' . $q3 . ')*100');
						$cellIterator->current()->setValue('=(E'. ($row-1) . '/' . $worableHours[$TG_ID]['arrayYieldQ3Sum'] . ')');
						$sheet3->getStyle("E" . $row)->getNumberFormat()->setFormatCode('##0%');
					}
					$cellIterator->next();
					if($worableHours[$TG_ID]['arrayYieldQ4Sum'] == 0)
						$cellIterator->current()->setValue('0');
					else
					{
		//                $cellIterator->current()->setValue('=(E'. ($row-1) . '/' . $q4 . ')*100');
						$cellIterator->current()->setValue('=(F'. ($row-1) . '/' . $worableHours[$TG_ID]['arrayYieldQ4Sum'] . ')');
						$sheet3->getStyle("F" . $row)->getNumberFormat()->setFormatCode('##0%');
					}
					$sheet3->getStyle('F' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					if($worableHours[$TG_ID]['arrayYieldSum'] == 0)
						$cellIterator->current()->setValue('0');
					else
						$cellIterator->current()->setValue("=(G" . ($row-1) . "/" . $worableHours[$TG_ID]['arrayYieldSum'] . ')');
					$sheet3->getStyle("G" . $row)->getNumberFormat()->setFormatCode('##0%');
					$cellIterator->next();
	//                $cellIterator->current()->setValue('hrs');
					$sheet3->getStyle('H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
					$sheet3->getStyle('A' . $row . ':' . 'H' . $row)->applyFromArray($borderMediumBottom);
					//$sheet3->getStyle('A' . $row . ':G' . $row)->getFont()->setBold(true);
					if($colorValue/2 != floor($colorValue/2))
						$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('B8CCE4');
					else
						$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('D8D8D8');
					$cellIterator->next();
					$lastRowForGeneralCollapse = $row;
					$rowIterator->next();
					$cellIterator = $rowIterator->current()->getCellIterator();
					$colorValue++;
				}
				else
				{
					// Total
					$row = $cellIterator->current()->getRow();
					$OrgUnitTechGroupsFinalSum[$TG_ID]['provided']['row'] = $row;
					$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($TG_ID)->name . ' - total');
					$sheet3->getStyle('B' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					if($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($TG_ID)->Parent_ID)->Path == 12)
						$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($TG_ID)->Parent_ID)->Name);
					else
						$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($TG_ID)->Name);
					$cellIterator->next();
					$cellIterator->current()->setValue("0");
					$cellIterator->next();
					$cellIterator->current()->setValue("0");
					$cellIterator->next();
					$cellIterator->current()->setValue("0");
					$cellIterator->next();
					$cellIterator->current()->setValue("0");
					$sheet3->getStyle('F' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					$cellIterator->current()->setValue("0");
					$cellIterator->next();
					$cellIterator->current()->setValue('hrs');
					$sheet3->getStyle('H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
					if($colorValue/2 != floor($colorValue/2))
						$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('B8CCE4');
					else
						$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('D8D8D8');
					$rowIterator->next();

					// Yield
					$cellIterator = $rowIterator->current()->getCellIterator();
					$row = $cellIterator->current()->getRow();
					$finalSUMRowsYield[] = $row;
					$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($TG_ID)->name . ' - group coverage');
					$sheet3->getStyle('B' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					if($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($TG_ID)->Parent_ID)->Path == 12)
						$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($TG_ID)->Parent_ID)->Name);
					else
						$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($TG_ID)->Name);
					$cellIterator->next();
					$cellIterator->current()->setValue('0');
					$cellIterator->next();
					$cellIterator->current()->setValue('0');
					$cellIterator->next();
					$cellIterator->current()->setValue('0');
					$cellIterator->next();
					$cellIterator->current()->setValue('0');
					$sheet3->getStyle('F' . $row)->applyFromArray($borderMediumRight);
					$cellIterator->next();
					$cellIterator->current()->setValue('0');
					$sheet3->getStyle("G" . $row)->getNumberFormat()->setFormatCode('##0%');
					$cellIterator->next();
					$sheet3->getStyle('H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
					$sheet3->getStyle('A' . $row . ':' . 'H' . $row)->applyFromArray($borderMediumBottom);
					if($colorValue/2 != floor($colorValue/2))
						$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('B8CCE4');
					else
						$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('D8D8D8');
					$cellIterator->next();
					$lastRowForGeneralCollapse = $row;
					$rowIterator->next();
					$cellIterator = $rowIterator->current()->getCellIterator();
					$colorValue++;
				}
			}
		}
        for ($i = $firstRowForGeneralCollapse; $i <= $lastRowForGeneralCollapse; $i++)
        {
            $sheet3->getRowDimension($i)->setOutlineLevel(1);
            $sheet3->getRowDimension($i)->setVisible(false);
        }
        foreach ($rowForProjectCharterCollapse as $ProjectCharterRows)
            foreach ($ProjectCharterRows as $row)
            {
                $sheet3->getRowDimension($row)->setOutlineLevel(2);
                $sheet3->getRowDimension($row)->setVisible(false);
            }

        $columnProvidedC = '';
        $columnProvidedD = '';
        $columnProvidedE = '';
        $columnProvidedF = '';
        //final total sum
        if($finalSUMRowsTotal != null)
        {
            $columnProvidedC = join(',', $subtotalColumnC);
            $columnProvidedD = join(',', $subtotalColumnD);
            $columnProvidedE = join(',', $subtotalColumnE);
            $columnProvidedF = join(',', $subtotalColumnF);

			$row = $providedFinalTotal = $cellIterator->current()->getRow();
            $cellIterator->current()->setValue('Provided total');
            $sheet3->getStyle('B' . $row)->applyFromArray($borderMediumRight);
            $cellIterator->next();
			$cellIterator->current()->setValue('-');
			$cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnProvidedC . ')');
            $cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnProvidedD . ')');
            $cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnProvidedE . ')');
            $cellIterator->next();
            $cellIterator->current()->setValue('=SUBTOTAL(9,' . $columnProvidedF . ')');
            $sheet3->getStyle('F' . $row)->applyFromArray($borderMediumRight);
            $cellIterator->next();
            $cellIterator->current()->setValue("=SUM(C" . $row . ":F" . $row . ")");
            $cellIterator->next();
            $cellIterator->current()->setValue("hrs");
            $sheet3->getStyle('H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
            $cellIterator->next();
            $sheet3->getStyle('A' . $row . ':H' . $row)->getFont()->setBold(true);
            $rowIterator->next();
            $cellIterator = $rowIterator->current()->getCellIterator();
        }
		else
		{
			$row = $providedFinalTotal = $cellIterator->current()->getRow();
            $cellIterator->current()->setValue('Provided total');
            $sheet3->getStyle('B' . $row)->applyFromArray($borderMediumRight);
            $cellIterator->next();
			$cellIterator->current()->setValue('-');
			$cellIterator->next();
            $cellIterator->current()->setValue('0');
            $cellIterator->next();
            $cellIterator->current()->setValue('0');
            $cellIterator->next();
            $cellIterator->current()->setValue('0');
            $cellIterator->next();
            $cellIterator->current()->setValue('0');
            $sheet3->getStyle('F' . $row)->applyFromArray($borderMediumRight);
            $cellIterator->next();
            $cellIterator->current()->setValue("0");
            $cellIterator->next();
            $cellIterator->current()->setValue("hrs");
            $sheet3->getStyle('H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
            $cellIterator->next();
            $sheet3->getStyle('A' . $row . ':H' . $row)->getFont()->setBold(true);
            $rowIterator->next();
            $cellIterator = $rowIterator->current()->getCellIterator();
		}
        
        //final total yield
        if($finalSUMRowsYield != null)
        {
            $providedFinalYield = $row = $cellIterator->current()->getRow();
            $cellIterator->current()->setValue('Provided total group coverage');
            $sheet3->getStyle('B' . $row)->applyFromArray($borderMediumRight);
            $cellIterator->next();
			$cellIterator->current()->setValue('-');
			$cellIterator->next();
            $cellIterator->current()->setValue("=(C" . ($row-1) . "/" . array_sum($arrayYieldQ1Sum) . ')');
            $sheet3->getStyle("C" . $row)->getNumberFormat()->setFormatCode('##0%');
            $cellIterator->next();
            $cellIterator->current()->setValue("=(D" . ($row-1) . "/" . array_sum($arrayYieldQ2Sum) . ')');
            $sheet3->getStyle("D" . $row)->getNumberFormat()->setFormatCode('##0%');
            $cellIterator->next();
            $cellIterator->current()->setValue("=(E" . ($row-1) . "/" . array_sum($arrayYieldQ3Sum) . ')');
            $sheet3->getStyle("E" . $row)->getNumberFormat()->setFormatCode('##0%');
            $cellIterator->next();
            $cellIterator->current()->setValue("=(F" . ($row-1) . "/" . array_sum($arrayYieldQ4Sum) . ')');
            $sheet3->getStyle("F" . $row)->getNumberFormat()->setFormatCode('##0%');
            $sheet3->getStyle('F' . $row)->applyFromArray($borderMediumRight);
            $cellIterator->next();
            $cellIterator->current()->setValue("=(G" . ($row-1) . "/" . array_sum($arrayYieldSum) . ')');
            $sheet3->getStyle("G" . $row)->getNumberFormat()->setFormatCode('##0%');
            $cellIterator->next();
//            $cellIterator->current()->setValue("hrs");
            $sheet3->getStyle('H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
            $cellIterator->next();
            $sheet3->getStyle('A' . $row . ':H' . $row)->getFont()->setBold(true);
            $sheet3->getStyle('A' . $row . ':' . 'H' . $row)->applyFromArray($borderMediumBottom);
            $rowIterator->next();
            $rowIterator->next();
			$rowIterator->next();
            $cellIterator = $rowIterator->current()->getCellIterator();
        }
		
        // Final total from totals
		$cellIterator->current()->setValue('Total ATE demand for resources of the unit');
		$cellIterator->next();
        $cellIterator->current()->setValue("Cluster");
		$cellIterator->next();
        $cellIterator->current()->setValue("Q1");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q2");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q3");
        $cellIterator->next();
        $cellIterator->current()->setValue("Q4");
        $cellIterator->next();
        $cellIterator->current()->setValue("Total");
        $cellIterator->next();
        $cellIterator->current()->setValue("Unit");
		$row = $cellIterator->current()->getRow();
		$sheet3->getStyle('A' . $row . ':H' . $row)->getFont()->setBold(true);
		$sheet3->getStyle('A' . $row . ':' . 'H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
		$rowIterator->next();
		$cellIterator = $rowIterator->current()->getCellIterator();
		$colorValue = 1;
		foreach($OrgUnitTechGroupsFinalSum as $TG_ID => $TG)
		{
			$row = $cellIterator->current()->getRow();
            $sheet3->getRowDimension($row)->setOutlineLevel(1);
            $sheet3->getRowDimension($row)->setVisible(false);
			$sheet3->getStyle('A' . $row . ':H' . $row)->applyFromArray($borderMediumTop);
			$sheet3->getStyle('B' . $row)->applyFromArray($borderMediumRight);
			$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($TG_ID)->name);
			$cellIterator->next();
			if($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($TG_ID)->Parent_ID)->Path == 12)
				$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($TG_ID)->Parent_ID)->Name);
			else
				$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($TG_ID)->Name);
			$cellIterator->next();
			if(isset($TG['owned']['C']) && isset($TG['provided']['C']))
			{
				$finalSubtotalColumnC[] = "C" . $row . ":C" . $row;
				$cellIterator->current()->setValue('=SUBTOTAL(9,' . $TG['owned']['C'] . ',' . $TG['provided']['C'] . ')');
				$cellIterator->next();
				$finalSubtotalColumnD[] = "D" . $row . ":D" . $row;
				$cellIterator->current()->setValue('=SUBTOTAL(9,' . $TG['owned']['D'] . ',' . $TG['provided']['D'] . ')');
				$cellIterator->next();
				$finalSubtotalColumnE[] = "E" . $row . ":E" . $row;
				$cellIterator->current()->setValue('=SUBTOTAL(9,' . $TG['owned']['E'] . ',' . $TG['provided']['E'] . ')');
				$cellIterator->next();
				$finalSubtotalColumnF[] = "F" . $row . ":F" . $row;
				$cellIterator->current()->setValue('=SUBTOTAL(9,' . $TG['owned']['F'] . ',' . $TG['provided']['F'] . ')');
			}
			elseif(!isset($TG['owned']['C']) && isset($TG['provided']['C']))
			{
				$finalSubtotalColumnC[] = "C" . $row . ":C" . $row;
				$cellIterator->current()->setValue('=SUBTOTAL(9,' . $TG['provided']['C'] . ')');
				$cellIterator->next();
				$finalSubtotalColumnD[] = "D" . $row . ":D" . $row;
				$cellIterator->current()->setValue('=SUBTOTAL(9,' . $TG['provided']['D'] . ')');
				$cellIterator->next();
				$finalSubtotalColumnE[] = "E" . $row . ":E" . $row;
				$cellIterator->current()->setValue('=SUBTOTAL(9,' . $TG['provided']['E'] . ')');
				$cellIterator->next();
				$finalSubtotalColumnF[] = "F" . $row . ":F" . $row;
				$cellIterator->current()->setValue('=SUBTOTAL(9,' . $TG['provided']['F'] . ')');
			}
			elseif(isset($TG['owned']['C']) && !isset($TG['provided']['C']))
			{
				$finalSubtotalColumnC[] = "C" . $row . ":C" . $row;
				$cellIterator->current()->setValue('=SUBTOTAL(9,' . $TG['owned']['C'] . ')');
				$cellIterator->next();
				$finalSubtotalColumnD[] = "D" . $row . ":D" . $row;
				$cellIterator->current()->setValue('=SUBTOTAL(9,' . $TG['owned']['D'] . ')');
				$cellIterator->next();
				$finalSubtotalColumnE[] = "E" . $row . ":E" . $row;
				$cellIterator->current()->setValue('=SUBTOTAL(9,' . $TG['owned']['E'] . ')');
				$cellIterator->next();
				$finalSubtotalColumnF[] = "F" . $row . ":F" . $row;
				$cellIterator->current()->setValue('=SUBTOTAL(9,' . $TG['owned']['F'] . ')');
			}
			else
			{
				$finalSubtotalColumnC[] = "C" . $row . ":C" . $row;
				$cellIterator->current()->setValue("0");
				$cellIterator->next();
				$finalSubtotalColumnD[] = "D" . $row . ":D" . $row;
				$cellIterator->current()->setValue("0");
				$cellIterator->next();
				$finalSubtotalColumnE[] = "E" . $row . ":E" . $row;
				$cellIterator->current()->setValue("0");
				$cellIterator->next();
				$finalSubtotalColumnF[] = "F" . $row . ":F" . $row;
				$cellIterator->current()->setValue("0");
			}
			$sheet3->getStyle('F' . $row)->applyFromArray($borderMediumRight);
			$cellIterator->next();
			$cellIterator->current()->setValue("=SUM(C" . $row . ":F" . $row . ")");
			$cellIterator->next();
			$cellIterator->current()->setValue("hrs");
			if($colorValue/2 != floor($colorValue/2))
				$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('B8CCE4');
			else
				$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('D8D8D8');
			$sheet3->getStyle('H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
			
			$rowIterator->next();
			$cellIterator = $rowIterator->current()->getCellIterator();
			
			$row = $cellIterator->current()->getRow();
            $sheet3->getRowDimension($row)->setOutlineLevel(1);
            $sheet3->getRowDimension($row)->setVisible(false);
			$sheet3->getStyle('B' . $row)->applyFromArray($borderMediumRight);
			$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($TG_ID)->name);
			$cellIterator->next();
			if($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($TG_ID)->Parent_ID)->Path == 12)
				$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($TG_ID)->Parent_ID)->Name);
			else
				$cellIterator->current()->setValue($this->context->organizationUnitRepository->find($TG_ID)->Name);
			$cellIterator->next();
			$sheet3->getStyle("C" . $row)->getNumberFormat()->setFormatCode('##0%');
			$cellIterator->current()->setValue("=C" . ($TG['owned']['row'] + 1) . "+C" . ($TG['provided']['row'] + 1));
			$cellIterator->next();
			$sheet3->getStyle("D" . $row)->getNumberFormat()->setFormatCode('##0%');
			$cellIterator->current()->setValue("=D" . ($TG['owned']['row'] + 1) . "+D" . ($TG['provided']['row'] + 1));
			$cellIterator->next();
			$sheet3->getStyle("E" . $row)->getNumberFormat()->setFormatCode('##0%');
			$cellIterator->current()->setValue("=E" . ($TG['owned']['row'] + 1) . "+E" . ($TG['provided']['row'] + 1));
			$cellIterator->next();
			$sheet3->getStyle("F" . $row)->getNumberFormat()->setFormatCode('##0%');
			$cellIterator->current()->setValue("=F" . ($TG['owned']['row'] + 1) . "+F" . ($TG['provided']['row'] + 1));
			$sheet3->getStyle('F' . $row)->applyFromArray($borderMediumRight);
			$cellIterator->next();
			$sheet3->getStyle("G" . $row)->getNumberFormat()->setFormatCode('##0%');
			$cellIterator->current()->setValue("=G" . ($TG['owned']['row'] + 1) . "+G" . ($TG['provided']['row'] + 1));
			if($colorValue/2 != floor($colorValue/2))
				$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('B8CCE4');
			else
				$sheet3->getStyle('A' . $row . ':H' . $row)->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('D8D8D8');
			$rowIterator->next();
			$cellIterator = $rowIterator->current()->getCellIterator();
			$colorValue++;
		}
		
		$columnFinalC = '';
        $columnFinalD = '';
        $columnFinalE = '';
        $columnFinalF = '';
		$columnFinalC = join(',', $finalSubtotalColumnC);
		$columnFinalD = join(',', $finalSubtotalColumnD);
		$columnFinalE = join(',', $finalSubtotalColumnE);
		$columnFinalF = join(',', $finalSubtotalColumnF);
		$cellIterator->current()->setValue('Total');
		$row = $cellIterator->current()->getRow();
		$sheet3->getStyle('A' . $row . ':H' . $row)->applyFromArray($borderMediumTop);
		$sheet3->getStyle('B' . $row)->applyFromArray($borderMediumRight);
		$cellIterator->next();
		$cellIterator->current()->setValue('-');
		$cellIterator->next();
		$cellIterator->current()->setValue('=C' . $ownedFinalTotal . '+C' . $providedFinalTotal);
		$cellIterator->next();
		$cellIterator->current()->setValue('=D' . $ownedFinalTotal . '+D' . $providedFinalTotal);
		$cellIterator->next();
		$cellIterator->current()->setValue('=E' . $ownedFinalTotal . '+E' . $providedFinalTotal);
		$cellIterator->next();
		$cellIterator->current()->setValue('=F' . $ownedFinalTotal . '+F' . $providedFinalTotal);
		$sheet3->getStyle('F' . $row)->applyFromArray($borderMediumRight);
		$cellIterator->next();
		$cellIterator->current()->setValue("=SUM(C" . $row . ":F" . $row . ")");
		$cellIterator->next();
		$cellIterator->current()->setValue("hrs");
		$sheet3->getStyle('H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
		$cellIterator->next();
		$sheet3->getStyle('A' . $row . ':H' . $row)->getFont()->setBold(true);
		$rowIterator->next();
		$cellIterator = $rowIterator->current()->getCellIterator();
			
        // Final total Yield from totals
        if(isset($providedFinalYield) AND isset($ownedFinalYield))
        {
            $cellIterator->current()->setValue('Total group coverage');
            $row = $cellIterator->current()->getRow();
            $sheet3->getStyle('A' . $row . ':H' . $row)->applyFromArray($borderMediumBottom);
            $sheet3->getStyle('B' . $row)->applyFromArray($borderMediumRight);
            $cellIterator->next();
			$cellIterator->current()->setValue('-');
			$cellIterator->next();
            $cellIterator->current()->setValue("=(C" . ($row-1) . "/" . array_sum($arrayYieldQ1Sum) . ')');
            $sheet3->getStyle("C" . $row)->getNumberFormat()->setFormatCode('##0%');
            $cellIterator->next();
            $cellIterator->current()->setValue("=(D" . ($row-1) . "/" . array_sum($arrayYieldQ2Sum) . ')');
            $sheet3->getStyle("D" . $row)->getNumberFormat()->setFormatCode('##0%');
            $cellIterator->next();
            $cellIterator->current()->setValue("=(E" . ($row-1) . "/" . array_sum($arrayYieldQ3Sum) . ')');
            $sheet3->getStyle("E" . $row)->getNumberFormat()->setFormatCode('##0%');
            $cellIterator->next();
            $cellIterator->current()->setValue("=(F" . ($row-1) . "/" . array_sum($arrayYieldQ4Sum) . ')');
            $sheet3->getStyle("F" . $row)->getNumberFormat()->setFormatCode('##0%');
            $sheet3->getStyle('F' . $row)->applyFromArray($borderMediumRight);
            $cellIterator->next();
            $cellIterator->current()->setValue("=(G" . ($row-1) . "/" . (array_sum($arrayYieldSum)) . ')');
            $sheet3->getStyle("G" . $row)->getNumberFormat()->setFormatCode('##0%');
            $cellIterator->next();
//            $cellIterator->current()->setValue("hrs");
            $sheet3->getStyle('H' . $row)->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
            $cellIterator->next();
            $sheet3->getStyle('A' . $row . ':H' . $row)->getFont()->setBold(true);
            $rowIterator->next();
			$rowIterator->next();
            $cellIterator = $rowIterator->current()->getCellIterator();
			$cellIterator->current()->setValue("WARNING: calculation of group coverage is based on workable hours of resources belonging to " . OrganizationUnit::getFullTypeName($orgUnit->Type) . " " . $orgUnit->Name . " as set in HON Planning Tool.");
			$rowIterator->next();
			$cellIterator = $rowIterator->current()->getCellIterator();
			$cellIterator->current()->setValue("Please make sure those are up-to-date and  communicate any changes to PMO(such as employee working part time or leaving company)!!! ");
		}
		
		$rowIterator->next();
		$rowIterator->next();
		$cellIterator = $rowIterator->current()->getCellIterator();
		
		$sheet4->mergeCells('B3:H3');
		$sheet4->mergeCells('A4:A17');
		$sheet4->mergeCells('C4:E4');
		$sheet4->mergeCells('F4:H4');
		$sheet4->mergeCells('C5:E10');
		$sheet4->mergeCells('F5:H10');
		$sheet4->mergeCells('C11:E17');
		$sheet4->mergeCells('F11:H17');
		$sheet4->mergeCells('B5:B10');
		$sheet4->mergeCells('B11:B17');
        $sheet4->getStyle('A4')->getFont()->setBold(true);
        $sheet4->getStyle('B3')->getFont()->setBold(true);
        $sheet4->getStyle('A3:H17')->getAlignment()->setHorizontal(PHPExcel_Style_Alignment::HORIZONTAL_CENTER);
		$sheet4->getStyle('A3:H17')->getAlignment()->setVertical(PHPExcel_Style_Alignment::VERTICAL_CENTER);
        $sheet4->getColumnDimension('A')->setWidth(2.86);
        $sheet4->getColumnDimension('B')->setWidth(2.86);
        $sheet4->getColumnDimension('C')->setWidth(2.86);
        $sheet4->getColumnDimension('H')->setWidth(2.86);
		$sheet4->getStyle('A4')->getAlignment()->setTextRotation(90);
		$sheet4->getStyle('B5')->getAlignment()->setTextRotation(90);
		$sheet4->getStyle('B11')->getAlignment()->setTextRotation(90);
		$sheet4->setCellValue("A1", 'Please click on the the matrix field depending on type of information you are seeking.');
		$sheet4->setCellValue("B3", 'Projects');
		$sheet4->setCellValue("C4", 'Owned');
		$sheet4->setCellValue("F4", 'Of other units');
		$sheet4->setCellValue("A4", 'Resources (people)');
		$sheet4->setCellValue("B5", 'Owned');
		$sheet4->setCellValue("B11", 'Of other units');
		$sheet4->setCellValue("C5", 'Owned resources sheet - Owned projets table');
		$sheet4->getStyle('C5')->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('75923C');
		$sheet4->getStyle('C5')->getAlignment()->setWrapText(true);
		$sheet4->setCellValue("F5", 'Owned resources sheet - Support provided to others table');
		$sheet4->getStyle('F5')->getAlignment()->setWrapText(true);
		$sheet4->getStyle('F5')->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('75923C');
		$sheet4->setCellValue("C11", 'Owned projects - Total budget');
		$sheet4->getStyle('C11')->getFill()->setFillType(PHPExcel_Style_Fill::FILL_SOLID)->getStartColor()->setARGB('D7E4BC');
		$sheet4->getStyle('C11')->getAlignment()->setWrapText(true);
		$sheet4->setCellValue("F11", 'X');
		$sheet4->getStyle('A3')->applyFromArray($borderMediumRight);
		$sheet4->getStyle('A2:H2')->applyFromArray($borderMediumBottom);
		$sheet4->getStyle('A3:H3')->applyFromArray($borderMediumBottom);
		$sheet4->getStyle('H3')->applyFromArray($borderMediumRight);
		$sheet4->getStyle('A4:A17')->applyFromArray($borderMediumRight);
		$sheet4->getStyle('A4:A17')->applyFromArray($borderMediumBottom);
		$sheet4->getStyle('B17:H17')->applyFromArray($borderMediumBottom);
		$sheet4->getStyle('B11:H11')->applyFromArray($borderMediumBottom);
		$sheet4->getStyle('H4:H17')->applyFromArray($borderMediumRight);
		$sheet4->getStyle('B5:H5')->applyFromArray($borderThinTop);
		$sheet4->getStyle('B5:B17')->applyFromArray($borderThinRight);
		$sheet4->getStyle('B11:H11')->applyFromArray($borderThinTop);
		$sheet4->getStyle('E4:E17')->applyFromArray($borderThinRight);
		$sheet4->getCell('B5')->getHyperlink()->setUrl("sheet://'Owned resources'!A1");
		$sheet4->getCell('C4')->getHyperlink()->setUrl("sheet://'Owned projects - total budget'!A6");
		$sheet4->getCell('C5')->getHyperlink()->setUrl("sheet://'Owned resources'!A3");
		$sheet4->getCell('F5')->getHyperlink()->setUrl("sheet://'Owned resources'!A" . $supProvOthersStartRow);
		$sheet4->getCell('C11')->getHyperlink()->setUrl("sheet://'Owned projects - total budget'!A6");
		$sheet4->getStyle('C4')->getFont()->setUnderline(true);
		$sheet4->getStyle('B5')->getFont()->setUnderline(true);
		$sheet4->getStyle('C5')->getFont()->setUnderline(true);
		$sheet4->getStyle('F5')->getFont()->setUnderline(true);
		$sheet4->getStyle('C11')->getFont()->setUnderline(true);
		
        setcookie('fileDownloadToken', time());
        header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
        header('Content-Disposition: attachment; filename=ProjectCharterReport.xlsx');
        header('Cache-Control: max-age=0');
        $objWriter = PHPExcel_IOFactory::createWriter($objPHPExcel, 'Excel2007');
		ob_end_clean();
        $objWriter->save("php://output");
        exit;
    }
    /**
     * Creates form for download.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentDownloadForm($name)
    {
        $form = new AppForm($this, $name);
        $years = array();
		for ($i = 2013; $i <= (date('Y')+1); $i++)
			$years[$i] = $i;        
        $form->addSelect('Year', 'Year', $years)->setDefaultValue(date('Y')+1);
        $orgUnitsResult = array();
		
		$sbesConfig = Environment::getConfig('charter_sbes');
		foreach($sbesConfig as $orgUnitID)
		{
			$sbe = $this->context->organizationUnitRepository->find($orgUnitID);
			$orgUnits = $this->context->organizationUnitRepository->findAllChildrenByPath($sbe->Path);
			foreach ($orgUnits as $orgUnit)
			{
				if ($orgUnit->Type == OrganizationUnit::ORG_UNIT_TYPE_SBE)
					$orgUnitsResult['SBE'][$orgUnit->ID] = $orgUnit->Name;
				if ($orgUnit->Type == OrganizationUnit::ORG_UNIT_TYPE_DEP)
					$orgUnitsResult['Department'][$orgUnit->ID] = $orgUnit->Name;
				if ($orgUnit->Type == OrganizationUnit::ORG_UNIT_TYPE_CLUS)
					$orgUnitsResult['Cluster'][$orgUnit->ID] = $orgUnit->Name;
			}
		}
        $form->addHidden('download_token_value_id');
        $form->addSelect('OrgUnit', 'Organization Unit', $orgUnitsResult);
        $form->addSubmit('download', 'Download report');
        $form->onSuccess[] = array($this, 'downloadFormSubmitted');
    }

    /**
     * Component downloadForm submit download project charter report.
     * 
     * @param AppForm $form 
     * @throws IOException if there is problem with generating project charter report.
     */
    public function downloadFormSubmitted(AppForm $form)
    {
        $values = $form->getValues();
        // checking of inputs
        $orgUnit = $this->context->organizationUnitRepository->find($values['OrgUnit']);
        $projectChartersArray = array();
        $projectCharters = array();
        $LMProjectCharters = array();
		$providedWork = array();
        if(strlen($orgUnit->Path) == 3)
		{
			$providedWork = $this->context->projectCharterBudgetRepository->findProjectCharterBudgetByOrgUnitId($values['OrgUnit']);
			$projectChartersArray = $this->context->projectCharterRepository->findAll($values['Year']);
			foreach ($projectChartersArray as $charter)
				$projectCharters[$charter->ID] = $charter;
		}
		elseif(strlen($orgUnit->Path) == 6)
		{
			$providedWork[$orgUnit->ID] = $this->context->projectCharterBudgetRepository->findProjectCharterBudgetByOrgUnitId($values['OrgUnit']);
			$clusters = $this->context->organizationUnitRepository->findAllChildren($orgUnit->ID);
			foreach ($clusters as $cluster)
			{
				$providedWork[$cluster->ID] = $this->context->projectCharterBudgetRepository->findProjectCharterBudgetByOrgUnitId($cluster->ID);
				$LMProjectCharters[] = $this->context->projectCharterRepository->findProjectCharterByLM($cluster->Leader, $values['Year']);
				foreach($LMProjectCharters as $array)
					foreach($array as $charter)
					$projectCharters[$charter->ID] = $charter;
			}
		}
		elseif(strlen($orgUnit->Path) == 9)
		{
			$providedWork[$orgUnit->ID] = $this->context->projectCharterBudgetRepository->findProjectCharterBudgetByOrgUnitId($orgUnit->ID);
			$LMProjectCharters = $this->context->projectCharterRepository->findProjectCharterByLM($orgUnit->Leader, $values['Year']);
			foreach($LMProjectCharters as $charter)
				$projectCharters[$charter->ID] = $charter;
		}
		
        if ($projectCharters == null && $providedWork == null)
        {
			$this->flashMessage('Selected Organization unit: ' . $orgUnit->name . ' and year: ' . $values['Year'] . ' does not have any Project charters.', 'note');
			$this->redirect('ProjectCharterReport:default');
        }

		try
		{
			// MS Excel file as output
            $objPHPExcel = new PHPExcel();
			$this->generateReport($projectCharters, $values, $objPHPExcel);          
            $this->redirect('ProjectCharterReport:default');
		}
		catch (IOException $e)
		{
			$this->flashMessage('Error while generating project charter report.', 'error');
			$this->redirect('ProjectCharterReport:default');
		}
    }
	
	/**
	 * Function calculate workable hours for given cluster.
	 * Returns array with WH for every TG from cluster with TG ID as key.
	 * 
	 * @param int $clus id of cluster
	 * @param int $year
	 * @return Array $whArray.
	 */
	private function getWorkableHours($clus, $year)
	{
		$whArray = $clArray = array();
		$sumForCluster = $sumForClusterQ1 = $sumForClusterQ2 = $sumForClusterQ3 = $sumForClusterQ4 = 0;
		$clus = $this->context->organizationUnitRepository->find($clus);
		$tgs = $this->context->organizationUnitRepository->findAllChildren($clus->ID);
		$clHours = $this->context->aopRepository->findForPerson($year, $this->context->personRepository->find($clus->Leader)->ID);
		if($clHours)
		{
			$clArray['arrayYieldSum'] = array_sum($clHours->AOP);
			$clArray['arrayYieldQ1Sum'] = $clHours->getMonthAOPHours(1) + $clHours->getMonthAOPHours(2) + $clHours->getMonthAOPHours(3);
			$clArray['arrayYieldQ2Sum'] = $clHours->getMonthAOPHours(4) + $clHours->getMonthAOPHours(5) + $clHours->getMonthAOPHours(6);
			$clArray['arrayYieldQ3Sum'] = $clHours->getMonthAOPHours(7) + $clHours->getMonthAOPHours(8) + $clHours->getMonthAOPHours(9);
			$clArray['arrayYieldQ4Sum'] = $clHours->getMonthAOPHours(10) + $clHours->getMonthAOPHours(11) + $clHours->getMonthAOPHours(12);
		}
		//get all hours for all TGs
		foreach($tgs as $TG_ID => $tg)
		{
			// CL hours must be nulled becouse of PMO, PEC and ARHC org units. There are leaders counted also as part of persons.
			if(strlen($tg->path) <= 9)
			{
				$clArray['arrayYieldSum'] = 0;
				$clArray['arrayYieldQ1Sum'] = 0;
				$clArray['arrayYieldQ2Sum'] = 0;
				$clArray['arrayYieldQ3Sum'] = 0;
				$clArray['arrayYieldQ4Sum'] = 0;
			}
			$q1 = 0;
			$q2 = 0;
			$q3 = 0;
			$q4 = 0;
			$whArray[$TG_ID] = array();
			$persons = $this->context->organizationUnitRepository->findAllSubordinate($TG_ID);
			foreach ($persons as $preson)
			{
				$hour = $this->context->aopRepository->findForPerson($year, $preson);
				$q1 += $hour->getMonthAOPHours(1) + $hour->getMonthAOPHours(2) + $hour->getMonthAOPHours(3);
				$q2 += $hour->getMonthAOPHours(4) + $hour->getMonthAOPHours(5) + $hour->getMonthAOPHours(6);
				$q3 += $hour->getMonthAOPHours(7) + $hour->getMonthAOPHours(8) + $hour->getMonthAOPHours(9);
				$q4 += $hour->getMonthAOPHours(10) + $hour->getMonthAOPHours(11) + $hour->getMonthAOPHours(12);
			}
			$whArray[$TG_ID]['arrayYieldSum'] = ($q1+$q2+$q3+$q4);
			$whArray[$TG_ID]['arrayYieldQ1Sum'] = $q1;
			$whArray[$TG_ID]['arrayYieldQ2Sum'] = $q2;
			$whArray[$TG_ID]['arrayYieldQ3Sum'] = $q3;
			$whArray[$TG_ID]['arrayYieldQ4Sum'] = $q4;
		}
		// recalculate hours according cluster leader hours
		if($clHours)
		{
			// get sum for whole cluster
			foreach($whArray as $tg_id => $tg)
			{
				$sumForCluster += $whArray[$tg_id]['arrayYieldSum'];
				$sumForClusterQ1 += $whArray[$tg_id]['arrayYieldQ1Sum'];
				$sumForClusterQ2 += $whArray[$tg_id]['arrayYieldQ2Sum'];
				$sumForClusterQ3 += $whArray[$tg_id]['arrayYieldQ3Sum'];
				$sumForClusterQ4 += $whArray[$tg_id]['arrayYieldQ4Sum'];
			}
			// recalculation
			if($sumForCluster > 0)
				foreach($whArray as $tg_id => $tg)
				{
					$whArray[$tg_id]['arrayYieldSum'] = ($sumForCluster !== 0) ? round(($clArray['arrayYieldSum'] * $whArray[$tg_id]['arrayYieldSum'] / $sumForCluster) + $whArray[$tg_id]['arrayYieldSum']) : 0;
					$whArray[$tg_id]['arrayYieldQ1Sum'] = ($sumForClusterQ1 !== 0) ? round(($clArray['arrayYieldQ1Sum'] * $whArray[$tg_id]['arrayYieldQ1Sum'] / $sumForClusterQ1) + $whArray[$tg_id]['arrayYieldQ1Sum']) : 0;
					$whArray[$tg_id]['arrayYieldQ2Sum'] = ($sumForClusterQ2 !== 0) ? round(($clArray['arrayYieldQ2Sum'] * $whArray[$tg_id]['arrayYieldQ2Sum'] / $sumForClusterQ2) + $whArray[$tg_id]['arrayYieldQ2Sum']) : 0;
					$whArray[$tg_id]['arrayYieldQ3Sum'] = ($sumForClusterQ3 !== 0) ? round(($clArray['arrayYieldQ3Sum'] * $whArray[$tg_id]['arrayYieldQ3Sum'] / $sumForClusterQ3) + $whArray[$tg_id]['arrayYieldQ3Sum']) : 0;
					$whArray[$tg_id]['arrayYieldQ4Sum'] = ($sumForClusterQ4 !== 0) ? round(($clArray['arrayYieldQ4Sum'] * $whArray[$tg_id]['arrayYieldQ4Sum'] / $sumForClusterQ4) + $whArray[$tg_id]['arrayYieldQ4Sum']) : 0;
				}
		}
		return $whArray;
	}
	
	/**
	 * Function will sort all TGs according clusters. 
	 * Each cluster is array with cluster id as key and contains TGs array with project charter budgets prepared to report.
	 * 
	 * @param Array $tgArray Array of project charters budgets with TG id as key.
	 * @return Array $clusArray.
	 */
	private function sortTechGroupToClusters($tgArray)	
	{
		$clusArray = array();
		foreach($tgArray as $tg_id => $charterBudget)
		{
			$tg = $this->context->organizationUnitRepository->find($tg_id);
			$clusArray[$tg->Parent_ID][$tg_id] = $charterBudget;
		}
		return $clusArray;
	}
}
