<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011, 2014 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters
 */

/**
 * Presenter for resources lock.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class ResourceLockPresenter extends SecuredPresenter
{	
    /**
     * Nette default render method.
     */
    public function renderDefault()
    {
		
    }
	
    /**
     * Creates general lock form.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentLockForm($name)
    {
        $form = new AppForm($this, $name);

		$form['OrganizationUnitSelector'] = new OrganizationUnitLockSelectorContainer(300, FALSE);
			$form['OrganizationUnitSelector']['SBE']->setRequired('Please select SBE at least!');
		    $form['OrganizationUnitSelector']['ajaxHandle']->setValue($this->link('OrganizationUnitLockSelector'));

		$form->addCheckbox('recursiveLock', HPTForm::createLabel('Recursive Lock', 'Lock works with subunits.'));
		$form->addSubmit('unLock', 'Unlock')
			->onClick[] = callback($this, 'unLockFormSubmitted');

		$form->addSubmit('lock', 'Lock')
			->onClick[] = callback($this, 'lockFormSubmitted');
		$orgunitTypes = OrganizationUnit::getTypes();
		$isResOwner = array_key_exists(strtoupper (Environment::getUser()->getId()), $this->context->personRepository->getLeadersByOrgUnitType($orgunitTypes));
		$form['unLock']->setDisabled(true);
		$form['lock']->setDisabled(true);
		if($this->isAllowed(self::RESOURCE_RESOURCE_LOCK, self::ACTION_RUN) || $isResOwner)
		{
			$form['unLock']->setDisabled(false);
			$form['lock']->setDisabled(false);
		}
        return $form;
    }
	
	/**
	 * Method locks selected resources
	 * @param SubmitButton $button
	 */
	public function lockFormSubmitted(SubmitButton $button)
	{
		$orgunitTypes = OrganizationUnit::getTypes();
		$isResOwner = array_key_exists(strtoupper (Environment::getUser()->getId()), $this->context->personRepository->getLeadersByOrgUnitType($orgunitTypes));
		if($this->isAllowed(self::RESOURCE_RESOURCE_LOCK, self::ACTION_RUN) || $isResOwner)
		{
			if ($button->form->isValid())
			{
				$entry = $button->form->getValues();
				$unit_id = NULL;
				if ($entry->OrganizationUnitSelector->TechnicalGroup)
					$unit_id = $entry->OrganizationUnitSelector->TechnicalGroup;
				elseif ($entry->OrganizationUnitSelector->Cluster)
					$unit_id = $entry->OrganizationUnitSelector->Cluster;
				elseif ($entry->OrganizationUnitSelector->Department)
					$unit_id = $entry->OrganizationUnitSelector->Department;
				elseif ($entry->OrganizationUnitSelector->SBE)
					$unit_id = $entry->OrganizationUnitSelector->SBE;
				if ($unit_id)
				{
					$unit = $this->context->organizationUnitRepository->find($unit_id);
					if ($unit)
					{
						if(($unit->Leader == strtoupper(Environment::getUser()->getId())) || $this->isAllowed(self::RESOURCE_RESOURCE_LOCK, self::ACTION_RUN))
						{
							$unit->Locked = 1;
							if($this->context->organizationUnitRepository->update($unit))
							{
								$this->flashMessage('Organization Unit: ' . $unit->Name . ' was locked.', 'success');
							}
							else
							{
								$this->flashMessage('Organization Unit: ' . $unit->Name . ' was not locked.', 'error');
							}
							if($entry['recursiveLock'])// locks units recursively
							{
								$childrenUnits = $this->context->organizationUnitRepository->findAllChildrenByPath($unit->Path);
								unset($childrenUnits[$unit->ID]);
								if($childrenUnits)
								{
									$multilog = new MultiLogger();
									$batch_id = 'RES-LOCK-'.time().'-'. rand(1, 9);
									$multilog->add($this->context->createLogger($batch_id, "Resources lock"));
									foreach($childrenUnits as $childUnit)
									{
										$childUnit->Locked = 1;
										if($this->context->organizationUnitRepository->update($childUnit))
										{
											$multilog->log('Recursive organization unit: ' . $childUnit->Name . ' was locked.', ILogger::INFO);
										}
										else
										{
											$multilog->log('Recursive organization unit: ' . $childUnit->Name . ' was not locked.', ILogger::WARNING);
										}
									}
									$this->flashMessage("Recursive organizaiton units were locked. See log for more information.", 'notice');
								}
								else
									$this->flashMessage("No recursive organizaiton units have been found.", 'notice');
							}
						}
						else
						{
							$this->flashMessage("You are not authorized to lock resources. PMO or Resource Owner roles required.", 'error');
						}
					}
					else
					{
						$this->flashMessage("Selected Organization Unit doesn't exist.", 'error');
					}
				}
				else
				{
					$this->flashMessage("No organization unit selected!", 'error');
				}
			}
			else
			{
				$this->flashMessage("Invalid form values.", 'error');
			}
		}
		else
		{
			$this->flashMessage("You are not authorized to lock resources. PMO or Resource Owner roles required.", 'error');
		}

	    $this->redirect('this');
	}
	
	/**
	 * Method locks selected resources
	 * @param SubmitButton $button
	 */
	public function unLockFormSubmitted(SubmitButton $button)
	{
		$orgunitTypes = OrganizationUnit::getTypes();
		$isResOwner = array_key_exists(strtoupper (Environment::getUser()->getId()), $this->context->personRepository->getLeadersByOrgUnitType($orgunitTypes));
		if($this->isAllowed(self::RESOURCE_RESOURCE_LOCK, self::ACTION_RUN) || $isResOwner)
		{
			if ($button->form->isValid())
			{
				$entry = $button->form->getValues();
				$unit_id = NULL;
				if ($entry->OrganizationUnitSelector->TechnicalGroup)
					$unit_id = $entry->OrganizationUnitSelector->TechnicalGroup;
				elseif ($entry->OrganizationUnitSelector->Cluster)
					$unit_id = $entry->OrganizationUnitSelector->Cluster;
				elseif ($entry->OrganizationUnitSelector->Department)
					$unit_id = $entry->OrganizationUnitSelector->Department;
				elseif ($entry->OrganizationUnitSelector->SBE)
					$unit_id = $entry->OrganizationUnitSelector->SBE;
				if ($unit_id)
				{
					$unit = $this->context->organizationUnitRepository->find($unit_id);
					if ($unit)
					{
						if(($unit->Leader == strtoupper(Environment::getUser()->getId())) || $this->isAllowed(self::RESOURCE_RESOURCE_LOCK, self::ACTION_RUN))
						{
							$unit->Locked = 0;
							if($this->context->organizationUnitRepository->update($unit))
							{
								$this->flashMessage('Organization Unit: ' . $unit->Name . ' was unlocked.', 'success');					
							}
							else
							{
								$this->flashMessage('Organization Unit: ' . $unit->Name . ' was not unlocked.', 'error');
							}
							if($entry['recursiveLock'])// locks units recursively
							{
								$childrenUnits = $this->context->organizationUnitRepository->findAllChildrenByPath($unit->Path);
								unset($childrenUnits[$unit->ID]);
								if($childrenUnits)
								{
									$multilog = new MultiLogger();
									$batch_id = 'RES-LOCK-'.time().'-'. rand(1, 9);
									$multilog->add($this->context->createLogger($batch_id, "Resources lock"));
									foreach($childrenUnits as $childUnit)
									{
										$childUnit->Locked = 0;
										if($this->context->organizationUnitRepository->update($childUnit))
										{
											$multilog->log('Recursive organization unit: ' . $childUnit->Name . ' was unlocked.', ILogger::INFO);
										}
										else
										{
											$multilog->log('Recursive organization unit: ' . $childUnit->Name . ' was not unlocked.', ILogger::WARNING);
										}
									}
									$this->flashMessage("Recursive organizaiton units were unlocked. See log for more information.", 'notice');
								}
								else
									$this->flashMessage("No recursive organizaiton units have been found.", 'notice');
							}
						}
						else
						{
							$this->flashMessage("You are not authorized to lock resources. PMO or Resource Owner roles required.", 'error');
						}
					}
					else
					{
						$this->flashMessage("Selected Organization Unit doesn't exist.", 'error');
					}
				}
			}
			else
			{
				$this->flashMessage("Invalid form values.", 'error');
			}
		}
		else
		{
			$this->flashMessage("You are not authorized to unlock resources. PMO role required.", 'error');
		}

	    $this->redirect('this');
	}
	
	/**
	 * Prepares data for organization unit selector
	 * @param int $id ID of selected organization unit
	 */
	public function actionOrganizationUnitLockSelector($id)
	{		
		$org_unit_selector = new OrganizationUnitLockSelectorContainer;
		$this->payload->organizationUnitSelectorResult = $org_unit_selector->ajaxHandle($id);
		$this->terminate();
	}
}