<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2016 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters
 */

/**
 * Presenter started by cron process to run TLC actuals import.
 * Authentication is done by url (known token).
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class TLCActualsAutoImportPresenter extends TokenAccessPresenter
{
	/* authentication token setup */
	const AUTH_TOKEN_NAME = 'token',
		AUTH_TOKEN_KEY = 'TLC.actuals.credentials.cronToken';
	
	/**
     * Service for TLC iASAP importing.
     * @var iASAPActualsImportServiceTLC
     */
	private $iASAPActualsImportServiceTLC;
	
    /**
     * Returns http parameter name with authentication token.
     * 
     * @return string
     */
	protected function getAuthTokenName()
	{
		return self::AUTH_TOKEN_NAME;
	}

    /**
     * Returns http parameter name with authentication token.
	 * 
     * @return string
     */
	protected function getAuthTokenSettingsKey()
	{
		return self::AUTH_TOKEN_KEY;
	}
	
	/**
     * Run method 
     */
    public function renderRun()
    {
		// init logging
		$logs_suffix = time().'-'. rand(1, 9);
		$current_log_file_name = 'tlc_actuals_import-'.$logs_suffix.'.html';
		$batch_id = 'tlc_actuals_import-'.$logs_suffix;
		$filelog_path = TEMP_DIR . DIRECTORY_SEPARATOR . $current_log_file_name;
        $filelog = $this->context->createFileLogger($filelog_path, $batch_id, "TLC ACTUALS IMPORT") ;
		$multilog = new MultiLogger();
		$multilog->add($filelog);
		$multilog->add($this->context->createLogger($batch_id, "TLC ACTUALS IMPORT"));

		//  time admin table import
        $this->iASAPActualsImportServiceTLC = new IASAPActualsImportServiceTLC($this->context, $multilog);
        
        try
        {
			switch ($this->iASAPActualsImportServiceTLC->runTimeAdminImport())
			{
				case IASAPActualsImportServiceTLC::RESULT_SUCCESS:
					$this->flashMessage('TLC (time admin) actuals import was successful.', 'success');
					break;
				case IASAPActualsImportServiceTLC::RESULT_NO_DATA:
					$this->flashMessage('TLC (time admin) actuals import was successful but no actuals was found.', 'warning');
					break;
				case IASAPActualsImportServiceTLC::RESULT_WARNING:
					$this->flashMessage('TLC (time admin) actuals import was successful with warnings.', 'warning');
					break;
				case IASAPActualsImportServiceTLC::RESULT_ERROR:
					$this->flashMessage('TLC (time admin) actuals import failed!', 'error');
					break;
				default: break;
			}
        }
        catch (IASAPActualsImportServiceTLCException $e)
        {
			$this->flashMessage("TLC (time admin) actuals import failed: " . $e->getMessage(), 'error');
			$multilog->log('TLC (time admin) actuals import failed: ' . $e->getMessage(), ILogger::ERROR);
			Debugger::log('TLC (time admin) actuals import failed: ' . $e->getMessage(), Debugger::ERROR);
		}
		
		// ysp detail csc table import
//        $this->iASAPActualsImportServiceTLC = new IASAPActualsImportServiceTLC($this->context, $multilog);
//        
//        try
//        {
//			switch ($this->iASAPActualsImportServiceTLC->runYPSDetailImport())
//			{
//				case IASAPActualsImportServiceTLC::RESULT_SUCCESS:
//					$this->flashMessage('TLC (ysp detail csc) actuals import was successful.', 'success');
//					break;
//				case IASAPActualsImportServiceTLC::RESULT_NO_DATA:
//					$this->flashMessage('TLC (ysp detail csc) actuals import was successful but no actuals was found.', 'warning');
//					break;
//				case IASAPActualsImportServiceTLC::RESULT_WARNING:
//					$this->flashMessage('TLC (ysp detail csc) actuals import was successful with warnings.', 'warning');
//					break;
//				case IASAPActualsImportServiceTLC::RESULT_ERROR:
//					$this->flashMessage('TLC (ysp detail csc) actuals import failed!', 'error');
//					break;
//				default: break;
//			}
//        }
//        catch (IASAPActualsImportServiceTLCException $e)
//        {
//			$this->flashMessage("TLC (ysp detail csc) actuals import failed: " . $e->getMessage(), 'error');
//			$multilog->log('TLC (ysp detail csc) actuals import failed: ' . $e->getMessage(), ILogger::ERROR);
//			Debugger::log('TLC (ysp detail csc) actuals import failed: ' . $e->getMessage(), Debugger::ERROR);
//		}
        $filelog->close();
		
        $this->template->lastUpdated    = $this->context->actualsRepository->getLastImportDate(Actuals::SOURCE_IASAP_TIMEADMIN);
        $this->template->logfilePath    = basename(TEMP_DIR) . '/' . $current_log_file_name;
		$this->template->batchNumber	= $batch_id;
    }
}
