<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters
 */

/**
 * Presenter for auto generation of tracking table.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class TrackingTableAutoGenerationPresenter extends TokenAccessPresenter
{
	/* authentication token setup */
	const AUTH_TOKEN_NAME = 'token',
		  AUTH_TOKEN_KEY = 'TTReport.credentials.cronToken';
	
    /**
     * Returns http parameter name with authentication token.
     * 
     * @return string
     */
	protected function getAuthTokenName()
	{
		return self::AUTH_TOKEN_NAME;
	}

    /**
     * Returns http parameter name with authentication token.
	 * 
     * @return string
     */
	protected function getAuthTokenSettingsKey()
	{
		return self::AUTH_TOKEN_KEY;
	}
	
    /**
     * Nette default render method 
     */
	public function renderDefault()
	{
	}
    
	/**
     * Generate method 
     */
    public function renderGenerateReport()
    {
		$year = date('Y');
		$sbes = $this->context->organizationUnitRepository->findAllOrgUnitByType(OrganizationUnit::ORG_UNIT_TYPE_SBE);
		foreach($sbes as $sbe)
		{
			$multilog = new MultiLogger();
			$batch_id = 'TT-'.time().'-'. rand(1, 9);
			$multilog->add($this->context->createLogger($batch_id, "TT auto generation"));
			$TTReportService = new TTReportService($this->context, $multilog, $year, $sbe);
			$importResult = true;
			try
			{
				$TTReportService->runTrackingTableGeneration();
			}
			catch (Exception $e)
			{
				$importResult = false;
				Debugger::log('TT auto generation failed: ' . $e->getMessage(), Debugger::ERROR);
				$multilog->log('TT auto generation failed: ' . $e->getMessage(), ILogger::ERROR);
			}
			$this->template->result = $importResult;
			if($importResult)
			{
				$multilog->log('TT auto generation completed.', ILogger::NOTICE);
			}
		}
    }
}

