<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011, 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters
 */

/**
 * Presenter for administration of workable hours.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
Class WorkableHourPresenter extends SecuredPresenter
{

    /**
	 * Compares two persons by surname alphabetically.
	 * 
	 * @param array of Person that can be assigned to task
	 * @param array of Person that can be assigned to task
	 * @return int -1, 0, 1
	 */
    private function comparePersonBySurname($person1, $person2)
	{
		return strcasecmp($person1->getSurname(), $person2->getSurname());
	}
    
    /**
     * Nette default render method.
     */
    public function renderDefault ()
    {
        $personFilter = new PersonFilter();
        if (isset($this->payload->filter))
        {            
            $personFilter->ID = $this->payload->filter['EID'];
            $personFilter->Firstname = $this->payload->filter['Name'];
            $personFilter->Surname = $this->payload->filter['Surname'];
        }        
        
		$persons_filtered = $this->context->personRepository->getPersonsByFilter($personFilter);
		usort($persons_filtered, array($this, 'comparePersonBySurname'));
        $persons = array();
        foreach ($persons_filtered as $person)
        {
            $persons[]['EID'] = $person->ID;
            $persons[count($persons)-1]['Surname'] = $person->Surname;
            $persons[count($persons)-1]['Firstname'] = $person->Firstname;
        }
        
        $this->template->persons = $persons;
        $this->template->form = $this['filterPersonForm'];
    }
    
    /**
     * Shows detail of workable hours.
     * 
     * @param string $id Person EID.
     */
    public function renderShowDetail($id)
    {
        $person = $this->context->personRepository->find($id);

        $formDefaults = array();
        $formDefaults['EID'] = $person->ID;
        $formDefaults['Surname'] = $person->Surname;
        $formDefaults['Name'] = $person->Firstname;
        $formPerson = $this['detailPersonForm'];
        $formPerson->setDefaults($formDefaults);
        $this->template->formPerson = $formPerson;
        
        //actual year
        $year = date("Y");
        
        $formDefaultYear = array();                 
        $formYear = $this['yearForm'];
        $formDefaultYear['Year'] = $year;
        $formYear->setDefaults($formDefaultYear);
        $this->template->formYear = $formYear;
        $isAOP = null;
        
        if ($this->isAjax())
        {                        
            $pom = $this->payload->year;
            $hour = $this->context->aopRepository->findForPerson($pom, $id);
            $aopHour = $this->context->aopRepository->find($pom);
            $formDefaultYear['Year'] = $pom;
            if($this->context->workableHourRepository->isAop($pom, $id))
                $isAOP = 0;
            else
                $isAOP = 1;
        }
        else
        {
            $hour = $this->context->aopRepository->findForPerson($year, $id);
            $aopHour = $this->context->aopRepository->find($year);
            if($this->context->workableHourRepository->isAop($year, $id))
                $isAOP = 0;
            else
                $isAOP = 1;
        }
        
        $formDefaultHours = array(); 
        for($i=0; $i<12; $i++)
        {            
            $formDefaultHours[ FiscalCalendar::fiscalMonthIndexToName($i, false) ] = $hour->getMonthAOPHours($i+1);
        }
        for($i=0; $i<12; $i++)
        {
            $formDefaultHours[ 'H' . FiscalCalendar::fiscalMonthIndexToName($i, false) ] = $aopHour->getMonthAOPHours($i+1);
        }
        $formDefaultHours['Year'] = $hour->getYear();
        $formDefaultHours['EID'] = $id;
        $formDefaultHours['isAop'] = $isAOP;
        $formDefaultHours['Percentage'] = $this->context->workableHourRepository->getPercentage($id, $formDefaultYear['Year'])*100;        
        $formHour = $this['workableHourForm'];
        $formHour->setDefaults($formDefaultHours);
        $this->template->formHour = $formHour;           
    }
    
    /**
     * Creates form for filtering Persons.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentFilterPersonForm($name)
    {
        $form = new AppForm($this, $name);

        $form->addText('EID', 'EID')
                ->setAttribute('maxlength', '7')
                ->setAttribute('size', '30');
        $form->addText('Surname', 'Surname')
                ->setAttribute('size', '30');
        $form->addText('Name', 'Name')
                ->setAttribute('size', '30');      
        $form->getElementPrototype()->class('ajax');
        $form->onSuccess[] = array($this, 'filterPersonFormSubmitted');
        
        return $form;
    }
    
    /**
     * Creates form for showing Person's details.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentDetailPersonForm($name)
    {
        $form = new AppForm($this, $name);

        $form->addText('EID', 'EID')
                ->setAttribute('size', '30')
                ->setAttribute('readonly', 'readonly');
        $form->addText('Surname', 'Surname')
                ->setAttribute('size', '30')
                ->setAttribute('readonly', 'readonly');
        $form->addText('Name', 'Name')
                ->setAttribute('size', '30')
                ->setAttribute('readonly', 'readonly');

        return $form;
    }
    
    /**
     * Creates form for showing workable hours.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentWorkableHourForm($name)
    {
        $per = array('100' => '100%', '75' => '75%', '50' => '50%', '25' => '25%');        
        $form = new AppForm($this, $name);

        for($i=0; $i<12; $i++)
        {
        $form->addHidden('H' . FiscalCalendar::fiscalMonthIndexToName($i, false))
                ->setAttribute('class', 'workableHoursInputHidden');
        }        
        $form->addHidden('EID');
        $form->addHidden('Year');
        $form->addHidden('isAop')
                ->setAttribute('class', 'isAop');
        $form->addCheckbox('AOP', 'AOP Calendar')
                ->setAttribute('class', 'workableHoursCheckBox');
        for($i=0; $i<12; $i++)
        {
            $form->addText(FiscalCalendar::fiscalMonthIndexToName($i, false), FiscalCalendar::fiscalMonthIndexToName($i, true))
                ->addConditionOn($form['AOP'], Form::EQUAL, FALSE)
                    ->addRule(Form::PATTERN, 'Hours must be positive integer.', '[0-9]+');
                $form[FiscalCalendar::fiscalMonthIndexToName($i, false)]->setAttribute('size', '3')
                ->setAttribute('class', 'workableHoursInputText');
        }
        $form->addSelect('Percentage', 'Percentage', $per)
                ->setHtmlId("per");
        $form->addSubmit('Back', 'Go back')
                ->setValidationScope(FALSE)
                ->onClick[] = callback($this, 'backClicked');
        $form->addSubmit('Save', 'Save');
        $form->onSuccess[] = array($this, 'workableHourFormSubmittedSave');        
        return $form;
    }
    
    /**
     * Creates form for selecting years.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentYearForm($name)
    {
        $year = $this->context->aopRepository->getYears();        
        $form = new AppForm($this, $name);
        $form->addSelect('Year', 'Year', $year);        
        $form->getElementPrototype()->class('ajax');
        $form->onSuccess[] = array($this, 'YearFormSubmitted');
        return $form;
    }
    
    /**
     * Workable hour form submitted.
     * 
     * @param AppForm $form 
     */
    public function workableHourFormSubmittedSave($form)
    {
        if($form->isValid())
        {
            $edit = $form->getValues();
            $hour = new WorkableHour();
            $hour->setID($edit['EID']);
            $hour->setYear($edit['Year']);
            if ($edit['Jan'] != null)
            {
                for($i = 1; $i<13 ; $i++)
                {
                    $hour->setMonthHours($edit[ FiscalCalendar::fiscalMonthIndexToName($i-1, false) ], $i);
                }
            }
            $hour->setPercentage($edit['Percentage']);
            
            if($edit['AOP']==false)
            {            
                if ($this->context->workableHourRepository->search($hour->Year, $hour->ID))
                {
                    $this->context->workableHourRepository->update($hour);
                    $this->flashMessage("Workable hours of person: '" . $hour->ID . "' updated.", 'success');
                }
                else
                {
                    $this->context->workableHourRepository->create($hour);
                    $this->flashMessage("Workable hours of person: '" . $hour->ID . "' saved.", 'success');
                }
            }
            else
            {
                if($hour->Percentage == 100)
                {
                    if ($this->context->workableHourRepository->search($hour->Year, $hour->ID))
                    {
                        $this->context->workableHourRepository->delete($hour->Year, $hour->ID);
                        $this->flashMessage("Workable hours of person: '" . $hour->ID . "' deleted.", 'success');
                    }
                    else
                    {
                        $this->flashMessage("Workable hours of person: '" . $hour->ID . "' was already deleted.", 'success');
                    }
                }
                else
                {
                    if ($this->context->workableHourRepository->search($hour->Year, $hour->ID))
                    {
                        $this->context->workableHourRepository->update($hour);
                        $this->flashMessage("Workable hours of person: '" . $hour->ID . "' updated.", 'success');
                    }
                    else
                    {
                        $this->context->workableHourRepository->create($hour);
                        $this->flashMessage("Workable hours of person: '" . $hour->ID . "' saved.", 'success');
                    }
                }
            }
        }
        else
        {  
            $this->flashMessage("Invalid form values.");
        }
         $this->redirect('WorkableHour:showDetail', $edit['EID']);        
    }
    
    /**
     * Person form submitted.
     * 
     * @param AppForm $form 
     */
    public function filterPersonFormSubmitted(AppForm $form)
    {
        if ($this->isAjax())
        {
            $this->payload->filter = $form->getValues();
            $this->invalidateControl('persons');
            Debugger::log('Person filter form submitted by AJAX.', Debugger::DEBUG);
        }
    }
    
    /**
     * Year form submitted.
     * 
     * @param AppForm $form 
     */
    public function yearFormSubmitted(AppForm $form)
    {               
        $this->payload->year = $form->getValues();
        $this->invalidateControl('hours');
        Debugger::log('Year filter form submitted by AJAX.', Debugger::DEBUG);        
    }
    
    /**
     * Go back button redirects back to :default.
     * 
     * @param SubmitButton $button Go back button.
     */
    public function backClicked(SubmitButton $button)
    {
        $this->redirect('default');
    }
}

