<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2015 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters
 */

/**
 * Presenter for administration of workpackages.
 *
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
class WorkpackagePresenter extends SecuredPresenter
{
    /** @var session */
    private $session;
	/** @persistent */
	public $year;

	/**
	 * Initialization
	 */
	public function startup()
	{
		parent::startup();

        $this->session = $this->getSession('WorkPackage');
        $this->session->setExpiration(0);
        
        $this->setYear($this->year, $this->session);
	}
	
    /**
     * Handles creation of worpackage year report
     */
    public function handleYearWorkPackageReport($downloadTokenValue = null)
    {
        $workPackageID = $this->getHttpRequest()->getQuery('id');
		$year = $this->getHttpRequest()->getQuery('year');

		$multilog = new MultiLogger();
		$batch_id = 'WorkPackageReport-'.time().'-'. rand(1, 9);
		$multilog->add($this->context->createLogger($batch_id, "WorkPackage Report"));
        $workPackageReportService = new WorkPackageReportService($workPackageID, $this->context, $multilog, array($year), time());
		$importResult = true;
        try
        {
			$workPackageReportService->runWorkPackageReportGeneration();
		}
        catch (Exception $e)
        {
			$importResult = false;
            Debugger::log('WorkPackage Report generation failed: ' . $e->getMessage(), Debugger::ERROR);
			$multilog->log('WorkPackage Report generation failed: ' . $e->getMessage(), ILogger::ERROR);
			$this->flashMessage('WorkPackage Report generation failed: ' . $e->getMessage(), 'error');
		}
		if($importResult)
		{
			$multilog->log('WorkPackage Report generation completed.', ILogger::NOTICE);
			$this->flashMessage('WorkPackage Report generation was successful.', 'success');
		}
		$this->redirect('this');
    }
    
    /**
     * Handles creation of overall workPackage report
     */
    public function handleWholeTimeWorkPackageReport($downloadTokenValue = null)
    {
        $workPackageID = $this->getHttpRequest()->getQuery('id');

		$multilog = new MultiLogger();
		$batch_id = 'WorkPackageReport-'.time().'-'. rand(1, 9);
		$multilog->add($this->context->createLogger($batch_id, "WorkPackage Report"));
        $workPackageReportService = new WorkPackageReportService($workPackageID, $this->context, $multilog, null, time());
		$importResult = true;
        try
        {
			$workPackageReportService->runWorkPackageReportGeneration();
		}
        catch (Exception $e)
        {
			$importResult = false;
            Debugger::log('WorkPackage Report generation failed: ' . $e->getMessage(), Debugger::ERROR);
			$multilog->log('WorkPackage Report generation failed: ' . $e->getMessage(), ILogger::ERROR);
			$this->flashMessage('WorkPackage Report generation failed: ' . $e->getMessage(), 'error');
		}
		if($importResult)
		{
			$multilog->log('WorkPackage Report generation completed.', ILogger::NOTICE);
			$this->flashMessage('WorkPackage Report generation was successful.', 'success');
		}
		$this->redirect('this');
    }
    
    /**
     * Global setting of templates
     */
    public function beforeRender()
    {
        parent::beforeRender();
        
        $this->template->year = $this->year;
    }
	
	/**
	 * Shows workpackage detail
	 * @param integer $id Should be workpackage id
	 */
    public function renderDetail($id, $year = NULL)
    {
		$workpackage = $this->context->workPackageRepository->find($id);
		if (!$workpackage)
		{
			$this->flashMessage('Invalid Work Package ID. You have been redirected.', 'warning');
			$this->redirect('Project:default');
		}

        if ($year && is_numeric($year))
            $this->year = $year;
        
        // Temporary loading of project id
        // TODO project id should be loaded automaticaly in find method
        $workpackage->ProjectID = $this->context->workPackageRepository->getProjectID($id);
        $project = $this->context->projectRepository->find($workpackage->ProjectID);
        
        $this->template->workpackage = $workpackage;
        $this->template->project = ($project) ? $project : new Project();
		
		$this->template->eacLink = $this->link('eAC:AjaxCall!');
		$this->template->wbsLink = $this->link('wBS:AjaxCall!');
    }
    
    /**
     * Creates EAC table
     * @return \EACControl
     */
    public function createComponentEAC()
    {
        $workpackage = $this->context->workPackageRepository->find((int) $this->getParameter('id'));        
        $control = new EACControl($workpackage, $this->year, $this->getParameter('expandMonths'));
        return $control;
    }
    
    /**
     * Creates base WBS filter form
     * @return WBSFilterForm
     */
    public function createComponentWBSFilterForm()
    {
        $control = new WBSFilterForm();
        return $control;
    }
    
    /**
     * Creates WBS
     * @return \WBSControl
     */
    public function createComponentWBS()
    {
		$wpID = (int)$this->getParameter('id');
		$wpYear = (int)$this->getParameter('year');
        $workpackage = $this->context->workPackageRepository->find($wpID);
        // Temporary loading of project id
        // TODO project id should be loaded automatically in find method
        $workpackage->ProjectID = $this->context->workPackageRepository->getProjectID($workpackage->ID);
        $control = new WBSControl($workpackage, $this->year, 'wp' . '+' . $wpID . '+' . $wpYear);
        return $control;
    }
}
