<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters
 */

/**
 * Presenter for administration of Strap Items.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class ItemPresenter extends SecuredPresenter
{
	/** @const CTQ template value setup */
	const CTQ_TEMPLATE_VALUE = 'ctqTemplateValue';
	/** @const  Highest value of TRL that can be reached */
	const MAX_TRL_VALUE = 9;
	
    /**
     * Nette default render method.
	 * Shows list of STRAP ITEMs
     */
    public function renderDefault()
    {
		
        // in case that filter is filled, copy its content into filter object
        $itemFilter = new ItemFilter();
        if (isset($this->payload->filter))
        {
            $itemFilter->ResponsibleOrgUnitID = $this->payload->filter;
        }
        
        // get items according to values of filter
        $itemsFiltered = $this->context->itemRepository->getItemsByFilter($itemFilter);

        $items = array(); $i = 0;
        foreach ($itemsFiltered as $item)
        {

			$totalBudget = 0;
			$totalBudgetFromCurrentYear = 0;
			$responsibleOrgUnit = $this->context->organizationUnitRepository->find($item->responsibleOrgUnitID)->Name;
            $items[$i]['ResponsibleOrgUnitID'] = $responsibleOrgUnit;
			$items[$i]['ID'] = $item->ID;
            $items[$i]['CustomID'] = $item->CustomID;
            $items[$i]['Name'] = $item->Name;
			$items[$i]['TargetTRL'] = $item->TargetTRL;
			$items[$i]['TargetTRLYear'] = $item->TargetTRLYear;
			$items[$i]['Description'] = $item->Description;
			$items[$i]['Active'] = $item->Active;
			// Target value calculation
			// Find all activities
			$activities = $this->context->itemActivityRepository->findByItemID($item->ID);
			foreach($activities as $activity)
			{
				if($activity->active == 1)
					if($activity->Type == ItemActivity::ITEM_ACTIVITY_TYPE_PROJECT)
					{
						$activityBudgets = $this->context->itemActivityYearlyBudgetRepository->findAllByID($activity->ID);
						foreach($activityBudgets as $budget)
						{
							if($budget->Year > Date('Y'))
							{
									$totalBudget += $budget->LaborCosts + $budget->SubcontractingCosts + $budget->TravelCosts + $budget->MaterialCosts;
									$totalBudgetFromCurrentYear += $budget->LaborCosts + $budget->SubcontractingCosts + $budget->TravelCosts + $budget->MaterialCosts;
							}
						}
						$project = $this->context->projectRepository->find($activity->ProjectID);
						$reporter = new ProjectEACReporter($this->context, $project, Date('Y'));
						$labor = $mat = $trv = $sub = 0;
						try
						{
							$labor = $reporter->getProjectLabourPlannedCostsMonthTotals()->sum();
						}
						catch (InvalidStateException $e)
						{
							$this->flashMessage($e->getMessage(), 'error');
							Debugger::log($e->getMessage(), Debugger::ERROR);
							$this->redirect('Board:default');
						}
						$mat = $reporter->getProjectTravelPlannedCostsMonthTotals()->sum();
						$trv = $reporter->getProjectMaterialPlannedCostsMonthTotals()->sum();
						$sub = $reporter->getProjectSubcontractingPlannedCostsMonthTotals()->sum();
						$totalBudget += $labor + $trv + $mat + $sub;
						$totalBudgetFromCurrentYear += $labor + $trv + $mat + $sub;
					}
					else
					{
						$activityBudgets = $this->context->itemActivityYearlyBudgetRepository->findAllByID($activity->ID);
						foreach($activityBudgets as $budget)
						{
							$totalBudget += $budget->LaborCosts + $budget->SubcontractingCosts + $budget->TravelCosts + $budget->MaterialCosts;
							if($budget->Year >= Date('Y'))
							{
								$totalBudgetFromCurrentYear += $budget->LaborCosts + $budget->SubcontractingCosts + $budget->TravelCosts + $budget->MaterialCosts;
							}
						}
					}
			}
			$items[$i]['TargetValue'] = $totalBudget;
			$items[$i]['TargetValueFromCurrentYear'] = $totalBudgetFromCurrentYear;
            $i++;
			}
		asort($items);
		
        $this->template->items = $items;
		//prepare url for ajax action handle first change
        $url1 = str_replace('?', '?do=firstChange&', $this->link('Item:'));
        $this->template->linkToSignal1 = $url1;
		
		//prepare url for ajax action handle second change
        $url2 = str_replace('?', '?do=secondChange&', $this->link('Item:'));
        $this->template->linkToSignal2 = $url2;
		
		// cuz of some kind of bug in snippet, needs to be filled variable _form with FilterItemForm???
		$this->template->_form = $this['filterItemForm'];
    }
    
	/*
	 * Shows detail of selected Strap Item
	 * 
	 * @param int $id Strap Item ID.
	 */
    public function renderShowItem($id)
    {
		$item = $this->context->itemRepository->find($id);
		if(is_null($item))
		{
			$this->flashMessage("Selected Strap Item with ID: " . $id . " does not exist.", 'notice');
			$this->redirect('default');
		}
		$this->template->itemID = $item->ID;
		
		// EC licence check
		// Find minimal required licence for item according to licence of all activities owned by item
		$item_activities = $this->context->itemActivityRepository->findActiveByItemID($item->ID);
		$all_licences = $this->context->ecLicenceRepository->findAll();
		$proposed_licence = array();
		foreach ($item_activities as $activity)
		{
			if ($all_licences[$item->ECLicenceID]->Value > $all_licences[$activity->ECLicenceID]->Value)
				$proposed_licence[$all_licences[$activity->ECLicenceID]->Value] = $all_licences[$activity->ECLicenceID]->Name;
		}
		if (count($proposed_licence))
		{
			$min_value = $this->context->ecLicenceRepository->findMaxValue();
			foreach ($proposed_licence as $value => $name)
				$min_value = ($min_value < $value) ? $min_value : $value;
			
			$this->flashMessage('Item licence should be updated, because some activity has licence with higher priority. Minimal required licence should be: ' . $proposed_licence[$min_value], 'info');
		}
		
        $formDefaults = array();
        $formDefaults['id'] = $item->ID;
        $formDefaults['customID'] = $item->customID;
        $formDefaults['name'] = $item->Name;
		$formDefaults['cluster'] = $item->ResponsibleOrgUnitID;
		$formDefaults['targetTRL'] = $item->TargetTRL;
		$formDefaults['TRLyear'] = $item->TargetTRLYear;
		$formDefaults['description'] = $item->Description;
		$formDefaults['ECLicenceID'] = $item->ECLicenceID;
        $form = $this['detailStrapItemForm'];
		
		$clusters = $itemCluster = array();
		// STRAP-ADMIN may see all clusters, but others may see only theirs
		$responsibleUnit = $this->context->organizationUnitRepository->find($item->ResponsibleOrgUnitID);
		
		if ($this->getUser()->isInRole(UserRole::ROLE_STRAP_ADMIN))
			$clusters = $this->context->organizationUnitRepository->findAllChildrenByType($this->context->globalSetting->get('orgUnit.id.ATE'), OrganizationUnit::ORG_UNIT_TYPE_CLUS);
		else
			$clusters = array($responsibleUnit->ID => $responsibleUnit);
		
		// set clusters
		foreach ($clusters as $clus)
			$itemCluster[$clus->ID] = $clus->Name;
		
		if($responsibleUnit->Status == false)
			$itemCluster[$responsibleUnit->ID] = $responsibleUnit->Name;
		$form['cluster']->setItems($itemCluster);

		//set default values
        $form->setDefaults($formDefaults);
		
		//disable buttons if user has not STRAP CL role
		if(!$this->isAllowed(self::RESOURCE_STRAP_ITEM, array(self::ACTION_EDIT, self::ACTION_DELETE)))
		{
			//also disable buttons if user is not CL of selected technical group
			if(Environment::getUser()->getId() != strtolower($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($item->ResponsibleOrgUnitID)->parent_ID)->Leader))
			{
				$form['update']->setDisabled(true);
				$form['delete']->setDisabled(true);
			}
		}
		if(!$this->isAllowed(self::RESOURCE_STRAP_ACTIVITY, array(self::ACTION_CREATE)))
		{
			//also disable buttons if user is not CL of selected technical group
			if(Environment::getUser()->getId() != strtolower($this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($item->ResponsibleOrgUnitID)->parent_ID)->Leader))
			{
				$form['createNewActivity']->setDisabled(true);
			}
		}
		
		//but enable for STRAP Admin
		if($this->isAllowed(self::RESOURCE_STRAP_ITEM, array(self::ACTION_EDIT, self::ACTION_DELETE)))
		{
			$form['update']->setDisabled(false);
			$form['delete']->setDisabled(false);
			$form['createNewActivity']->setDisabled(false);
		}
		if($this->isAllowed(self::RESOURCE_STRAP_ACTIVITY, array(self::ACTION_CREATE)))
		{
			$form['createNewActivity']->setDisabled(false);
		}

        $this->template->form = $form;
		
		//find all activities
		$activities = $this->context->itemActivityRepository->findByItemID($item->ID);
		$this->template->activities = $activities;
		
		//Get data for Strap Item Activity budget overview
		$years = $targets = $pursuits = $projects = array();
		$currentYear = Date('Y');
		for($year = Date('Y'); $year <= $currentYear+10; $year++)
		{
			$pursuits[$year] = 0;
			$targets[$year] = 0;
			$projects[$year] = 0;
		}
		for($year = Date('Y'); $year <= $currentYear+10; $year++)
		{
			$years[$year] = $year;
			foreach($activities as $activity)
			{
				if($activity->Active == 1)
				{
					$budget = $this->context->itemActivityYearlyBudgetRepository->find($activity->ID, $year);
					if($budget && !($activity->Type == ItemActivity::ITEM_ACTIVITY_TYPE_PROJECT && $year == $currentYear))
					{
						if($activity->Type == ItemActivity::ITEM_ACTIVITY_TYPE_NEED_TO_PURSUE)
							$targets[$year] += $budget->LaborCosts + $budget->TravelCosts + $budget->MaterialCosts + $budget->SubcontractingCosts;
						if($activity->Type == ItemActivity::ITEM_ACTIVITY_TYPE_PURSUIT)
						{
							$pursuit = $this->context->pursuitRepository->findAllPursuitsByActivityID($activity->ID);
							if (count($pursuit) == 1)
							{
								$key = key($pursuit);
								if(!($pursuit[$key]->Status == Pursuit::PURSUIT_STATUS_CLOSED && 
										($pursuit[$key]->ClosureResult == Pursuit::PURSUIT_CLOSURE_RESULT_LOST || 
										$pursuit[$key]->ClosureResult == Pursuit::PURSUIT_CLOSURE_RESULT_ON_HOLD || 
										$pursuit[$key]->ClosureResult == Pursuit::PURSUIT_CLOSURE_RESULT_STOPPED)))
								{
									$targets[$year] += $budget->LaborCosts + $budget->TravelCosts + $budget->MaterialCosts + $budget->SubcontractingCosts;
									$probabilityOfWin = $pursuit[$key]->ProbabilityOfWin;
									$pursuits[$year] += ($budget->LaborCosts + $budget->TravelCosts + $budget->MaterialCosts + $budget->SubcontractingCosts)*$probabilityOfWin;
								}
							}
							else
							{
								$denominator = 0;
								foreach($pursuit as $pur)
								{
									if(!($pur->Status == Pursuit::PURSUIT_STATUS_CLOSED && 
											($pur->ClosureResult == Pursuit::PURSUIT_CLOSURE_RESULT_LOST || 
											$pur->ClosureResult == Pursuit::PURSUIT_CLOSURE_RESULT_ON_HOLD || 
											$pur->ClosureResult == Pursuit::PURSUIT_CLOSURE_RESULT_STOPPED)))
									{
										$denominator += ($budget->LaborCosts + $budget->TravelCosts + $budget->MaterialCosts + $budget->SubcontractingCosts)*$pur->ProbabilityOfWin;
									}
								}
								$targets[$year] += $budget->LaborCosts + $budget->TravelCosts + $budget->MaterialCosts + $budget->SubcontractingCosts;
								$pursuits[$year] = $denominator;
							}
						}
						else
							$pursuits[$year] += 0;
						if($activity->Type == ItemActivity::ITEM_ACTIVITY_TYPE_PROJECT)
						{
							$targets[$year] += $budget->LaborCosts + $budget->TravelCosts + $budget->MaterialCosts + $budget->SubcontractingCosts;
							$projects[$year] += ($budget->LaborCosts + $budget->TravelCosts + $budget->MaterialCosts + $budget->SubcontractingCosts)*$activity->ProjectBudgetUsage;
						}
						else
							$projects[$year] += 0;
					}
					elseif($activity->Type == ItemActivity::ITEM_ACTIVITY_TYPE_PROJECT && $year == $currentYear)
					{
						$project = $this->context->projectRepository->find($activity->ProjectID);
						$reporter = new ProjectEACReporter($this->context, $project, $year);
						try
						{
							$projects[$year] += $reporter->getProjectLabourPlannedCostsMonthTotals()->sum()*$activity->ProjectBudgetUsage;
						}
						catch (InvalidStateException $e)
						{
							$this->flashMessage($e->getMessage(), 'error');
							Debugger::log($e->getMessage(), Debugger::ERROR);
							$this->redirect('default');
						}
						$projects[$year] += $reporter->getProjectTravelPlannedCostsMonthTotals()->sum()*$activity->ProjectBudgetUsage;
						$projects[$year] += $reporter->getProjectMaterialPlannedCostsMonthTotals()->sum()*$activity->ProjectBudgetUsage;
						$projects[$year] += $reporter->getProjectSubcontractingPlannedCostsMonthTotals()->sum()*$activity->ProjectBudgetUsage;
						$targets[$year] += $reporter->getProjectLabourPlannedCostsMonthTotals()->sum();
						$targets[$year] += $reporter->getProjectTravelPlannedCostsMonthTotals()->sum();
						$targets[$year] += $reporter->getProjectMaterialPlannedCostsMonthTotals()->sum();
						$targets[$year] += $reporter->getProjectSubcontractingPlannedCostsMonthTotals()->sum();
					}
				}
			}
		}
		$this->template->years = $years;
		$this->template->targets = $targets;
		$this->template->pursuits = $pursuits;
		$this->template->projects = $projects;
		$this->template->all_licences = $all_licences;
    }
	
	/*
	 * Renders form for creating new Strap Item
	 */
	public function renderCreateItem()
	{
		if(!$this->isAllowed(self::RESOURCE_STRAP_ITEM, self::ACTION_CREATE))
		{
			$this->flashMessage('You don\'t have permission to create STRAP Item.', 'warning');
			$this->redirect('default');
		}
        $form = $this['createStrapItemForm'];
        $this->template->form = $form;
	}
	
    /**
     * Creates filter STRAP Item form.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentFilterItemForm($name)
    {
        $form = new AppForm($this, $name);
        
        $departments = array();
        $deps = $this->context->organizationUnitRepository->findAllChildrenByType($this->context->globalSetting->get('orgUnit.id.ATE'), OrganizationUnit::ORG_UNIT_TYPE_DEP);
        foreach ($deps as $dep)
				$departments[$dep->ID] = $dep->Name;
        $form->addSelect('first', 'Department', $departments)
				->setPrompt('*');
		
        $clusters = array();
        $cluss = $this->context->organizationUnitRepository->findAllChildrenByType($this->context->globalSetting->get('orgUnit.id.ATE'), OrganizationUnit::ORG_UNIT_TYPE_CLUS);
        foreach ($cluss as $clus)
				$clusters[$clus->ID] = $clus->Name;
        $form->addSelect('second', 'Cluster', $clusters)
				->setPrompt('*');
		
		$form->addSubmit('create', 'Create new Item')
				->onClick[] = callback($this, 'createNewItemClicked');
		if(!$this->isAllowed(self::RESOURCE_STRAP_ITEM, self::ACTION_CREATE))
			$form['create']->setDisabled(true);
    }
	
    /**
     * Load values to second select
     * @param int Department id
     */
    public function handleFirstChange($dep = null, $clus = null)
    {
		//select form changes
        $secondSelect = array();
        if ($dep) 
        {
            $departmet = $this->context->organizationUnitRepository->find($dep);
            $clusters = $this->context->organizationUnitRepository->findAllChildrenByType($this->context->globalSetting->get('orgUnit.id.ATE'), OrganizationUnit::ORG_UNIT_TYPE_CLUS);
            foreach ($clusters as $cluster)
                if (preg_match('#^' . $departmet->Path . '#', $cluster->Path))
                    $secondSelect[$cluster->ID] = $cluster->Name;
            $this['filterItemForm']['second']->setItems($secondSelect)
                    ->setPrompt('*');
        }
        else
        {
            $secondSelect = array();
            $clusters = $this->context->organizationUnitRepository->findAllChildrenByType($this->context->globalSetting->get('orgUnit.id.ATE'), OrganizationUnit::ORG_UNIT_TYPE_CLUS);
            foreach ($clusters as $cluster)
                $secondSelect[$cluster->ID] = $cluster->Name;
			$this['filterItemForm']['second']->setItems($secondSelect)
					->setPrompt('*');
        }
        $this->invalidateControl('select');
		
		$clusArray = array();
		//strap item changes
		if ($dep)
        {
            $cluss = $this->context->organizationUnitRepository->findAllChildren($dep);
			
			//default value in case we can't find any cluster
			if(!$cluss)
			{
				$clusArray[] = 1;
			}
			else
			{
				foreach ($cluss as $clus)
					$clusArray[] = $clus->ID;
			}
			$this->payload->filter = $clusArray;
			$this->invalidateControl('items');
        }
		else
		{
			$this->invalidateControl('items');
		}
    }
	
    /**
     * Load values to second select
     * @param int Cluster id
     */
    public function handleSecondChange($dep = null, $clus = null)
    {
		$clusArray = array();
		//strap item changes
        if ($clus)
        {
			$clusArray[] = $clus;
			$this->payload->filter = $clusArray;
			$this->invalidateControl('items');
        }
		else
		{
			if($dep)
			{
				$this->handleFirstChange($dep, $clus);
			}
			else
			{
				$this->invalidateControl('items');
			}
		}
    }
	
    /**
     * Creates general STRAP Item form.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentStrapItemForm($name)
    {
        $form = new AppForm($this, $name);

        $form->addHidden('id');
        $form->addText('name', 'Name', 46, 150)
				->addRule(FORM::FILLED, 'Name must be filled.');
        $form->addText('customID', 'Item ID', null, 20);

		// get all TG
		$arrayClus = array();
		$clusters = $this->context->organizationUnitRepository->findAllChildrenByType($this->context->globalSetting->get('orgUnit.id.ATE'), OrganizationUnit::ORG_UNIT_TYPE_CLUS);
		foreach($clusters as $clus)
			$arrayClus[$clus->ID] = $clus->Name;
        $form->addSelect('cluster', 'Cluster', $arrayClus)
				->addRule(FORM::FILLED, 'Cluster must be filled.');
				
		for($i = 0; $i <= self::MAX_TRL_VALUE; $i++)
			$TRLs[$i] = $i;
        $form->addSelect('targetTRL', 'Target TRL', $TRLs)
				->addRule(FORM::FILLED, 'Target TRL must be filled.');
        
        $form->addText('TRLyear', 'Target TRL Year', null, 4)
				// $^ regex means to match nothing, an empty string
				->addRule(FORM::PATTERN, 'Year must be four number integer.', '[0-9]{4}|[0]|$^');
		
		$form->addTextArea('description', 'Description', 55, 5);
		
		$form->addTextArea('ctq', 'Please indicate following  CTQs for the STRAP item -->', 55, 5)
				->setDefaultValue($this->context->globalSetting->get(self::CTQ_TEMPLATE_VALUE))
				->setAttribute('readonly', 'readonly');
		
		$licences = array();
		$all_licences = $this->context->ecLicenceRepository->findAll();
		foreach ($all_licences as $licence)
			$licences[$licence->ECLicenceID] = $licence->Name;
 	  	$form->addSelect('ECLicenceID', HPTForm::createLabel('Licence', 'Export control licence determines importance of given data. It usually depends on target customer.'), $licences)
				->setPrompt('')
			    ->setAttribute('style', 'width: 140px;');
		        $form['ECLicenceID']->addRule(Form::FILLED, 'Licence must be filled.');

        return $form;
    }
	
    /**
     * Creates create STRAP Item form.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentCreateStrapItemForm($name)
    {
        $form = $this->createComponentStrapItemForm($name);

		// get all CL's tech groups
        $clusters = array();
		$allClusters = array();
		
        // STRAP-ADMIN may see all clusters, but STRAP-CL may see only his clusters
		if ($this->getUser()->isInRole(UserRole::ROLE_STRAP_ADMIN))
		{
			$allClusters[] = $this->context->organizationUnitRepository->findAllChildrenByType($this->context->globalSetting->get('orgUnit.id.ATE'), OrganizationUnit::ORG_UNIT_TYPE_CLUS);
		}
		elseif($this->getUser()->isInRole(UserRole::ROLE_STRAP_CL))
		{
			$allClusters[] = $this->context->organizationUnitRepository->findByTypeAndLeader(OrganizationUnit::ORG_UNIT_TYPE_CLUS, Environment::getUser()->getId());
		}

        foreach ($allClusters as $arrayOfClusters)
			foreach($arrayOfClusters as $clus)
				$clusters[$clus->ID] = $clus->Name;
		$form['cluster']->setItems($clusters);
		$form['cluster']->setPrompt('- Choose Cluster -');
		
		$form['targetTRL']->setPrompt('- Choose Target TRL -');
		
        $form->addSubmit('save', 'Save')
                ->onClick[] = callback($this, 'strapItemFormSubmittedSave');
		if (!$this->isAllowed(self::RESOURCE_STRAP_ITEM, self::ACTION_CREATE))
			$form['save']->setDisabled(TRUE);
		
        $form->addSubmit('back', 'Back to items')
                ->setValidationScope(FALSE)
                ->onClick[] = callback($this, 'backClicked');
		
        return $form;
    }
	
    /**
     * Creates edit STRAP Item form.
     * 
     * @param string $name Name of the form.
     * @return AppForm Returns AppForm.
     */
    public function createComponentDetailStrapItemForm($name)
    {
        $form = $this->createComponentStrapItemForm($name);

        $form->addSubmit('update', 'Update')
                ->onClick[] = callback($this, 'strapItemFormSubmittedUpdate');
		
        $form->addSubmit('delete', 'Delete')
				->setValidationScope(FALSE)
                ->onClick[] = callback($this, 'strapItemFormSubmittedDelete');

        $form->addSubmit('back', 'Back to items')
                ->setValidationScope(FALSE)
                ->onClick[] = callback($this, 'backClicked');
		
        $form->addSubmit('createNewActivity', 'Create New Activity')
                ->setValidationScope(FALSE)
                ->onClick[] = callback($this, 'createNewActivityClicked');
		
        return $form;
    }
	
    /**
     * Strap Item Form Submitted - Update.
     * 
     * @param SubmitButton $button 
     */
    public function strapItemFormSubmittedUpdate(SubmitButton $button)
    {
        $entry = $button->form->getValues();
		// role test
		if ($this->isAllowed(self::RESOURCE_STRAP_ITEM, self::ACTION_EDIT))
		{
			if ($button->form->isValid())
			{				
				$item = $this->context->itemRepository->find($entry['id']);
				// Responsible organization unit has been changed, so create new custom id
				if ($item->ResponsibleOrgUnitID != $entry['cluster'])
				{
					$clus = $this->context->organizationUnitRepository->find($entry['cluster']);
					$dep = $this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($clus->Parent_ID)->Parent_ID);
					$prefix = $dep->Short . '-' . $clus->Short . '-'; // longest identical part of customID before order number.
					$item->CustomID =  $prefix . str_pad($this->context->itemRepository->getNextCustomIDNumber($prefix), 2, "0", STR_PAD_LEFT);
				}
				$item->Name = $entry['name'];
				$item->ResponsibleOrgUnitID = $entry['cluster'];
				$item->TargetTRL = $entry['targetTRL'];
				$item->TargetTRLYear = empty($entry['TRLyear']) ? 0 : $entry['TRLyear'];
				$item->Description = $entry['description'];
				// TODO
				// Check if it is possible to change licence
				// 1: level cannot be lower than the lowest level of child activity
				$item->ECLicenceID = $entry['ECLicenceID'];
				if ($this->context->itemRepository->update($item))
				{
					$this->flashMessage("Strap Item " . $item->Name . " updated successfully.", 'success');
					$this->redirect('showItem', $item->ID);
				}
				else
				{
					$this->flashMessage("Strap Item with ID:" . $item->CustomID . " saved unsuccessfully.", 'error');
					$this->redirect('showItem', $item->ID);
				}
            }
			else
			{
				$this->flashMessage("Invalid form values.");
				$this->redirect('showItem');
			}
		}
		else
		{
			$this->flashMessage("You are not authorized to update STRAP Item. CL or STRAP ADMIN role required.", 'error');
			$this->redirect('default');
		}
    }
	
    /**
     * Strap Item Form Submitted - Delete.
     * 
     * @param SubmitButton $button 
     */
    public function strapItemFormSubmittedDelete(SubmitButton $button)
    {
        $entry = $button->form->getValues();
		// role test
		if ($this->isAllowed(self::RESOURCE_STRAP_ITEM, self::ACTION_DELETE))
		{
			$item = $this->context->itemRepository->find($entry['id']);
			$item->Active = 0;
			$activities = $this->context->itemActivityRepository->findByItemID($item->ID);
			if ($this->context->itemRepository->update($item))
			{
				$success = true;
				foreach($activities as $activity)
				{
					$activity->Active = 0;
					if(!$this->context->itemActivityRepository->update($activity))
					{
						$success = false;
					}
				}
				if($success)
					$this->flashMessage("Strap Item " . $item->Name . "'s activities deleted successfully.", 'success');
				else
					$this->flashMessage("Strap Item " . $item->Name . "'s activities deleted unsuccessfully.", 'error');
				$this->flashMessage("Strap Item " . $item->Name . " deleted successfully.", 'success');
				$this->redirect('default');
			}
			else
			{
				$this->flashMessage("Strap Item with ID:" . $item->CustomID . " deleted unsuccessfully.", 'error');
				$this->redirect('showItem', $item->ID);
			}
		}
		else
		{
			$this->flashMessage("You are not authorized to delete STRAP Item. CL or STRAP ADMIN role required.", 'error');
			$this->redirect('default');
		}
    }
	
    /**
     * Strap Item Form Submitted - Save.
     * 
     * @param SubmitButton $button 
     */
    public function strapItemFormSubmittedSave(SubmitButton $button)
    {
        $entry = $button->form->getValues();
		// role test
		if ($this->isAllowed(self::RESOURCE_STRAP_ITEM, self::ACTION_CREATE))
		{
			if ($button->form->isValid())
			{
				$item = new Item();
				//custom id auto generated
				$clus = $this->context->organizationUnitRepository->find($entry['cluster']);
				$dep = $this->context->organizationUnitRepository->find($this->context->organizationUnitRepository->find($clus->Parent_ID)->Parent_ID);
				$prefix = $dep->Short . '-' . $clus->Short . '-'; // longest identical part of customID before order number.
				$item->CustomID =  $prefix . str_pad($this->context->itemRepository->getNextCustomIDNumber($prefix), 2, "0", STR_PAD_LEFT);
				$item->Name = $entry['name'];
				$item->ResponsibleOrgUnitID = $entry['cluster'];
				$item->TargetTRL = $entry['targetTRL'];
				$item->TargetTRLYear = empty($entry['TRLyear']) ? 0 : $entry['TRLyear'];
				$item->Description = $entry['description'];
				$item->ECLicenceID = $entry['ECLicenceID'];
				if ($this->context->itemRepository->save($item))
				{
					$this->flashMessage("Strap Item " . $item->Name . " saved successfully.", 'success');
					$this->redirect('showItem', $this->context->itemRepository->findByCustomID($item->CustomID)->ID);
				}
				else
				{
					$this->flashMessage("Strap Item with ID:" . $item->CustomID . " saved unsuccessfully.", 'error');
					$this->redirect('createItem');
				}
            }
			else
			{
				$this->flashMessage("Invalid form values.");
				$this->redirect('createItem');
			}
		}
		else
		{
			$this->flashMessage("You are not authorized to save STRAP Item. CL or PEC role required.", 'error');
			$this->redirect('default');
		}
    }
	
    /**
     * Go back button redirects back to :default.
     * 
     * @param SubmitButton $button Go back button.
     */
    public function backClicked(SubmitButton $button)
    {
        $this->redirect('default');
    }
	
    /**
     * Create new item button redirects to create item view.
     * 
     * @param SubmitButton $button Create new item button.
     */
    public function createNewItemClicked(SubmitButton $button)
    {
        $this->redirect('createItem');
    }
	
    /**
     * Create new item activity button redirects to create activity view.
     * 
     * @param SubmitButton $button Create new item button.
     */
    public function createNewActivityClicked(SubmitButton $button)
    {
		$item_ID = $this->getHttpRequest()->getQuery('id');
        $this->redirect('Activity:createActivity', $item_ID);
    }
}