<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2015 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * ActualsTemp for iASAP repository access class.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class ActualsTempForIASAPRepository extends Object
{
    /** @var IActualsTempForIASAPMapper */
    private $mapper;

    public function __construct(IActualsTempForIASAPMapper $mapper)
    {
        $this->mapper = $mapper;
    }	

    /**
     * Gets all actuals.
     * 
     * @return array array of Actuals
     */
    public function findAll()
    {
        return $this->mapper->findAll();
    }
	
    /**
     * Returns number all actuals.
     * 
     * @param DateTime $startDate
     * @param DateTime $endDate
     * @return int Number of stored actuals.
     */
    public function countActualsByRangeAndType(DateTime $startDate, DateTime $endDate)
    {
        return $this->mapper->countActualsByRangeAndType($startDate, $endDate);
    }
	
	/**
     * Moves actuals record.
     * 
     * @return boolean Returns true if move successfull, otherwiste returns false.
     */
    public function moveAll()
    {
        return $this->mapper->moveAll();
    }
	
    /**
     * Deletes all actuals.
     * 
	 * @return boolean
     */
    public function deleteAll()
    {
        return $this->mapper->deleteAll();
    }
    
    /**
     * Saves new Actuals record.
     * 
     * @param ActualsTempForIASAP $actual
     * @return boolean Returns true if save successfull, otherwiste returns false.
     */
    public function save(ActualsTempForIASAP $actual)
    {
        return $this->mapper->save($actual);
    }
}
