<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Class for accessing AOPs from database using dibi.
 *
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 */
class AOPDibiMapper extends DibiMapper implements IAOPMapper
{
	/**
	 * Creates AnnualOperatingPlan instance from DibiRow.
	 * 
	 * @param DibiRow $row
	 * @return	AnnualOperatingPlan 
	 */
    private function loadAOP(DibiRow $row)
    {
		$aop = new AnnualOperatingPlan($row->Year);
		$col_names = array(	1 => 'Jan', 
							2 => 'Feb', 
							3 => 'Mar', 
							4 => 'Apr', 
							5 => 'May', 
							6 => 'Jun', 
							7 => 'Jul', 
							8 => 'Aug', 
							9 => 'Sep', 
							10 => 'Oct', 
							11 => 'Nov', 
							12 => 'Dec');
		foreach ($col_names as $month => $col_name)
			$aop->setMonthAOPHours($row->$col_name, $month);
		return $aop;
    }	

	/**
	 * Returns AOP for selected year.
	 * 
	 * @param int $year year
	 * @return	AnnualOperationPlan of NULL if not found.
	 */
	public function find($year)
	{
		$aop_db_result = $this->conn->query('SELECT * FROM [AOPCalendar] WHERE [Year] = %u', $year)->fetch();
		if ($aop_db_result)
			return $this->loadAOP($aop_db_result);
		else
			return NULL;
	}

	/**
	 * Returns AOP for selected year for selected user.
	 * 
	 * Returns whole budget of hours which doesn't mean it have to be vacant
	 * (depends on assignments of hours to worker).
	 * 
	 * @param int $year year
	 * @param int $person_id ID of worker/employee.
	 * @return	AnnualOperationPlan of NULL if not found.
	 */
	public function findForPerson($year, $person_id)
	{
		$base_aop = $this->find($year);
		if ($base_aop == NULL)
			return NULL;
		$aop_db_result = $this->conn->query('SELECT * FROM [Hour] WHERE [Year] = %u AND [EID] = %s', $year, $person_id)->fetch();
		if ($aop_db_result)
		{
			if ($aop_db_result->IsAOP)
			//if (is_numeric($aop_db_result->Contract) && is_numeric($aop_db_result->Yield))
			{
				// TODO: rounding according to eCharge? e.g. 1.2, 1.7 (for three quarters), ...
				for ($i = 1; $i <= 12; $i++)
					$base_aop->setMonthAOPHours(ceil(($base_aop->getMonthAOPHours($i) * $aop_db_result->Contract * $aop_db_result->Yield)), $i);
				return $base_aop;
			}
			else
				return $this->loadAOP($aop_db_result);
		}
		else
			return $base_aop;
	}
	    
    public function getYears()
    {
        $aop_db_result = $this->conn->query('SELECT [Year] FROM [AOPCalendar]')->fetchAll();
		$arr = array();
        if ($aop_db_result)
        {            
            foreach ($aop_db_result as $year)
            {
                $arr[$year->Year] = $year->Year;
            }
            return $arr;
        }
        else
			return NULL;
    }
}
