<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * CostCenter represents center for invoicing labour work.
 * Cost center has diffrent CostCenterLabourRates for every year.
 *
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 */
class CostCenter extends Object
{
	/** @var string */
	private $id;

	/** @var string */
	private $name;

	/** @var string */
	private $taskNamePrefix;
	
	/** @var int */
	private $plant;

	/** @var array of CostCenterLabourRates. Yearly rates of labour work per year*/
	private $rates;
	
	/** @var boolean Mark if work center is active or inactive.*/
    private $status = TRUE;
	
	public function __construct()
	{
	}

    /**
     * Sets cost center ID.
     * 
     * @param $id string
     */
	public function setID($id)
	{
		$this->id = $id;
	}

    /**
     * Gets cost center ID.
     * 
     * @return string
     */
	public function getID()
	{
		return $this->id;
	}	
	
    /**
     * Sets cost center name.
     * 
     * @param string $name
     */
	public function setName($name)
	{
		$this->name = $name;
	}

    /**
     * Gets cost center name.
     * 
     * @return string
     */
	public function getName()
	{
		return $this->name;
	}	

    /**
     * Sets cost center task name prefix.
     * 
     * @param string $prefix
     */
	public function setTaskNamePrefix($prefix)
	{
		$this->taskNamePrefix = $prefix;
	}

    /**
     * Gets cost center task name prefix.
     * 
     * @return string
     */
	public function getTaskNamePrefix()
	{
		return $this->taskNamePrefix;
	}	
	
    /**
     * Sets cost center plant.
     * 
     * @param $plant int
     */
	public function setPlant($plant)
	{
		$this->plant = $plant;
	}

    /**
     * Gets cost center plant.
     * 
     * @return int
     */
	public function getPlant()
	{
		return $this->plant;
	}	

	/**
	 * Gets labour rate object if it is defined for selected year.
	 * 
	 * @param int $year
	 * @return CostCenterLabourRates object or empty object if it is not available.
	 */
	public function getYearLabourRate($year)
	{
		if (NumericUtils::isPositiveInteger($year))
		{
			if (isset($this->rates[$year]))
				return $this->rates[$year];
			else //TODO: Alert about missing labour rate
			{
				$rate = new CostCenterLabourRates();
				$rate->Year = $year;
				return $rate;
			}
		}
		else
			throw new InvalidArgumentException('Year must be positive integer. Given: ' . $year . '.');
	}
	
	/**
	 * Check if labour rate exists for selected year.
	 * 
	 * @param int $year
	 * @return boolean True if labour rate for given year exists, otherwise false.
	 */
	public function labourRateExists($year)
	{
		if (isset($this->rates[$year]))
			return true;
		else
		{
			return false;
		}
	}

	/**
	 * Sets labour rates for a year.
	 * 
	 * @param int $year
	 * @param CostCenterLabourRates $rates
	 * @return float
	 */
	public function setYearLabourRate($year, CostCenterLabourRates $rates)
	{
		if (is_int($year))
			$this->rates[$year] = $rates;
		else
			throw new InvalidArgumentException('Year must be integer value. wrong param: ' . $year);
	}
        
	/**
	 * Gets labour rate years as array.
	 * 
	 * @return array Returns array or empty array if no years defined.
	 */
	public function getLabourRateYears()
	{
        $years = array();
		if (count($this->rates))
            foreach ($this->rates as $CostCenterLabourRates)
                $years[] = $CostCenterLabourRates->Year;
		return $years;
	}
	
	/**
	 * Sets WC status.
     * @param boolean $status
     */
    public function setStatus($status)
    {
        $this->status = ($status) ? TRUE : FALSE;
    }

    /**
	 * Gets WC status.
     * @return boolean
     */
    public function getStatus()
    {
        return $this->status;
    }
}
