<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Class for accessing customers from database using dibi.
 *
 * @author Jiri Zajic <jiri.zajic@honeywell.com>
 */
class CustomerDibiMapper extends DibiMapper implements ICustomerMapper
{
	/**
	 * Creates Customer instance from DibiRow.
	 * 
	 * @param DibiRow $row
	 * @return	Customer 
	 */
    private function loadCustomer(DibiRow $row)
    {
		$customer = new Customer();
		$customer->ID = $row->Customer_ID;
		$customer->Name = $row->Name;
		$customer->Responsible = $row->Responsible;
		$customer->Remarks = $row->Remarks;
		return $customer;
    }	

    /**
     * Saves customer.
     * 
     * @param Customer $customer customer
     * @return boolean Returns true if customer is successfully saved, otherwise false.
     */
    public function save(Customer $customer)
    {
        try
        {
            $array = array();
            $array['Name'] = $customer->Name;
            $array['Responsible'] = $customer->Responsible;
            $array['Remarks'] = $customer->Remarks;
            $db_result = $this->conn->insert('Customer', $array)->execute();
                        $customer->ID = $this->conn->insertId();
            return true;
        }
        catch (DibiException $e)
        {
            Debugger::log("Saving Customer with Name = " . $customer->Name . " failed. " . $e->getMessage(), Debugger::ERROR);
            return false;
        }
    }

    /**
     * Updates customer.
     * 
     * @param Customer $customer customer
     * @return boolean Returns true if customer is successfully updated, otherwise false.
     */
    public function update(Customer $customer)
    {
        try
        {
            $array = array();
            $array['Name'] = $customer->Name;
            $array['Responsible'] = $customer->Responsible;
            $array['Remarks'] = $customer->Remarks;
            $db_result = $this->conn->update('Customer', $array)->where('[Customer_ID] = %i', $customer->ID)->execute();
            return true;
        }
        catch (DibiException $e)
        {
            Debugger::log("Customer update with ID = " . $customer->ID . " and Name = " . $customer->Name . " failed. " . $e->getMessage(), Debugger::ERROR);
            return false;
        }
    }
	
	/**
	 * Returns customer.
	 * 
	 * @param string $id Customer ID.
	 * @return Customer or NULL if not found.
	 */
	public function findCustomer($id)
	{
		$customer_db_result = $this->conn->query('SELECT * FROM [Customer] WHERE [Customer_ID] = %s', $id)->fetch();
		if ($customer_db_result)
		{
			$customer = $this->loadCustomer($customer_db_result);
			return $customer;
		}
		else
			return NULL;
	}

	/**
	 * Returns all customers as an array sorted by name.
	 * 
	 * @return array associative array of Customer as value and its ID as a key
	 */
	public function findAllCustomers()
	{
		$customers_db_result = $this->conn->query('SELECT * FROM [Customer] ORDER BY [Name] ASC')->fetchAll();
		$customers = array();
		foreach ($customers_db_result as $row)
		{
			$customer = $this->loadCustomer($row);
			$customers[$customer->ID] = $customer;
		}
		return $customers;
	}
	
}
