<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2014 Honeywell International spol. s r.o.
 *
 * For the full copyright and licence information, please view
 * the file licence.txt that was distributed with this source code.
 * @package models
 */

/**
 * Mapper for accessing ECLicenceName from database using dibi.
 *
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
class ECLicenceNameDibiMapper extends DibiMapper implements IECLicenceNameMapper
{
	/**
	 * Creates ECLicenceName instance from DibiRow.
	 * @param DibiRow $row
	 * @return ECLicenceName
	 */
    private function load(DibiRow $row)
    {
		$licence_name = new ECLicenceName();
		$licence_name->ECLicenceNameID = $row->ECLicenceName_ID;
		$licence_name->Name = $row->Name;
		return $licence_name;
    }
	
	/**
	 * Saves ECLicenceName.
	 * @param ECLicenceName $licence_name
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function save(ECLicenceName $licence_name)
	{
		try
        {
            $array = array();
            $array['Name'] = $licence_name->Name;
            $db_result = $this->conn->insert('ECLicenceName', $array)->execute();
                        $licence_name->ECLicenceNameID = $this->conn->insertId();
            return TRUE;
        }
        catch (DibiException $e)
        {
            Debugger::log("Saving ECLicenceName with Name = " . $licence_name->Name . "failed. " . $e->getMessage(), Debugger::ERROR);
            return FALSE;
        }
	}
	
	/**
	 * Updates ECLicenceName.
	 * @param ECLicenceName $licence_name
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function update(ECLicenceName $licence_name)
	{
		try
        {
            $array = array();
            $array['ECLicenceName_ID'] = $licence_name->ECLicenceNameID;
            $array['Name'] = $licence_name->Name;
            $db_result = $this->conn->update('ECLicenceName', $array)->where('[ECLicenceName_ID] = %i', $licence_name->ECLicenceNameID)->execute();
            return TRUE;
        }
        catch (DibiException $e)
        {
            Debugger::log("ECLicenceName update with ID = " . $licence_name->ECLicenceNameID . " failed. " . $e->getMessage(), Debugger::ERROR);
            return FALSE;
        }
	}
	
	/**
	 * Deletes ECLicenceName.
	 * @param int $id ECLicenceName id.
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function delete($id)
	{
		try
		{
		    $db_result = $this->conn->delete('[ECLicenceName]')->where('[ECLicenceName_ID] = %i', $id)->execute();
			if ($db_result)
				Debugger::log("ECLicenceName with ID = " . $id . " was deleted.", Debugger::INFO);
			else
				Debugger::log("Deleting of ECLicenceName with ID = " . $id . " failed.", Debugger::ERROR);
			return ($db_result) ? TRUE : FALSE;
		}
        catch (DibiException $e)
        {
            Debugger::log("Deleting of ECLicenceName with ID = " . $id . " failed: " . $e->getMessage(), Debugger::ERROR);
            return FALSE;
        }
	}
	
	/**
	 * Finds ECLicenceName by id.
	 * @param int $id EC licence id.
	 * @return ECLicenceName or NULL if not found.
	 */
	public function find($id)
	{
		$db_result = $this->conn->select('*')->from('[ECLicenceName]')->where('[ECLicenceName_ID] = %i', $id)->fetch();
		if ($db_result !== FALSE)
			return $this->load($db_result);
		else
			return NULL;
	}
	
	/**
	 * Finds all ECLicenceNames.
	 * @return array Array of ECLicenceName or empty array.
	 */
	public function findAll()
	{
		$db_result = $this->conn->select('*')->from('[ECLicenceName]')->orderBy('[Name]')->fetchAll();     
		$licence_name_array = array();
        if ($db_result !== FALSE)
        {
            foreach ($db_result as $row)
                $licence_name_array[$row->ECLicenceName_ID] = $this->load($row);
        }		
		return $licence_name_array;
	}
	
	/**
	 * Finds all ECLicenceName by name.
	 * @param string $name
	 * @return ECLicenceName or NULL if not found.
	 */
	public function findByName($name)
	{
		$db_result = $this->conn->select('*')->from('[ECLicenceName]')->where('[Name] = %s', $name)->fetch();
		if ($db_result !== FALSE)
			return $this->load($db_result);
		else
			return NULL;
	}
}
