<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Interface for accessing actuals cost.
 *
 * @author Jiri Zajic <jiri.zajic@honeywell.com>
 */
interface IActualsCostMapper
{
	/**
	 * Returns all actuals costs.
	 * 
	 * @return array associative array of Actuals.
	 */
	public function findAll();
	
	/**
     * Returns all actuals costs for single task
     * 
     * @return array Array of arrays (years) of arrays (fiscal months)
     * of Actuals Cost records for single task.
     */
    public function findAllForTask($id);
	
	/**
     * Gets single actuals cost record.
     * --- MOSTLY FOR DEBUGGING ---
     * 
     * @return ActualsCost ActualsCost single record
     */
    public function findSingle();
	
	/**
	 * Function drops data from selected year.
	 * 
	 * @param int $year
	 * @return boolean Returns true if success, otherwise returns false.
	 */
	public function deleteDataFromYear($year, $source);
	
	/**
	 * Function imports data from array where items are ActualsCost objects.
	 * 
	 * @param array $actualCostsArray array of ActualsCost
	 */
	public function importActualsCost($actualCostsArray);
	
}
