<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2013 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Interface for accessing project charter.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
interface IProjectCharterApproverMapper
{
	/**
	 * Saves project charter approver.
	 * 
	 * @param ProjectCharterApprover $projectCharterApprover
	 * @return boolean
	 */
	public function save(ProjectCharterApprover $projectCharterApprover);

	/**
	 * Updates project charter approver.
	 * 
	 * @param ProjectCharterApprover $projectCharterApprover
     * @return boolean
	 */
	public function update(ProjectCharterApprover $projectCharterApprover);
	
	/**
	 * Deletes existing project charter approver.
	 * 
	 * @param int $projectCharterApprover_id ProjectCharterApprover ID.
	 * @return boolean
	 */
	public function delete($projectCharterApprover_id);
    
	/**
	 * Finds project charter approver by  project charter id.
	 * 
	 * @param int $projectCharterApprover_id ProjectCharter ID.
	 * @return	ProjectCharterApprover or NULL if not found.
	 */
	public function find($projectCharterApprover_id);
    
	/**
	 * Finds all project charter approver by project charter id and version.
	 * 
	 * @param int $projectCharter_id ProjectCharter ID.
     * @param int $version Version of round of approval.
	 * @return	array Associative array of ProjectCharterApprover where key is approver eid or NULL if not found.
	 */
	public function findAllApprover($projectCharter_id, $version);
    
    /**
	 * Find out if project charter is approved by all approvers.
	 * 
	 * @param int $projectCharter_id ProjectCharter ID.
     * @param int $version Version of round of approval.
	 * @return	boolean True if project charter is approved otherwise false.
	 */
	public function isApproved($projectCharter_id, $version);
}
