<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2013 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Interface for accessing project charter budget.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
interface IProjectCharterBudgetMapper 
{
/**
	 * Saves Project charter budget.
	 * 
	 * @param ProjectCharter $projectCharter
	 */
	public function save(ProjectCharterBudget $projectCharterBudget);
    
	/**
	 * Updates Project charter budget.
	 * 
	 * @param ProjectCharter $projectCharter
	 */
	public function update(ProjectCharterBudget $projectCharterBudget);
    
	/**
	 * Deletes Project charter budget.
	 * 
	 * @param int $id Project charter ID.
	 */
	public function delete($id);
	
	/**
	 * Deletes all Project Charter Budgets with specified Project Charter ID and Version.
	 * 
	 * @param int $projectCharterID
	 * @param int $version
	 * @return boolean
	 */
	public function deleteByProjectCharterIDAndVersion($projectCharterID, $version);
	
	/**
	 * Finds Project charter budget by id.
	 * 
	 * @param int $id Project charter ID.
	 * @return	Project charter or NULL if not found.
	 */
	public function find($id);
        
    /**
	 * Finds all project charter budgets.
	 * 
     * @param int $projectCharterID Should be ID of existing project charter.
     * @param int $version Version of ProjectCharterBudgetHistory.
	 * @return array Array of ProjectCharterBudget.
	 */
	public function findByProjecCharterIDAndVersion($projectCharterID, $version);
}
