<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Interface for accessing newly found projects stubs in import from SAP.
 *
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 */
interface IProjectFoundMapper
{
	/**
	 * Saves project stub.
	 * 
	 * @param ProjectFound $project
	 * @return boolean
	 */
	public function save(ProjectFound $project);
    
	/**
	 * Updates info for project stub.
	 * 
	 * @param ProjectFoundInfo $project
	 * @return boolean
	 */
	public function updateInfo(ProjectFoundInfo $project);
	
	/**
	 * Finds project stub by SAP id including plans if any.
	 * 
	 * @param string $sap_id SAP ID.
	 * @return	ProjectFound or NULL if not found.
	 */
	public function findBySAPID($sap_id);

	/**
	 * Finds info for project stub by SAP id.
	 * 
	 * @param string $sap_id SAP ID.
	 * @return	ProjectFoundInfo or NULL if not found.
	 */
	public function findInfoBySAPID($sap_id);
	
	/**
	 * Finds all infos for found project stubs.
	 * 
	 * @return array Array of ProjectFoundInfo where SAP ID is key.
	 */
	public function findAllInfos();
	
	/**
	 * Deletes found project stub by SAP ID.
	 * 
	 * @param string $id found project stubs SAP ID.
	 * @return boolean Return true if delete was successfull, otherwise returns false.
	 */
	public function delete($sap_id);

	/**
	 * Puts project stub identified by SAP ID on blacklisted.
	 * 
	 * @return	boolean
	 */
	public function putOnBlacklist($sap_id);

	/**
	 * Returns whether project identified by SAP ID is blacklisted.
	 * 
	 * @return	boolean
	 */
	public function isBlacklisted($sap_id);
	
	/**
	 * Deletes found project stubs and plans and leaves infos only for blacklisted.
	 * 
	 * @return boolean Return true if delete was successfull, otherwise returns false.
	 */
	public function deleteAllButBlacklisted();	
}
