<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011, 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Interface for accessing workable hours.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
interface IWorkableHourMapper
{
    /**
     * Search if workable hours of person for selected year exists.
     * 
     * @param int $year
     * @param string $person_id
     * @return Return true if search successfull, otherwise returns false. 
     */
    public function search($year, $person_id);
            
    /**
	 * Updates workable hour.
	 * 
	 * @param WorkableHour $workableHour
     * @return True or false if not updated
	 */
	public function update(WorkableHour $workableHour);

    /**
	 * Create workable hour.
	 * 
	 * @param WorkableHour $workableHour
	 * @return	True or false if not created
	 */
    public function create(WorkableHour $workableHour);
	
    /**
     * Deletes WorkableHour.
     * 
     * @param int $year
     * @param string $person_id
     * @return boolean Return true if delete successfull, otherwise returns false.
     */
    public function delete($year, $person_id);
    
    /**
     * Get yield of workanle hours for user and for selected year.
     *
     * @param string $id
     * @param int $year
     * @return float
     */
    public function getYield ($id, $year);
	
    /**
     * Get contract of workanle hours for user and for selected year.
     *
     * @param string $id
     * @param int $year
     * @return float
     */
    public function getContract ($id, $year);
}
