<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2016 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Repository of newly found persons stubs from isasap import.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class PersonFoundRepository extends Object
{
    /** @var IPersonFoundMapper */
 	private $mapper;

    public function __construct(IPersonFoundMapper $mapper)
    {
        return $this->mapper = $mapper;
    }	

	/**
	 * Saves found person
	 * 
	 * @param PersonFound $person
	 * @return boolean
	 */
	public function save(PersonFound $person)
	{
		return $this->mapper->save($person);
	}
    
	/**
	 * Updates found person
	 * 
	 * @param PersonFound $person
	 * @return boolean
	 */
	public function update(PersonFound $person)
	{
		return $this->mapper->update($person);
	}

	/**
	 * Finds person stub by EID.
	 * 
	 * @param string $eid EID.
	 * @return	PersonFound or NULL if not found.
	 */
	public function findByEID($eid)
	{
		return $this->mapper->findByEID($eid);
	}
	
	/**
	 * Finds all PersonFound.
	 * 
	 * @return array Array of Persons where EID is key.
	 */
	public function findAll()
	{
		return $this->mapper->findAll();
	}
	
	/**
	 * Finds all infos for found person stubs.
	 * 
	 * @return array Array of PersonFound where EID is key.
	 */
	public function findAllBlacklisted()
	{
		return $this->mapper->findAllBlacklisted();
	}
	
	/**
	 * Finds all infos for found person stubs.
	 * 
	 * @return array Array of PersonFound where EID is key.
	 */
	public function findAllNonBlacklisted()
	{
        return $this->mapper->findAllNonBlacklisted();
	}
	
	/**
	 * Deletes found person stub by EID.
	 * 
	 * @param string $eid found person EID
	 * @return boolean Return true if delete was successfull, otherwise returns false.
	 */
	public function delete($eid)
	{
		return $this->mapper->delete($eid);
	}
}
