<?php

/**
 * This file is part of the HON Tool
 *
 * Copyright (c) 2009, 2016 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Repository for accessing project charter checklist.
 *
 * @author Leos Navratil <leos.navratil@honeywell.com>
 */
class ProjectCharterChecklistRepository extends Object
{
    /** @var IProjectCharterChecklistMapper */
 	private $mapper;

    public function __construct(IProjectCharterChecklistMapper $mapper)
    {
        $this->mapper = $mapper;
    }
	
	/**
	 * Finds all checklist records related to certain Project Charter ID.
	 * 
	 * @param int $projectCharterID
	 * @return array of ProjectCharterChecklist objects.
	 */
	public function findByProjectCharterID($projectCharterID)
	{
		return $this->mapper->findByProjectCharterID($projectCharterID);
	}
	
	/**
	 * Saves a ProjectCharterChecklist object into the DB.
	 * 
	 * @param ProjectCharterChecklist $projectCharterChecklist
	 * @return bool True on successful insertion.
	 */
	public function save(ProjectCharterChecklist $projectCharterChecklist)
	{
		return $this->mapper->save($projectCharterChecklist);
	}
	
	/**
	 * Updates a ProjectCharterChecklist object in the DB.
	 * 
	 * @param ProjectCharterChecklist $projectCharterChecklist
	 * @return bool True on successful update.
	 */
	public function update(ProjectCharterChecklist $projectCharterChecklist)
	{
		return $this->mapper->update($projectCharterChecklist);
	}
}