<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2016 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Interface for accessing project planning charter item.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
interface IProjectPlanningCharterItemMapper
{
	/**
	 * Saves project planning charter item.
	 * 
     * @param ProjectPlanningCharterItem $projectPlanningCharterItem Project planning charter item
	 * @return boolean
	 */
	public function save(ProjectPlanningCharterItem $projectPlanningCharterItem);
    
	/**
	 * Updates project planning charter item.
	 * 
	 * @param ProjectPlanningCharterItem $projectPlanningCharterItem Project planning charter item
	 * @return boolean
	 */
	public function update(ProjectPlanningCharterItem $projectPlanningCharterItem);
	
	/**
	 * Deletes existing project planning charter item.
	 * 
	 * @param int $projectPlanningCharterItem_id
	 * @return boolean
	 */
	public function delete($projectPlanningCharterItem_id);
    
	/**
	 * Returns project planning charter item by its id.
	 * 
	 * @param int $id ProjectPlanningCharterItem ID.
	 * @return ProjectPlanningCharterItem
	 */
	public function find($id);
	
	/**
	 * Returns the count of rows with specified type
	 * 
	 * @param int $projectPlanningCharterID Project ID.
	 * @param array $types Type of the records to count, e.g. 'Person', 'OrganizationUnit'.
	 * @return int The count of rows with specified type.
	 */
	public function countRecordsByProjectPlanningCharterIDAndType($projectPlanningCharterID, $types);
	
	/**
	 * Returns rows related to Planning Project Charter ID with specified Type
	 * 
	 * @param int $projectPlanningCharterID Planning Project Charter ID.
	 * @param string $type Type of the records to find, e.g. 'Person', 'OrganizationUnit', 'Subcontractor', 'Other'.
	 * @return array $projectPlanningCharterItem_array
	 */
	public function findByProjectPlanningCharterIDAndType($projectPlanningCharterID, $type);
	
	/**
	 * Returns project planning charter item by project planning charter id.
	 * 
	 * @param int $projectPlanningCharterID ProjectPlanningCharter ID.
	 * @return array of ProjectPlanningCharterItem or empty array if not found
	 */
	public function findByProjectPlanningCharterID($projectPlanningCharterID);

	/**
	 * Returns all project planning charter items.
	 * 
	 * @return array of ProjectPlanningCharterItem or empty array if not found
	 */
	public function findAll();
	
	public function findAllPeopleByProjectPlanningCharterID($projectPlanningCharterID);
	
	public function findAllOrgUnitsByProjectPlanningCharterIDByOrganizationUnit_ID($projectPlanningCharterID, $orgUnitID);
}