<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2016 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * ProjectPlanningCharter represents basic object for project planning charter.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class ProjectPlanningCharter extends Object
{
	/* possible ProjectPlanningCharter types */
	const PROJECT_PLANNING_CHARTER_TYPE_HRS = 'HRS';
	const PROJECT_PLANNING_CHARTER_TYPE_SUB = 'SUB';
	const PROJECT_PLANNING_CHARTER_TYPE_TRV = 'TRV';
	const PROJECT_PLANNING_CHARTER_TYPE_MAT = 'MAT';

	/** @var int ProjectPlanningCharter ID */
	private $id;

	/** @var int Project ID */
	private $projectID;
	
	/** @var int Year */
	private $year;

	/** @var string Name */
	private $name;

	/** @var string Type */
	private $type;

	public function __construct()
	{
		
	}

	/**
	 * Sets ProjectPlanningCharter ID.
	 * 
	 * @param int $id
	 */
	public function setID($id)
	{
		if (is_int($id + 0))
		{
			$this->id = $id;
		}
		else
		{
			throw new InvalidArgumentException('ID must be integer. Wrong param: ' . $id);
		}
	}

	/**
	 * Gets ProjectPlanningCharter ID.
	 * 
	 * @return int
	 */
	public function getID()
	{
		return $this->id;
	}

	/**
	 * Sets ProjectID.
	 * 
	 * @param int $projectID
	 */
	public function setProjectID($projectID)
	{
		if (is_int($projectID + 0))
		{
			$this->projectID = $projectID;
		}
		else
		{
			throw new InvalidArgumentException('ProjectID must be integer. Wrong param: ' . $projectID);
		}
	}

	/**
	 * Gets ProjectID.
	 * 
	 * @return int
	 */
	public function getProjectID()
	{
		return $this->projectID;
	}


	/**
	 * Sets Name.
	 * 
	 * @param string $varchar
	 */
	public function setName($varchar)
	{
		if (is_string($varchar . ''))
		{
			$this->name = $varchar;
		}
		else
		{
			throw new InvalidArgumentException('Name must be string. Wrong param: ' . $varchar);
		}
	}

	/**
	 * Gets Name.
	 * 
	 * @return string
	 */
	public function getName()
	{
		return $this->name;
	}
	
	/**
	 * Sets Year.
	 * 
	 * @param int $year
	 */
	public function setYear($year)
	{
		if (is_int($year + 0))
		{
			$this->year = $year;
		}
		else
		{
			throw new InvalidArgumentException('Year must be integer. Wrong param: ' . $year);
		}
	}

	/**
	 * Gets Year.
	 * 
	 * @return int
	 */
	public function getYear()
	{
		return $this->year;
	}

	/**
	 * Sets Type.
	 * 
	 * @param string $type
	 */
	public function setType($type)
	{
		if (in_array($type, array_keys(ProjectPlanningCharter::getTypes())))
		{
			$this->type = $type;
		}
		else
		{
			throw new InvalidArgumentException('Type must be enum. Wrong param: ' . $type);
		}
	}

	/**
	 * Gets Type.
	 * 
	 * @return string
	 */
	public function getType()
	{
		return $this->type;
	}

	/**
	 * Returns array of available Type.
	 * 
	 * @return array
	 */
	public static function getTypes()
	{
		return array(
			self::PROJECT_PLANNING_CHARTER_TYPE_HRS => self::PROJECT_PLANNING_CHARTER_TYPE_HRS,
			self::PROJECT_PLANNING_CHARTER_TYPE_SUB => self::PROJECT_PLANNING_CHARTER_TYPE_SUB,
			self::PROJECT_PLANNING_CHARTER_TYPE_TRV => self::PROJECT_PLANNING_CHARTER_TYPE_TRV,
			self::PROJECT_PLANNING_CHARTER_TYPE_MAT => self::PROJECT_PLANNING_CHARTER_TYPE_MAT
		);
	}

}
