<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Mapper for accessing projects from database using dibi.
 *
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 */
class ProjectDibiMapper extends DibiMapper implements IProjectMapper
{

	/**
	 * Creates Project instance from DibiRow.
	 * 
	 * @param DibiRow $row
	 * @return	Project 
	 */
    private function load(DibiRow $row)
    {

		$project = new Project();
		$project->ID = $row->Project_ID;
		$project->SAP_ID  = $row->SAP_ID;
        $project->EU_SAP_ID  = $row->EU_SAP_ID;
		$project->PIPM = $row->PIPM;
		$project->TM = $row->TM;
		$project->PMOE = $row->PMOE;
		$project->PPaC = $row->PPaC;
		$project->Name = $row->Name;
		$project->Type = $row->Type;
		$project->Customer = $row->Customer;
		$project->Responsibility = $row->Responsibility;
		$project->Description = $row->Description;
		$project->Date = $row->Date;
		$project->Phase = $row->Phase;
		$project->State = $row->State;
		$project->Remark = $row->Remark;
		$project->ECORemark = $row->ECORemark;
		$project->LastStateChange = $row->LastStateChange;
		$project->KeyCode = $row->KeyCode;
        $project->EuKeyCode = $row->EUKeyCode;
		$project->PMOSupport = $row->PMO;
		// start and end dates are returned from database as timestamp (even if date format) => drop time
		// TODO: find a better solution
		if ($row->Start != '')
		{
			$dt = explode(' ', $row->Start);
			$project->Start = $dt[0];
		}
		else
			$project->Start = $row->Start;
		if ($row->End != '')
		{
			$dt = explode(' ', $row->End);
			$project->End = $dt[0];
		}
		else
			$project->End = $row->End;
		$project->ProgramID = $row->Program_ID;
		$project->CallID = $row->Call_ID;
		$project->ResponsibleUnit = $row->ResponsibleUnit;
		$project->ECLicenceID = $row->ECLicence_ID;
		$project->Fake = $row->Fake;
		$project->RealCostShare = $row->RealCostShare;
		$project->Plant = $row->Plant;
		return $project;
	}	

	/**
	 * Saves new project.
	 * 
	 * @param Project $project
	 * @return boolean
	 */
	public function save(Project $project)
	{
        try
        {
            $array = array();
			$array['PIPM%sN'] = $project->getPIPM();
			$array['TM%sN'] = $project->getTM();
			$array['PMOE%sN'] = $project->getPMOE();
			$array['PPaC%sN'] = $project->getPPaC();
            $array['Name'] = $project->getName();
            $array['SAP_ID'] = $project->getSAPID();
            $array['EU_SAP_ID'] = $project->getEU_SAP_ID();
            $array['Type'] = $project->getType();
            $array['Customer'] = $project->getCustomer();
            $array['Responsibility'] = $project->getResponsibility();
            $array['Description'] = $project->getDescription();
            $array['Date'] = date('Y-m-d');
            $array['Phase'] = $project->getPhase();
            $array['State'] = $project->getState();
			$array['Remark'] = $project->getRemark();
			$array['ECORemark'] = $project->getECORemark();
            // LastStateChange is set by CURRENT_TIMESTAMP() function
			$array['KeyCode'] = $project->getKeyCode();
            $array['EuKeyCode'] = $project->getEuKeyCode();
			$array['PMO'] = $project->getPMOSupport();
			$array['Start%sN'] = $project->getStart();
			$array['End%sN'] = $project->getEnd();
			$array['Program_ID'] = $project->getProgramID();
			$array['Call_ID'] = $project->getCallID();
			$array['ResponsibleUnit'] = $project->getResponsibleUnit();
			$array['ECLicence_ID'] = $project->getECLicenceID();
			$array['Fake'] = $project->getFake();
			$array['RealCostShare'] = $project->getRealCostShare();
			if($project->getFake())
				$array['Plant'] = $project->getPlant();
			else
				$array['Plant'] = 0;
            $this->conn->insert('Project', $array)->execute();
			$project->ID = $this->conn->insertId();
			return true;
        }
        catch (DibiException $e)
        {
            Debugger::log("Insert of project with SAP ID = ".$project->getSAPID()." failed: ".$e->getMessage(), Debugger::ERROR);
            return false;
        }
	}
	
	/**
	 * Updates existing project.
	 * 
	 * Updates only attributes that are updatable.
	 * 
	 * @param Project $project
	 * @return boolean
	 */
	public function update(Project $project)
	{
        try
        {
            $array = array();
            $array['EU_SAP_ID'] = $project->getEU_SAP_ID();
            $array['PIPM%sN'] = $project->getPIPM();
            $array['TM%sN'] = $project->getTM();
            $array['PMOE%sN'] = $project->getPMOE();
            $array['PPaC%sN'] = $project->getPPaC();
            $array['Name'] = $project->getName();
            $array['Type'] = $project->getType();
            $array['Customer'] = $project->getCustomer();
            $array['Responsibility'] = $project->getResponsibility();
            $array['Description'] = $project->getDescription();
			// Date of creation cannot be changed
            $array['Phase'] = $project->getPhase();
            $array['State'] = $project->getState();
			$array['Remark'] = $project->getRemark();
			$array['ECORemark'] = $project->getECORemark();
			// LastStateChange ???
			$array['KeyCode'] = $project->getKeyCode();
            $array['EuKeyCode'] = $project->getEuKeyCode();
			$array['PMO'] = $project->getPMOSupport();
			$array['Start%sN'] = $project->getStart();
			$array['End%sN'] = $project->getEnd();
			$array['Program_ID'] = $project->getProgramID();
			$array['Call_ID'] = $project->getCallID();
			$array['ResponsibleUnit'] = $project->getResponsibleUnit();
			$array['ECLicence_ID'] = $project->getECLicenceID();
			$array['Fake'] = $project->getFake();
			$array['RealCostShare'] = $project->getRealCostShare();
			$array['Plant'] = $project->getPlant();
            $this->conn->update('Project', $array)->where('[Project_ID] = %u', $project->getID())->execute();
			return true;
        }
        catch (DibiException $e)
        {
            Debugger::log("Update of project with ID = ".$project->getID()." failed: ".$e->getMessage(), Debugger::ERROR);
            return false;
        }
	}
	
	/**
	 * Deletes existing project.
	 * 
	 * @param int $project_id
	 * @return boolean
	 */
	public function delete($project_id)
	{
		try
		{
		    $result = $this->conn->delete('Project')->where('[Project_ID] = %i', $project_id)->execute();
			if ($result)
				Debugger::log("Project with ID = ".$project_id." was deleted.", Debugger::INFO);
			else
				Debugger::log("Deleting of project with ID = ".$project_id." failed.", Debugger::ERROR);
			return $result;
		}
        catch (DibiException $e)
        {
            Debugger::log("Deleting of project with ID = ".$project_id." failed: ".$e->getMessage(), Debugger::ERROR);
            return false;
        }
	}

	/**
	 * Gets project by id.
	 * 
	 * @param int $project_id
	 * @return Project
	 */
	public function find($project_id)
	{
		$project_db_result = $this->conn->select('*')->from('Project')->where('[Project_ID] = %u', $project_id)->fetch();
		if ($project_db_result !== FALSE)
			return $this->load($project_db_result);
		else
			return NULL;
	}

	/**
	 * Gets project by SAP ID.
	 * 
	 * @param string $sap_id
	 * @return Project
	 */
	public function findBySAPID($sap_id)
	{
		$project_db_result = $this->conn->select('*')->from('Project')->where('[SAP_ID] = %s', $sap_id)->fetch();
		if ($project_db_result !== FALSE)
			return $this->load($project_db_result);
		else
			return NULL;
	}

	/**
	 * Gets all Projects.
	 * 
	 * @return array Array of Projects where Project_ID is key.
	 */
	public function findAll()
	{
        $projects_array = array();
		$projects_db_result = $this->conn->select('*')->from('Project')->orderBy('Name', 'ASC')->fetchAll();        
		foreach ($projects_db_result as $project)
			$projects_array[$project->Project_ID] = $this->load($project);
        return $projects_array;
	}
    
    /**
	 * Gets all Projects which has taks plan in given year.
	 * 
     * @param int $year year.
	 * @return array Array of Projects where Project_ID is key.
	 */
	public function findAllProjectsInYear($year)
	{
        $projects_array = array();
		$projects_db_result = $this->conn->query("SELECT DISTINCT [Project].[*] FROM [Project]
                                                    LEFT JOIN [Task] ON [Task].[Project_ID] = [Project].[Project_ID]
                                                        LEFT JOIN [TaskPlan] ON [TaskPlan].[Task_ID] = [Task].[Task_ID]
                                                            WHERE [TaskPlan].[Year] = %u", $year)->fetchAll();
		foreach ($projects_db_result as $project)
			$projects_array[$project->Project_ID] = $this->load($project);
        return $projects_array;
    }
	
	/**
	 * Gets all Projects which has taks plan in given year and belongs to given SBE unit.
	 * 
     * @param int $year year.
	 * @param int $orgUnitID Organization unit ID.
	 * @return array Array of Projects where Project_ID is key.
	 */
	public function findAllSBEProjectsInYear($year, $orgUnitID)
	{
        $projects_array = array();
		$projects_db_result = $this->conn->query("SELECT DISTINCT [Project].[*] FROM [Project]
                                                    LEFT JOIN [Task] ON [Task].[Project_ID] = [Project].[Project_ID]
                                                        LEFT JOIN [TaskPlan] ON [TaskPlan].[Task_ID] = [Task].[Task_ID]
                                                            WHERE [TaskPlan].[Year] = %u AND [Project].[ResponsibleUnit] = %u", $year, $orgUnitID)->fetchAll();
		foreach ($projects_db_result as $project)
			$projects_array[$project->Project_ID] = $this->load($project);
        return $projects_array;
    }
    
	/**
	 * Gets project by task id.
	 * 
	 * @param int $task_id
	 * @return Project
	 */
	public function findProjectByTaskId($task_id)
	{
		$project_id = $this->conn->query('SELECT [Project_ID] FROM [Task] WHERE [Task_ID] = %u', $task_id)->fetchSingle();
		if ($project_id !== FALSE)
			return $this->find($project_id);
		else
			return NULL;
	}	
    
    /**
     * Gets all years of project.
     * 
     * @param int $project_id
     * @return array Array of available years
     */
    public function findProjectYears($project_id)
    {
		$db_result = $this->conn->query('SELECT DISTINCT [TaskPlan].[Year] FROM [Task]
                                            JOIN [TaskPlan] ON [Task].[Task_ID] = [TaskPlan].[Task_ID]
                                                WHERE [Task].[Project_ID] = %u ORDER BY [TaskPlan].[Year] ASC', $project_id)->fetchAll();
        $years = array();        
		foreach ($db_result as $year)		
			array_push($years, $year->Year);       
        return $years;
    }
    
    /**
     * Gets all current and future projects of person.
     * @param string $person_id person ID.
	 * @param int $year year.
     * @return array of Projects. Return array if find succesfull, otherwise returns null. 
     */
    public function findPersonAssignedAtProjectsInYearAndFuture($person_id, $year)
    {
        $db_result = $this->conn->query("SELECT DISTINCT [Project].* FROM [Person_Task]
                                        JOIN [Task] ON [Person_Task].[Task_ID] = [Task].[Task_ID]
                                            JOIN [Project] ON [Task].[Project_ID] = [Project].[Project_ID]
                                                WHERE [Person_Task].[Year] >= %i AND [Person_Task].[EID] = %s", $year, $person_id)->fetchAll();
        $projects = array();
        if ($db_result !== FALSE)
        {
            foreach($db_result as $row)
                $projects[$row->Project_ID] = $this->load($row);
            return $projects;        
        }
        else
            return NULL;
    }
	
    /**
     * Gets all projects of person in given year.
     * @param string $person_id person ID.
     * @param int $year year.
     * @return array of Projects. Return array if find succesfull, otherwise returns null. 
     */
    public function findPersonAssignedAtProjectsInYear($person_id, $year)
    {
        $db_result = $this->conn->query("SELECT DISTINCT [Project].* FROM [Person_Task]
                                        JOIN [Task] ON [Person_Task].[Task_ID] = [Task].[Task_ID]
                                            JOIN [Project] ON [Task].[Project_ID] = [Project].[Project_ID]
                                                WHERE [Person_Task].[Year] = %i AND [Person_Task].[EID] = %s", $year, $person_id)->fetchAll();
        $projects = array();
        if ($db_result !== FALSE)
        {
            foreach($db_result as $row)
                $projects[$row->Project_ID] = $this->load($row);
            return $projects;        
        }
        else
            return NULL;
    }
	
	/**
     * Gets all projects of person in given year where is not assigned on any task.
     * @param string $person_id person ID.
     * @param int $year year.
     * @return array of Projects. Return array if find succesfull, otherwise returns null. 
     */
    public function findPersonNotAssignedAtProjectsInYear($person_id, $year)
    {
        $db_result = $this->conn->query("SELECT DISTINCT [Project].[*] FROM [Actuals]
											JOIN [Task] ON [Task].[SAP_ID] = [Actuals].[ChargeNumber]
												JOIN [Project] ON [Task].[Project_ID] = [Project].[Project_ID]
													WHERE [Actuals].[Year] = %i AND [Actuals].[EID] = %s", $year, $person_id)->fetchAll();
        $projects = array();
        if ($db_result !== FALSE)
        {
            foreach($db_result as $row)
                $projects[$row->Project_ID] = $this->load($row);
            return $projects;        
        }
        else
            return NULL;
    }

    /**
     * Gets all projects where given person is involved as PI, PM, CL or PP&C
     *
     * @param string $person_id
     * @return array List of projects or empty array
     */
    public function findByPerson($person_id)
    {
        $db_result = $this->conn
            ->query('
                SELECT *
                FROM [Project]
                WHERE [PIPM] = %s OR
                      [TM] = %s OR
                      [PMOE] = %s OR
                      [PPaC] = %s
                ORDER BY [Name] ASC
            ', $person_id, $person_id, $person_id, $person_id)
            ->fetchAll();

        $projects = array();
        foreach ($db_result as $row)
        {
        	$project = $this->load($row);
            $projects[$project->ID] = $project;
        }

        return $projects;
    }
	
	/**
     * Gets Projects by ProjectFilter. Returns every project that matches all set conditions.
     * @param ProjectFilter $filter
     * @return array Of Projects or empty array
    */
	public function findByFilter(ProjectFilter $filter)
	{
		$current_year = date('Y');
		$db_result = $this->conn->select('*')->from('[Project]');
		
		if ($filter->Name)
            $db_result->where("[Name] LIKE %~like~", $filter->Name);
		if ($filter->SAPID)
            $db_result->where("[SAP_ID] LIKE %~like~", $filter->SAPID);
		if ($filter->KeyCode)
            $db_result->where("[KeyCode] LIKE %~like~", $filter->KeyCode);
		
		if ($filter->POValueMin && $filter->POValueMax)
            $db_result->where("
				[Project_ID] IN (SELECT [Project_ID] 
				                 FROM [POAttributesAndBudget]
								 WHERE [Year] = %s
								 GROUP BY [Project_ID]
								 HAVING SUM([POValue]) >= %f AND SUM([POValue]) <= %f)",
			    $current_year, $filter->POValueMin, $filter->POValueMax
		    );
		elseif ($filter->POValueMin)
			$db_result->where("
				[Project_ID] IN (SELECT [Project_ID]
				                 FROM [POAttributesAndBudget]
								 WHERE [Year] = %s
								 GROUP BY [Project_ID]
								 HAVING SUM([POValue]) >= %f)",
				$current_year, $filter->POValueMin
			);
		elseif ($filter->POValueMax)
			$db_result->where("
				[Project_ID] IN (SELECT [Project_ID]
				                 FROM [POAttributesAndBudget]
								 WHERE [Year] = %s
								 GROUP BY [Project_ID]
								 HAVING SUM([POValue]) <= %f)",
				$current_year, $filter->POValueMax
			);
		if ($filter->PONumber)
		{
			$db_result->where("[Project_ID] IN (SELECT [Project_ID] FROM [POAttributesAndBudget] WHERE [PONumber] LIKE %~like~ AND [Year] = %s
						UNION SELECT [Project_ID] FROM [Task] LEFT JOIN [TaskPONumber] 
								ON [TaskPONumber].[Task_ID] = [Task].[Task_ID] 
										WHERE [TaskPONumber].[PONumber] LIKE %~like~)", $filter->PONumber, $current_year, $filter->PONumber);
		}
		if ($filter->Start)
            $db_result->where("[Start] >= %d", $filter->Start);
		if ($filter->End)
            $db_result->where("[End] <= %d", $filter->End);
		if ($filter->PIPM)
            $db_result->where("[PIPM] = %s", $filter->PIPM);
		if ($filter->TM)
            $db_result->where("[TM] = %s", $filter->TM);
		if ($filter->PMOE)
            $db_result->where("[PMOE] = %s", $filter->PMOE);
		if ($filter->PPaC)
            $db_result->where("[PPaC] = %s", $filter->PPaC);
		if ($filter->PMO)
            $db_result->where("[PMO] = %s", $filter->PMO);
		if ($filter->Customer)
            $db_result->where("[Customer] = %i", $filter->Customer);
		if ($filter->Program)
            $db_result->where("[Program_ID] = %i", $filter->Program);
		if ($filter->Call)
            $db_result->where("[Call_ID] = %i", $filter->Call);
		if ($filter->Responsibility)
            $db_result->where("[Responsibility] = %i", $filter->Responsibility);
		if ($filter->ChargeNumber)
            $db_result->where("[Project_ID] IN (SELECT [Project_ID] FROM [Task] WHERE [SAP_ID] LIKE %~like~)", $filter->ChargeNumber);
		if (is_array($filter->ResponsibleUnit))
        {
            $responsible_units = $filter->ResponsibleUnit;
			if (!in_array('', $responsible_units)) // star selected == all selected
			{
				$conditions = array();
                foreach ($responsible_units as $unit)
                    array_push($conditions, array("[ResponsibleUnit] = %s", $unit));
				if (count($conditions))
                    $db_result->where('(%or)', $conditions);
			}
			
			if (count($responsible_units) == 0) // no unit selected
				$db_result->where('[ResponsibleUnit] IS NULL');
        }
		if (is_array($filter->Type))
		{
			$types = $filter->Type;
			if (!in_array('', $types)) // star selected == all selected
			{
				$conditions = array();
                foreach ($types as $type)
                    array_push($conditions, array("[Type] = %s", $type));
				if (count($conditions))
                    $db_result->where('(%or)', $conditions);
			}
			
			if (count($types) == 0) // no type selected
				$db_result->where('[Type] IS NULL');
		}
		if (is_array($filter->Phase))
		{
			$phases = $filter->Phase;
			if (!in_array('', $phases)) // star selected == all selected
			{
				$conditions = array();
                foreach ($phases as $phase)
                    array_push($conditions, array("[Phase] = %s", $phase));
				if (count($conditions))
                    $db_result->where('(%or)', $conditions);
			}
			
			if (count($phases) == 0) // no phase selected
				$db_result->where('[Phase] IS NULL');
		}
		if ($filter->State || ($filter->State == 0) && ($filter->State !== NULL) && ($filter->State !== ''))
            $db_result->where("[State] = %i", $filter->State);
		
		// fake(place holders) projects 
		if (is_array($filter->Fake)) 
		{ 
			$fakes = $filter->Fake; 
			if (!in_array('', $fakes)) // star selected == all selected 
			{ 
				$conditions = array(); 
				foreach ($fakes as $fake) 
					array_push($conditions, array("[Fake] = %i", $fake)); 
				if (count($conditions)) 
					$db_result->where('(%or)', $conditions); 
			}

			if (count($fakes) == 0) // fake is not selected 
				$db_result->where('[Fake] = %i', 2); 
		}
		
		// get result
		$db_result->orderBy('[Name] ASC');
		
//        $db_result->test();
        $db_result->fetchAll();

        $array_project = array();
        foreach($db_result as $row)
            $array_project[$row->Project_ID] = $this->load($row);

        return $array_project;		
	}
	
	/**
	 * Gets next project id.
	 * 
	 * @return int Project ID;
	 */
	public function getNextProjectID()
	{
		$db_result = $this->conn->query('SELECT MAX([Project_ID]) FROM [Project]')->fetch();
		if ($db_result === FALSE)
			return '1';
		else		
			return sprintf('%06s', $db_result['MAX(`Project_ID`)'] + 1);
	}
	
	/**
	 * Finds out if given SBE has active or planned project.
	 * 
	 * @param int $orgUnitID Organization unit ID.
	 * @return boolean if active or planned project found
	 */
	public function hasOrgUnitActiveOrPlannedProject($orgUnitID)
	{
		$db_result = $this->conn->query('SELECT * FROM [Project] WHERE ([Phase] = %s OR [Phase] = %s) AND [ResponsibleUnit] = %i', Project::PROJECT_PHASE_ACTIVE, Project::PROJECT_PHASE_PLANNED, $orgUnitID)->fetch();
		if ($db_result !== FALSE)
			return true;
		else
			return false;
    }
}