<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models\Import
 */

/**
 * Service for EAC details export.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class EACReportService extends object
{
    /** @var DIContainer DI context with application repositories access */
    private $context;

	/** @var ILogger Logging facility */
    private $logger;
	
	/** @var int Year to generation */
    private $year;
	
	/** @var Array of SBE Organizaiton unit objects */
    private $sbes;
	
	/** @var String Value for freeze user interface during report generation. */
    private $uiFreezeToken;
	
    /** @var string Path to storage EAC files. */
    private $eac_storage_dir;
	
	/**
	 * Creates service for tracking table export.
	 *  
	 * @param $context Application context.
	 * @param ILogger Object for logging the import progress.
	 */
    public function  __construct(DIContainer $context, ILogger $logger, $year, $sbe, $uiFreezeToken = null)
    {
        $this->context = $context;
		$this->logger = $logger;
		$this->year = $year;
		$this->sbes = $sbe;
		$this->uiFreezeToken = $uiFreezeToken;
		$this->eac_storage_dir = Environment::getConfig('eacDetails_storage_dir');
    }
	
    /**
	 * 
     * Generates EAC Details as a XLSX (MS-EXCEL file).
	 * File can be downloaded through browser and also file is saved to the public/EACDetails folder.
	 * 
     */
    public function runEACDetailsGeneration()
    {
		$objPHPExcel = new PHPExcel();
		
        $exec_time = 600;
	    if (!ini_set("max_execution_time", $exec_time)) 
		{
			$this->flashMessage('Setup of maximum execution time failed. Contact administrator.', 'error');
			trigger_error('Unable to setup maximum execution time to '.$exec_time.'.', E_USER_ERROR);
		}
		$lock = $this->context->createLock('EAC_Report', 600);
		if (!$lock->lock())
		{
			$this->logger->log('EAC generation start failed - active lock detected: ' . date('m-d-Y H:i:s'), ILogger::INFO);
            throw new EeacReportServiceException("Export of EAC Report is already running.");
		}
		$this->logger->log('EAC generation start: ' . date('m-d-Y H:i:s'), ILogger::INFO);
		
		$sheet = $objPHPExcel->getActiveSheet();
		$rowIterator = $sheet->getRowIterator();
		$cellIterator = $rowIterator->current()->getCellIterator();        
		$currency = "USD"; // TargetCurr
		$currencyLabel = 'CZK'; // SourceCurr
		$exchageRate = $this->context->exchangeRatesRepository->findYearRates($currencyLabel, $currency, $this->year);
		// Header     
		$cellIterator->current()->setValue("Project name");
		$cellIterator->next();
		$cellIterator->current()->setValue("PIPM");
		$cellIterator->next();
		$cellIterator->current()->setValue("CL");
		$cellIterator->next();
		$cellIterator->current()->setValue("PMOE");
		$cellIterator->next();
		$cellIterator->current()->setValue("PP&C");
		$cellIterator->next();
		$cellIterator->current()->setValue("Project Phase");
		$cellIterator->next();
		$cellIterator->current()->setValue("Project Type");
		$cellIterator->next();
		$cellIterator->current()->setValue("Customer");
		$cellIterator->next();
		$cellIterator->current()->setValue("Responsibility");
		$cellIterator->next();
		$cellIterator->current()->setValue("Budget");
		$cellIterator->next();
		$cellIterator->current()->setValue("Project SAP ID");
		$cellIterator->next();
		$cellIterator->current()->setValue("Task");
		$cellIterator->next();
		$cellIterator->current()->setValue("Task SAP ID");
		$cellIterator->next();
		$cellIterator->current()->setValue("CostShare");
		$cellIterator->next();
		$cellIterator->current()->setValue("Jan");
		$cellIterator->next();
		$cellIterator->current()->setValue("Feb");
		$cellIterator->next();
		$cellIterator->current()->setValue("Mar");
		$cellIterator->next();
		$cellIterator->current()->setValue("Apr");
		$cellIterator->next();
		$cellIterator->current()->setValue("May");
		$cellIterator->next();
		$cellIterator->current()->setValue("Jun");
		$cellIterator->next();
		$cellIterator->current()->setValue("Jul");
		$cellIterator->next();
		$cellIterator->current()->setValue("Aug");
		$cellIterator->next();
		$cellIterator->current()->setValue("Sep");
		$cellIterator->next();
		$cellIterator->current()->setValue("Oct");
		$cellIterator->next();
		$cellIterator->current()->setValue("Nov");
		$cellIterator->next();
		$cellIterator->current()->setValue("Dec");
		$cellIterator->next();
		$cellIterator->current()->setValue("Unit");
		$cellIterator->next();
		$cellIterator->current()->setValue("Placeholder project");
		$cellIterator->next();
		$cellIterator->current()->setValue("Cost Element");
		$cellIterator->next();
		$cellIterator->current()->setValue("Work Center");
		$cellIterator->next();
		$cellIterator->current()->setValue("Labor");
		$cellIterator->next();
		$cellIterator->current()->setValue("Task Type");
		$cellIterator->next();
		$cellIterator->current()->setValue("SBE name");
		$cellIterator->next();
		$cellIterator->current()->setValue("SBE short");
		$cellIterator->next();
		$cellIterator->current()->setValue("Project Plant code");
		$cellIterator->next();
		$cellIterator->current()->setValue("Generation time");
		$row = $cellIterator->current()->getRow();
		$col = $cellIterator->current()->getColumn();
		$sheet->setCellValue($col . ($row + 1), date('m-d-Y H:i:s'));
		$rowIterator->next();
		$cellIterator = $rowIterator->current()->getCellIterator();
		foreach($this->sbes as $sbe)
		{
			$allProjects = $this->context->projectRepository->findAllSBEProjectsInYear($this->year, $sbe->ID, true);
			// Data generating
			foreach ($allProjects as $project)
			{
				$reporter = new ProjectEACReporter($this->context, $project, $this->year);
				$tasks = $this->context->taskRepository->findPlannedProjectTasksInYear($project->ID, $this->year); 

				if($project->PIPM == null)
					$pipm = 'UNKNOWN WORKER: ' . $project->PIPM;
				else
					$pipm = $this->context->personRepository->find($project->PIPM)->surname. ', ' . $this->context->personRepository->find($project->PIPM)->firstname;            

				if($project->TM == null)
					$tm = 'UNKNOWN WORKER: ' . $project->TM;
				else
					$tm = $tm = $this->context->personRepository->find($project->TM)->surname. ', ' . $this->context->personRepository->find($project->TM)->firstname;

				if($project->PMOE == null)
					$pmoe = 'UNKNOWN WORKER: ' . $project->PMOE;
				else
					$pmoe = $this->context->personRepository->find($project->PMOE)->surname. ', ' . $this->context->personRepository->find($project->PMOE)->firstname;

				if($project->PPaC == null)
					$ppac = 'UNKNOWN WORKER: ' . $project->PPaC;
				else
					$ppac = $this->context->personRepository->find($project->PPaC)->surname. ', ' . $this->context->personRepository->find($project->PPaC)->firstname;

				if($project->Customer == null)
					$customer = 'UNKNOWN CUSTOMER: ' . $project->Customer;
				else
					$customer = $this->context->customerRepository->find($project->Customer)->Name;

				if($project->Responsibility == null)
					$responsibility = 'UNKNOWN RESPONSIBILITY: ' . $project->Responsibility;
				else
					$responsibility = $this->context->responsibilityRepository->find($project->Responsibility)->Name;

				foreach ($tasks as $task)
				{
					$hours = array();
					if($task->isLabourTask() && !$task->costAsLabour)
						$hours = $reporter->getTaskLabourEACHoursMonthTotals($task);
					elseif($task->costAsLabour)
						$hours = $reporter->getTaskCostAsLabourEACCostMonthTotals($task, $currency);
					else
						$hours = $reporter->getTaskNonLabourEACCostsMonthTotals($task, $currency);

					$cellIterator->current()->setValue($project->Name);
					$cellIterator->next();
					$cellIterator->current()->setValue($pipm);
					$cellIterator->next();
					$cellIterator->current()->setValue($tm);
					$cellIterator->next();
					$cellIterator->current()->setValue($pmoe);
					$cellIterator->next();
					$cellIterator->current()->setValue($ppac);
					$cellIterator->next();
					$cellIterator->current()->setValue($project->Phase);
					$cellIterator->next();
					$cellIterator->current()->setValue($project->Type);
					$cellIterator->next();
					$cellIterator->current()->setValue($customer);
					$cellIterator->next();
					$cellIterator->current()->setValue($responsibility);
					$cellIterator->next();
					$cellIterator->current()->setValue($this->context->poAttributesAndBudgetRepository->budgetByProjectIDAndYear($project->ID, $this->year));
					$cellIterator->next();
					$cellIterator->current()->setValue($project->SAPID);
					$cellIterator->next();
					$cellIterator->current()->setValue($task->name);
					$cellIterator->next();
					$cellIterator->current()->setValue($task->SAPID);
					$cellIterator->next();
					$cellIterator->current()->setValue($task->costShare);
					$cellIterator->next();

					for($i=1;$i<=12;$i++)
					{
						if($task->isLabourTask() && !$task->costAsLabour)
							$cellIterator->current()->setValue($hours[$i]);
						elseif($task->costAsLabour)
							$cellIterator->current()->setValue($hours[$i]*$exchageRate[$i]->Value);
						else
							$cellIterator->current()->setValue($hours[$i]*$exchageRate[$i]->Value);
						$cellIterator->next();
					}

					if($task->isLabourTask() && !$task->costAsLabour)
						$cellIterator->current()->setValue("hrs");
					else
						$cellIterator->current()->setValue($currencyLabel);                            
					$cellIterator->next();
					if($project->Fake)
						$cellIterator->current()->setValue('Yes');
					else
						$cellIterator->current()->setValue('No');
					$cellIterator->next();
					//$cellIterator->current()->setValue("");// Cost element placeholder
					$cellIterator->next();
					$cellIterator->current()->setValue($task->CostCenterID);
					$cellIterator->next();
					if($task->isLabourTask() && !$task->costAsLabour)
						$cellIterator->current()->setValue(1);
					else
						$cellIterator->current()->setValue(0);
					$cellIterator->next();
					if($task->Fake == Task::TASK_TYPE_SAP)
						$cellIterator->current()->setValue('SAP');
					elseif($task->Fake == Task::TASK_TYPE_PLACEHOLDER)
						$cellIterator->current()->setValue('Placeholder');
					else
						$cellIterator->current()->setValue('Planning');
					$cellIterator->next();
					$cellIterator->current()->setValue($sbe->Name);
					$cellIterator->next();
					$cellIterator->current()->setValue($sbe->Short);
					$cellIterator->next();
					$cellIterator->current()->setValue($project->Plant);
					$cellIterator->next();
					$rowIterator->next();
					$cellIterator = $rowIterator->current()->getCellIterator();
					$hours = null;
				}
			}
		}
		
		if(!is_null($this->uiFreezeToken))
			setcookie('fileDownloadToken', $this->uiFreezeToken);

        $objWriter = PHPExcel_IOFactory::createWriter($objPHPExcel, 'Excel2007');
        if (!file_exists($this->eac_storage_dir)) 
          mkdir($this->eac_storage_dir, 0777, TRUE);
		$fileName = null;
		if(count($this->sbes) > 1)
		{
			$fileName = 'AEE';
		}
		else
		{
			$fileName = $this->sbes[0]->Short;
		}
		if($this->year == date('Y'))
			$objWriter->save($this->eac_storage_dir . $fileName . '-EACReport.xlsx');
		else
			$objWriter->save($this->eac_storage_dir . $fileName . '-EACReport_' . $this->year . '.xlsx');
		
		$this->logger->log('EAC generation end: ' . date('m-d-Y H:i:s'), ILogger::INFO);
		$lock->unlock();
    }
}

class EeacReportServiceException extends Exception {}