<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2016 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models\Import
 */

/**
 * Service for project report.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class ProjectReportService extends ProjectEACReportService
{
	/** @var int Project ID */
	private $projectID;

	/**
	 * 
	 * @param int $projectID
	 * @param DIContainer $context
	 * @param ILogger $logger
	 * @param array $year
	 * @param int $uiFreezeToken
	 */
	public function __construct($projectID, DIContainer $context, ILogger $logger, $year, $uiFreezeToken = null)
	{
		parent::__construct($context, $logger, $year, "Project", $uiFreezeToken);
		$this->projectID = $projectID;
	}

	public function runProjectReportGeneration()
	{
		$this->logger->log('Project Report generation start: ' . date('m-d-Y H:i:s'), ILogger::INFO);

		// Data preperation
		// get project
		$project = $this->context->projectRepository->find($this->projectID);
		$tasks = array();
		if ($project == null)
		{
			throw new ProjectReportServiceException('Project with id: ' . $this->projectID . ' not found.');
		}
		// get projects year or end report generation if there is no data
		$oneYearReport = false;
		if ($this->year == null)
		{
			$this->year = $this->context->projectRepository->findProjectYears($project->ID);
			$tasks = $this->context->taskRepository->findAllProjectTasks($project->ID);
			if ($this->year == null)
			{
				throw new ProjectReportServiceException("There is no data to report.");
			}
		}
		else
		{
			$oneYearReport = true;
			$allTasks = $this->context->taskRepository->findAllProjectTasks($project->ID);
			//check every task if he has some data to report. 
			foreach($allTasks as $task)
			{
				//has some plan
				if($this->context->taskPlanRepository->findTaskYearPlan($task->ID, $this->year[0]))
				{
					$tasks[$task->ID] = $task;
					continue;
				}
				//has some actuals
				// This approche is way faster then taskRepository->findActiveProjectTasksInYear function
				if($task->isLabourTask())
				{
					if($this->context->workRepository->findPeopleWorkingOnTaskInYear($task->ID, $this->year[0]))
					{
						$tasks[$task->ID] = $task;
					}
				}
				else
				{
					if($this->context->costCenterRepository->findActualCostsYearSummary($task->ID, $this->year[0], 'USD')->sum() != 0)
					{
						$tasks[$task->ID] = $task;
					}
				}
			}
			if(empty($tasks))
			{
				throw new ProjectReportServiceException("There is no data to report.");
			}
		}
		
		$this->runProjectEACReportGeneration($tasks, $oneYearReport, $project->Name, $project->SAPID);
	}
}

class ProjectReportServiceException extends Exception
{
	
}