<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Repository of responsibilities.
 *
 * @author Jiri Zajic <jiri.zajic@honeywell.com>
 */
class ResponsibilityRepository extends Object
{
	/** @var IResponsibilityMapper */
    private $mapper;
	
	/** @var MultiLogger */
	private $multilog;

    public function __construct(IResponsibilityMapper $mapper)
    {
        $this->mapper = $mapper;
		$this->multilog = new MultiLogger();
		$batch_id = 'Responsibility-'.time().'-'.rand(1, 9);
		$this->multilog->add(Environment::getContext()->createLogger($batch_id, "Responsibility"));
    }
    
    /**
     * Saves Responsibility.
     * 
     * @param Responsibility $responsibility
     * @return boolean Returns true if update successfull, otherwiste returns false.
     */
    public function save(Responsibility $responsibility)
    {
		if($this->mapper->save($responsibility))
		{
			$this->multilog->log('Responsibility with ID: ' . $responsibility->ID . ' saved.', ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
    }
    
    /**
     * Updates Responsibility.
     * 
     * @param Responsibility $responsibility
     * @return boolean Returns true if update successfull, otherwiste returns false.
     */
    public function update(Responsibility $responsibility)
    {
		$oldObject = $this->find($responsibility->ID);
		if($this->mapper->update($responsibility))
		{
			$this->multilog->log('Responsibility with ID: ' . $responsibility->ID . ' saved. ' . $this->multilog->differences($oldObject, $responsibility), ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
    }
	
	/**
	 * Returns responsibility.
	 * 
	 * @param string $id Responsibility ID.
	 * @return Responsibility or NULL if not found.
	 */
	public function find($id)
	{
		return $this->mapper->findResponsibility($id);
	}

	/**
	 * Returns all responsibilities as an array sorted by name.
	 * 
	 * @return array associative array of Responsibility as value and its ID as a key
	 */
	public function findAll()
	{
		return $this->mapper->findAllResponsibilities();
	}

}
