<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2013 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * CustomerProgram repository access class.
 *
 * @author Vojtech Obrusnik <vojtech.obrusnik@honeywell.com>
 */
class CustomerProgramRepository extends Object
{
	/** @var ICustomerProgramMapper */
 	private $mapper;
	
	/** @var MultiLogger */
	private $multilog;

    public function __construct(ICustomerProgramMapper $mapper)
    {
        $this->mapper = $mapper;
		$this->multilog = new MultiLogger();
		$batch_id = 'Program-'.time().'-'.rand(1, 9);
		$this->multilog->add(Environment::getContext()->createLogger($batch_id, "Program"));
    }
    
	/**
	 * Saves program.
	 * @param CustomerProgram $program
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function save(CustomerProgram $program)
	{
		if($this->mapper->save($program))
		{
			$this->multilog->log('Program with ID: ' . $program->ProgramID . ' and Name: ' . $program->Program . ' saved.', ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
	}

	/**
	 * Updates program.
	 * @param CustomerProgram $program
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function update(CustomerProgram $program)
	{
		$oldObject = $this->find($program->ProgramID);
		if($this->mapper->update($program))
		{
			$this->multilog->log('Program with ID: ' . $program->ProgramID . ' and Name: ' . $program->Program . ' updated. ' . $this->multilog->differences($oldObject, $program), ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
	}
	
	/**
	 * Deletes program.
	 * @param int $id program ID.
	 * @return boolean TRUE if operation ended with success, FALSE otherwise.
	 */
	public function delete($id)
	{
		if($this->mapper->delete($id))
		{
			$this->multilog->log('Program with ID: ' . $id . ' deleted.', ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
	}
    
	/**
	 * Finds program by ID.
	 * @param int $id program ID.
	 * @return	CustomerProgram or NULL if not found.
	 */
	public function find($id)
	{
		return $this->mapper->find($id);
	}
	
	/** 
	 * Finds all programs.
	 * @return array Array of CustomerProgram or empty array.	
	 */
	public function findAll()
	{
		return $this->mapper->findAll();
	}
	
	/** 
	 * Finds programs by customer ID.
	 * @param int $id customer ID.
	 * @return array Array of CustomerProgram or empty array.	
	 */
	public function findByCustomer($id)
	{
		return $this->mapper->findByCustomer($id);
	}
}
