<?php

/**
 * This file is part of the ATE Tool - STRAP addon
 *
 * Copyright (c) 2009, 2013 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Interface for accessing STRAP ItemActivity.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
interface IItemActivityMapper
{
	/**
	 * Saves new STRAP item activity.
	 * 
	 * @param ItemActivity $item
	 * @return boolean
	 */
	public function save(ItemActivity $item);
	
	/**
	 * Updates existing STRAP item activity.
	 * 
	 * @param ItemActivity $item
	 * @return boolean
	 */
	public function update(ItemActivity $item);
	
	/**
	 * Deletes existing STRAP ItemActivity.
	 * 
	 * @param int $item
	 * @return boolean
	 */
	public function delete($item_id);

	/**
	 * Gets STRAP ItemActivity by id.
	 * 
	 * @param int $item_id
	 * @return ItemActivity or null if not found
	 */
	public function find($item_id);

	/**
	 * Gets all Strap Item Activities.
	 * 
	 * @return array Array of ItemActivity where Activity_ID is key or null if not found.
	 */
	public function findAll();
	
	/**
	 * Gets all Strap Item Activities belonging to STRAP item.
	 * 
	 * @param int $item_id
	 * @return array Array of ItemActivity where Activity_ID is key or null if not found.
	 */
	public function findByItemID($item_id);
	
	/**
	 * Gets all active Strap Item Activities belonging to STRAP item.
	 * 
	 * @param int $item_id
	 * @return array Array of ItemActivity where Activity_ID is key or empty array if not found.
	 */
	public function findActiveByItemID($item_id);
	
	/**
	 * Finds all strap item activities connected to one pursuit.
	 * 
	 * @param int $id Should be pursuit ID
	 * @return array Array of ItemActivity or empty array.
	 */
	public function findByPursuitID($id);
}
