<?php

/**
 * This file is part of the ATE Tool - STRAP addon
 *
 * Copyright (c) 2009, 2013 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * STRAP Item represents basic item for strategic planning.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class Item extends Object
{
	/** @var int */
	private $id;

	/** @var string custom eid */
	private $customID;

	/** @var string Item name*/
	private $name;

	/** @var int ID of organization unit*/
	private $responsibleOrgUnitID;
	
	/** @var int TRL*/
	private $targetTRL = 0;
	
	/** @var int TRL year*/
	private $targetTRLYear = 0;
	
	/** @var string Item name*/
	private $description;
	
	/** @var int Active*/
	private $active = 1;
	
	/** @var int ECLicence id */
	private $ECLicenceID;
	
	public function __construct()
	{
	}

    /**
     * Sets item ID.
     * 
     * @param int $id
     */
	public function setID($id)
	{
		if ($id > 0)
			$this->id = $id;
		else
			throw new InvalidArgumentException('STRAP Item ID must be integer greater than 0. Wrong param: '.$id);
	}

    /**
     * Gets item ID.
     * 
     * @return int
     */
	public function getID()
	{
		return $this->id;
	}	
	
    /**
     * Sets custom ID.
     * 
     * @param string $id 
     */
	public function setCustomID($id)
	{
		$this->customID = $id;
	}

    /**
     * Gets custom ID.
     * 
     * @return string
     */
	public function getCustomID()
	{
		return $this->customID;
	}
	
    /** 
     * Sets name. 
     *  
     * @param string $name  
     */ 
    public function setName($name) 
    { 
            $this->name = $name; 
    } 

    /** 
     * Gets name. 
     *  
     * @return string 
     */ 
    public function getName() 
    { 
            return $this->name; 
    } 
	
    /**
     * Sets responsible OrgUnit ID.
     * 
     * @param int $responsibleOrgUnit_ID
     */
	public function setResponsibleOrgUnitID($responsibleOrgUnit_ID)
	{
		if ((NumericUtils::isPositiveInteger($responsibleOrgUnit_ID)) || ($responsibleOrgUnit_ID === NULL))
			$this->responsibleOrgUnitID = $responsibleOrgUnit_ID;
		else
			throw new InvalidArgumentException('Responsible OrgUnit ID must be positive integer or NULL. Wrong param: ' . $responsibleOrgUnit_ID);
	}

    /**
     * Gets responsible OrgUnit ID.
     * 
     * @return int
     */
	public function getResponsibleOrgUnitID()
	{
		return $this->responsibleOrgUnitID;
	}	
	
    /**
     * Sets target TRL.
     * 
     * @param int $id
     */
	public function setTargetTRL($targetTRL)
	{
		$this->targetTRL = $targetTRL;
	}

    /**
     * Gets target TRL.
     * 
     * @return int
     */
	public function getTargetTRL()
	{
		return $this->targetTRL;
	}	
	
    /**
     * Sets target TRL year ID.
     * 
     * @param $id int
     */
	public function setTargetTRLYear($targetTRLYear)
	{
		$this->targetTRLYear = $targetTRLYear;
	}

    /**
     * Gets target TRL year ID.
     * 
     * @return int
     */
	public function getTargetTRLYear()
	{
		return $this->targetTRLYear;
	}	
	
    /** 
     * Sets Description. 
     *  
     * @param string $description  
     */ 
    public function setDescription($description) 
    { 
        $this->description = $description; 
    } 

    /** 
     * Gets Description. 
     *  
     * @return string 
     */ 
    public function getDescription() 
    { 
        return $this->description; 
    } 
	
    /**
     * Sets Active.
     * 
     * @param int $active
     */
	public function setActive($active)
	{
		$this->active = $active;
	}

    /**
     * Gets Active.
     * 
     * @return int
     */
	public function getActive()
	{
		return $this->active;
	}
	
	/**
     * Sets ECLicence id.
     * 
     * @param int $id
     */
	public function setECLicenceID($id)
	{
		if ($id > 0)
			$this->ECLicenceID = $id;
		else
			throw new InvalidArgumentException('ECLicence ID must be integer greater than 0. Wrong param: ' . $id);
	}

    /**
     * Gets ECLicence id.
     * 
     * @return int
     */
	public function getECLicenceID()
	{
		return $this->ECLicenceID;
	}	
}