<?php

/**
 * This file is part of the ATE Tool - STRAP addon
 *
 * Copyright (c) 2009, 2013 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Class for accessing STRAP Item Activity from database using dibi.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class ItemActivityDibiMapper extends DibiMapper implements IItemActivityMapper
{
	/**
	 * Creates ItemActivity instance from DibiRow.
	 * 
	 * @param DibiRow $row
	 * @return	ItemActivity
	 */
    private function load(DibiRow $row)
    {
		$item = new ItemActivity();
		$item->ID = $row->Activity_ID;
		$item->ItemID = $row->StrapItem_ID;
		$item->CustomID = $row->Custom_ID;
		$item->PursuitID = $row->Pursuit_ID;
		$item->ProjectID = $row->Project_ID;
        $item->NeedToPursueID = $row->NeedToPursue_ID;
		$item->TargetTRL = $row->TargetTRL;
		$item->TargetTRLYear = $row->TargetTRLYear;
		$item->Name = $row->Name;
		$item->Remarks = $row->Remarks;
		$item->TechnologyRoadmapDomain = $row->TechnologyRoadmapDomain;
        $item->MarketingProductManager = $row->MarketingProductManager;
		$item->PortfolioManager = $row->PortfolioManager;
		$item->ProductLine = $row->ProductLine;
		$item->RTCDirector = $row->RTCDirector;
		$item->Created = $row->Created;
		$item->Creator = $row->Creator;
        $item->CostShare = $row->CostShare;
		$item->ProjectBudgetUsage = $row->ProjectBudgetUsage;
		$item->PotentialCustomer = $row->PotentialCustomer;
		$item->Active = $row->Active;
		$item->LastUpdatedDate = $row->LastUpdatedDate;
		$item->UpdatedBy = $row->UpdatedBy;
		$item->ECLicenceID = $row->ECLicence_ID;
		return $item;
    }
	
	/**
	 * Saves new STRAP item activity.
	 * 
	 * @param ItemActivity $item
	 * @return boolean
	 */
	public function save(ItemActivity $item)
	{
        try
        {
            $array = array();
			$array['StrapItem_ID'] = $item->ItemID;
			$array['Custom_ID'] = $item->CustomID;
			$array['Pursuit_ID'] = $item->PursuitID;
			$array['Project_ID'] = $item->ProjectID;
			$array['NeedToPursue_ID'] = $item->NeedToPursueID;
			$array['TargetTRL'] = $item->TargetTRL;
			$array['TargetTRLYear'] = $item->TargetTRLYear;
			$array['Name'] = $item->Name;
			$array['Remarks'] = $item->Remarks;
			$array['TechnologyRoadmapDomain'] = $item->TechnologyRoadmapDomain;
			$array['MarketingProductManager'] = $item->MarketingProductManager;
			$array['PortfolioManager'] = $item->PortfolioManager;
			$array['ProductLine'] = $item->ProductLine;
			$array['RTCDirector'] = $item->RTCDirector;
			$array['Created'] = $item->Created;
			$array['Creator'] = $item->Creator;
			$array['CostShare'] = $item->CostShare;
			$array['ProjectBudgetUsage'] = $item->ProjectBudgetUsage;
			$array['PotentialCustomer'] = $item->PotentialCustomer;
			$array['Active'] = $item->Active;
			$array['LastUpdatedDate'] = new DateTime;
			$array['UpdatedBy'] = Environment::getUser()->getID();
			$array['ECLicence_ID'] = $item->ECLicenceID;
            $this->conn->insert('StrapItemActivity', $array)->execute();
			$item->ID = Dibi::getInsertId();
			return true;
        }
        catch (DibiException $e)
        {
            Debugger::log("Insert new STRAP ItemActivity by user = " . $item->CustomID . " failed: " . $e->getMessage(), Debugger::ERROR);
            return false;
        }
	}
	
	/**
	 * Saves linkage between Strap ItemActivity and Pursuit
	 * 
	 * @param int $activityID
	 * @param int $pursuitID
	 * @return boolean
	 */
	public function	savePursuitLinkage($activityID, $pursuitID)
	{
		$array = array();
		$array['Activity_ID'] = $activityID;
		$array['Pursuit_ID'] = $pursuitID;
		try
		{
			$this->conn->insert('StrapItemActivity_Pursuit', $array)->execute();
			return true;
		}
		catch (DibiException $e)
		{
            Debugger::log("Insert strap ItemActivity: " . $activityID . " linkage to Pursuit: " . $pursuitID . " failed: " . $e->getMessage(), Debugger::ERROR);
            return false;
		}
	}
	
	/**
	 * Deletes linkage between Strap ItemActivity and Pursuit
	 * 
	 * @param int $activityID
	 * @param int $pursuitID
	 * @return boolean
	 */
	public function	deletePursuitLinkage($activityID, $pursuitID)
	{
		try
		{
			$result = $this->conn->delete('StrapItemActivity_Pursuit')
									->where('[Activity_ID] = %i AND [Pursuit_ID] = %i', $activityID, $pursuitID)->execute();
			if ($result)
				Debugger::log("linkage between Strap ItemActivity: " . $activityID . " and Pursuit: " . $pursuitID . " was delted.", Debugger::INFO);
			else
				Debugger::log("Delete strap ItemActivity: " . $activityID . " linkage to Pursuit: " . $pursuitID . " failed.", Debugger::ERROR);
			return $result;
		}
		catch (DibiException $e)
		{
            Debugger::log("Delete strap ItemActivity: " . $activityID . " linkage to Pursuit: " . $pursuitID . " failed: " . $e->getMessage(), Debugger::ERROR);
            return false;
		}
	}
	
	/**
	 * Updates existing STRAP item activity.
	 * 
	 * @param ItemActivity $item
	 * @return boolean
	 */
	public function update(ItemActivity $item)
	{
        try
        {
            $array = array();
			$array['StrapItem_ID'] = $item->ItemID;
			$array['Custom_ID'] = $item->CustomID;
			$array['Pursuit_ID'] = $item->PursuitID;
			$array['Project_ID'] = $item->ProjectID;
			$array['NeedToPursue_ID'] = $item->NeedToPursueID;
			$array['TargetTRL'] = $item->TargetTRL;
			$array['TargetTRLYear'] = $item->TargetTRLYear;
			$array['Name'] = $item->Name;
			$array['Remarks'] = $item->Remarks;
			$array['TechnologyRoadmapDomain'] = $item->TechnologyRoadmapDomain;
			$array['MarketingProductManager'] = $item->MarketingProductManager;
			$array['PortfolioManager'] = $item->PortfolioManager;
			$array['ProductLine'] = $item->ProductLine;
			$array['RTCDirector'] = $item->RTCDirector;
			// creation date should not be updated.
			//$array['Created'] = $item->Created;
			$array['Creator'] = $item->Creator;
			$array['CostShare'] = $item->CostShare;
			$array['ProjectBudgetUsage'] = $item->ProjectBudgetUsage;
			$array['PotentialCustomer'] = $item->PotentialCustomer;
			$array['Active'] = $item->Active;
			$array['LastUpdatedDate'] = new DateTime;
			$array['UpdatedBy'] = Environment::getUser()->getID();
			$array['ECLicence_ID'] = $item->ECLicenceID;
            $this->conn->update('StrapItemActivity', $array)->where('[Activity_ID] = %i', $item->ID)->execute();
			return true;
        }
        catch (DibiException $e)
        {
            Debugger::log("Update of STRAP ItemActivity with ID = " . $item->ID . " failed: " . $e->getMessage(), Debugger::ERROR);
            return false;
        }
	}
	
	/**
	 * Deletes existing STRAP ItemActivity.
	 * 
	 * @param int $item
	 * @return boolean
	 */
	public function delete($item_id)
	{
		try
		{
		    $result = $this->conn->delete('StrapItemActivity')->where('[Activity_ID] = %i', $item_id)->execute();
			if ($result)
				Debugger::log("Strap Item Activity with ID = " . $item_id . " was deleted.", Debugger::INFO);
			else
				Debugger::log("Deleting of STRAP Item Activity with ID = " . $item_id . " failed.", Debugger::ERROR);
			return $result;
		}
        catch (DibiException $e)
        {
            Debugger::log("Deleting of STRAP Item Activity with ID = " . $item_id . " failed: ".$e->getMessage(), Debugger::ERROR);
            return false;
        }
	}

	/**
	 * Gets STRAP ItemActivity by id.
	 * 
	 * @param int $item_id
	 * @return ItemActivity or null if not found
	 */
	public function find($item_id)
	{
		$item_db_result = $this->conn->select('*')->from('StrapItemActivity')->where('[Activity_ID] = %u', $item_id)->fetch();
		if ($item_db_result !== FALSE)
			return $this->load($item_db_result);
		else
			return NULL;
	}

	/**
	 * Gets STRAP ItemActivity by custom id.
	 * 
	 * @param int $item_id
	 * @return ItemActivity or null if not found
	 */
	public function findByCustomID($item_id)
	{
		$item_db_result = $this->conn->select('*')->from('StrapItemActivity')->where('[Custom_ID] = %s', $item_id)->fetch();
		if ($item_db_result !== FALSE)
			return $this->load($item_db_result);
		else
			return NULL;
	}
	
	/**
	 * Gets all Strap Item Activities.
	 * 
	 * @return array Array of ItemActivity where Activity_ID is key or null if not found.
	 */
	public function findAll()
	{
        $items_array = array();
		$items_db_result = $this->conn->select('*')->from('StrapItemActivity')->orderBy('Name', 'ASC')->fetchAll();   
		if ($items_db_result !== FALSE)
		{
				foreach ($items_db_result as $item)
				{
					$items_array[$item->Activity_ID] = $this->load($item);
				}
				return $items_array;
		}
		else
			return null;
	}
	
	/**
	 * Gets all Strap Item Activities belonging to STRAP item.
	 * 
	 * @param int $item_id
	 * @return array Array of ItemActivity where Activity_ID is key or null if not found.
	 */
	public function findByItemID($item_id)
	{
        $items_array = array();
		$items_db_result = $this->conn->select('*')->from('StrapItemActivity')->where('[StrapItem_ID] = %i', $item_id)->fetchAll();   
		if ($items_db_result !== FALSE) 
		{
				foreach ($items_db_result as $item)
				{
					$items_array[$item->Activity_ID] = $this->load($item);
				}
				return $items_array;
		}
		else
			return null;
	}
	
	/**
	 * Gets all active Strap Item Activities belonging to STRAP item.
	 * 
	 * @param int $item_id
	 * @return array Array of ItemActivity where Activity_ID is key or empty array if not found.
	 */
	public function findActiveByItemID($item_id)
	{
		$db_result = $this->conn->select('*')->from('[StrapItemActivity]')->where('[StrapItem_ID] = %i AND [Active] = 1', $item_id)->fetchAll();
		$items_array = array();
		if ($db_result !== FALSE) 
		{
			foreach ($db_result as $item)
			    $items_array[$item->Activity_ID] = $this->load($item);
		}
		
		return $items_array;
	}
	
	/**
	 * Gets project allocaiotn from all strap item activities.
	 * 
	 * @param int $project_ID
	 * @return int $allocation
	 */
	public function findProjectAllocation($project_ID)
	{
        $allocation = 0;
		$items_db_result = $this->conn->query('SELECT SUM(ProjectBudgetUsage) FROM [StrapItemActivity] WHERE [Project_ID] = %i AND [Active] = 1', $project_ID)->fetch();
		$allocation = $items_db_result['SUM(ProjectBudgetUsage)'];
		
		return $allocation;
	}
	
	/**
	 * Finds all strap item activities connected to one pursuit.
	 * 
	 * @param int $id Should be pursuit ID
	 * @return array Array of ItemActivity or empty array.
	 */
	public function findByPursuitID($id)
	{
		$db_result = $this->conn->select('*')->from('StrapItemActivity')->where('[Pursuit_ID] = %i', $id)->fetchAll();
		$itemActivity_array = array();
        if ($db_result !== FALSE)
        {
            foreach ($db_result as $itemActivity)
                $itemActivity_array[] = $this->load($itemActivity);
        }		
		return $itemActivity_array;
	}
	
	/**
	 * Gets all Activities for given Pursuit.
	 * 
	 * @param int $pursuitID
	 * @return array Array of Activities where Activity ID is key or null if not found.
	 */
	public function findAllActivitiesByPursuitID($pursuitID)
	{
        $activities_array = array();
		$activities_db_result = $this->conn->query('SELECT [StrapItemActivity].* FROM [StrapItemActivity]
													JOIN [StrapItemActivity_Pursuit] ON [StrapItemActivity_Pursuit].[Activity_ID] = [StrapItemActivity].[Activity_ID]
														WHERE [StrapItemActivity_Pursuit].[Pursuit_ID] = %i', $pursuitID)->fetchAll();
		if ($activities_db_result !== FALSE)
		{
				foreach ($activities_db_result as $activity)
				{
					$activities_array[$activity->Activity_ID] = $this->load($activity);
				}
				return $activities_array;
		}
		else
			return null;
	}
	
	/**
	 * Gets highest Custom_ID for givin strap item id.
	 * 
	 * @param int $strapItem_ID StrapItem ID
	 * @return int Highest custom id or 0 if not found;
	 */
	public function getNextCustomIDNumber($strapItem_ID)
	{
		$db_result = $this->conn->query('SELECT MAX([Custom_ID]) FROM [StrapItemActivity] WHERE [StrapItem_ID] = %i' , $strapItem_ID)->fetch();
		if ($db_result === FALSE)
			return '0';
		else		
			return $db_result['MAX(`Custom_ID`)'];
	}
	
	/**
	 * Gets all strap item activities where is project allocated.
	 * 
	 * @param int $project_ID
	 * @return array Array of ItemActivity where Activity_ID is key or null if not found.
	 */
	public function findProjectActivities($project_ID)
	{
        $items_array = array();
		$items_db_result = $this->conn->query('SELECT * FROM [StrapItemActivity] WHERE [Project_ID] = %i AND [Active] = 1', $project_ID)->fetchAll();
		if ($items_db_result !== FALSE)
		{
				foreach ($items_db_result as $item)
				{
					$items_array[$item->Activity_ID] = $this->load($item);
				}
				return $items_array;
		}
		else
			return null;
	}
}
