<?php

/**
 * This file is part of the ATE Tool - STRAP addon
 *
 * Copyright (c) 2009, 2013 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Repository of pursuit action.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class PursuitActionRepository extends Object
{
	/** @var IPursuitActionMapper */
    private $mapper;

	/** @var MultiLogger */
	private $multilog;
	
    public function __construct(IPursuitActionMapper $mapper)
    {
        $this->mapper = $mapper;
		$this->multilog = new MultiLogger();
		$batch_id = 'PursuitAction-'.time().'-'.rand(1, 9);
		$this->multilog->add(Environment::getContext()->createLogger($batch_id, "Pursuit Action"));
    }
    
	/**
	 * Saves new PursuitAction.
	 * 
	 * @param PursuitAction $pursuitAction
	 * @return boolean
	 */
	public function save(PursuitAction $pursuitAction)
	{
		if($this->mapper->save($pursuitAction))
		{
			$this->multilog->log('PursuitAction with action: ' . $pursuitAction->Action . ' for pursuit: ' . $pursuitAction->PursuitID . ' saved.', ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
	}
	
	/**
	 * Updates PursuitAction.
	 * 
	 * @param PursuitAction $pursuitAction
	 * @return boolean
	 */
	public function update(PursuitAction $pursuitAction)
	{
		$oldObject = $this->find($pursuitAction->ID, $pursuitAction->PursuitID);
		if($this->mapper->update($pursuitAction))
		{
			$this->multilog->log('PursuitAction with action: ' . $pursuitAction->Action . ' for pursuit: ' . $pursuitAction->PursuitID . ' updated. ' . $this->multilog->differences($oldObject, $pursuitAction), ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
	}
	
	/**
	 * Deletes existing PursuitAction.
	 * 
	 * @param int $id PursuitAction ID 
	 * @return boolean
	 */
	public function delete($id)
	{
		if($this->mapper->delete($id))
		{
			$this->multilog->log('PursuitAction with ID: ' . $id . ' deleted. ', ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
	}

	/**
	 * Gets PursuitAction.
	 * 
	 * @param int $id PursuitAction id
	 * @return PursuitAction or null if not found
	 */
	public function find($id)
	{
		return $this->mapper->find($id);
	}
	
	/**
	 * Gets PursuitAction by purusit ID.
	 * 
	 * @param int $pursuitID Pursuit ID
	 * @return array Of PursuitAction or empty array if not found
	 */
	public function findByPursuitID($pursuitID)
	{
		return $this->mapper->findByPursuitID($pursuitID);
	}
	
	/**
	 * Gets nearest PursuitAction by purusit ID.
	 * 
	 * @param int $pursuitID Pursuit ID
	 * @return PursuitPlan or null if not found
	 */
	public function findNearestByPursuitID($pursuitID)
	{
		return $this->mapper->findNearestByPursuitID($pursuitID);
	}
	
	/**
	 * Finds out if exists missed milestone.
	 * 
	 * @param int $pursuitID Pursuit ID
	 * @return True or false
	 */
	public function existsMissedAction($pursuitID)
	{
		return $this->mapper->existsMissedAction($pursuitID);
	}
	
	/**
	 * Gets missed PursuitAction by purusit ID.
	 * 
	 * @param int $pursuitID Pursuit ID
	 * @return array Of PursuitAction or empty array if not found
	 */
	public function findMissedByPursuitID($pursuitID)
	{
		return $this->mapper->findMissedByPursuitID($pursuitID);
	}
}