<?php

/**
 * This file is part of the ATE Tool - STRAP addon
 *
 * Copyright (c) 2009, 2013 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Repository of STRAP TechnologyRoadmapDomain.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class TechnologyRoadmapDomainRepository extends Object
{
	/** @var ITechnologyRoadmapDomainMapper */
    private $mapper;
	
	/** @var MultiLogger */
	private $multilog;

    public function __construct(ITechnologyRoadmapDomainMapper $mapper)
    {
        $this->mapper = $mapper;
		$this->multilog = new MultiLogger();
		$batch_id = 'TechnologyRoadmap-'.time().'-'.rand(1, 9);
		$this->multilog->add(Environment::getContext()->createLogger($batch_id, "STRAP TechnologyRoadmap"));
    }
    
	/**
	 * Saves new STRAP TechnologyRoadmapDomain.
	 * 
	 * @param TechnologyRoadmapDomain $technologyRoadmapDomain
	 * @return boolean
	 */
	public function save(TechnologyRoadmapDomain $technologyRoadmapDomain)
	{
		if($this->mapper->save($technologyRoadmapDomain))
		{
			$this->multilog->log('Strap TechnologyRoadmap with Name: ' . $technologyRoadmapDomain->Domain . ' saved.', ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
	}
	
	/**
	 * Updates existing STRAP TechnologyRoadmapDomain.
	 * 
	 * @param TechnologyRoadmapDomain $technologyRoadmapDomain
	 * @return boolean
	 */
	public function update(TechnologyRoadmapDomain $technologyRoadmapDomain)
	{
		$oldObject = $this->find($technologyRoadmapDomain->Domain);
		if($this->mapper->update($technologyRoadmapDomain))
		{
			$this->multilog->log('Strap TechnologyRoadmap with Name: ' . $technologyRoadmapDomain->Domain . ' updated. ' . $this->multilog->differences($oldObject, $technologyRoadmapDomain), ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
	}
	
	/**
	 * Deletes existing STRAP TechnologyRoadmapDomain.
	 * 
	 * @param int $domain
	 * @return boolean
	 */
	public function delete($domain)
	{
		if($this->mapper->delete($domain))
		{
			$this->multilog->log('Strap TechnologyRoadmap with ID: ' . $domain . ' deleted.', ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
	}

	/**
	 * Gets STRAP TechnologyRoadmapDomain by id.
	 * 
	 * @param int $domain
	 * @return TechnologyRoadmapDomain or null if not found
	 */
	public function find($domain)
	{
		return $this->mapper->find($domain);
	}

	/**
	 * Gets all STRAP TechnologyRoadmapDomain.
	 * 
	 * @return array Array of TechnologyRoadmapDomain or null if not found.
	 */
	public function findAll()
	{
		return $this->mapper->findAll();
	}
}