<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Interface for accessing application global settings.
 * Global setting is a service with "associative-array"-like access.
 * 
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 */
interface IGlobalSetting
{
	/** possible data types for setting values */
	const OPTVAL_STRING = 'string';
	const OPTVAL_FLOAT = 'float';
	const OPTVAL_UNSIGNED_FLOAT = 'ufloat';
	const OPTVAL_INTEGER = 'int';
	const OPTVAL_UNSIGNED_INT = 'uint';
	const OPTVAL_BOOLEAN = 'boolean';
	
	/**
	 * Gets setting value by key if the is known.
	 * 
	 * @param string $key Key/index/name of the setting value.
	 * @return mixed Retuns value or NULL it it doesn't exist.
	 * @throws RangeException on unknown key.
	 */
	public function get($key);
	
	/**
	 * Sets setting user value by key.
	 * 
	 * If it does not exist yet, it is created as a default value of given type.
	 * 
	 * @param string $key Key/index/name of the setting value.
	 * @param mixed $value User value of the setting.
	 * @param string $autocreate Whether it should be created if it does not exist
	 * @param string $autocreate Data type that should 
	 * @throws RangeException on unknown key if $autocreate is FALSE.
	 * @throws InvalidArgumentException on invalid datatype of $value.
	 * @todo Should there be add method instead of set-autocreate functionality?
	 */
	public function set($key, $value, $autocreate = FALSE, $type = self::OPTION_STRING);
	
	/*public function getByPrefix($key_prefix);*/
	
	/**
	 * Resets value to default value. And NULLifies user-value.
	 * @param string $key Key/index/name of the setting value.
	 * @throws RangeException on unknown key.
	 */
	public function reset($key);
	
	/**
	 * Gets default value for key.
	 * @param string $key Key/index/name of the setting value.
	 * @return mixed 
	 * @throws RangeException on unknown key.
	 */
	public function getDefault($key);

	/**
	 * Tests whether value for key is defined (test whether any value is
	 * defined i.e. whether user-defined or default value is set)
	 * 
	 * @param string $key Key/index/name of the setting value.
	 * @return boolean
	 */
	public function exists($key);

	/**
	 * Removes key-value pair from settings (not only value NULLifiing).
	 * @param string $key Key/index/name of the setting value.
	 * @throws RangeException on unknown key.
	 */
	public function remove($key);
	
}


