<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011, 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Mapper for accessing user roles from database using dibi.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class UserRoleDibiMapper extends DibiMapper implements IUserRoleMapper
{	
    /**
	 * Creates UserRole instance from DibiRow.
	 * 
	 * @param DibiRow $row
	 * @return	UserRole
	 */
    private function loadUserRole(DibiRow $row)
    {
		$userRole = new UserRole();
		$userRole->ID = $row->EID;
		$userRole->role = $row->Role;
		return $userRole;
    }
    
    /**
	 * Finds roles by person id.
	 * 
	 * @param string $id person ID.
	 * @return	array of UserRole Return array if find succesfull, otherwise returns null.
	 */    
    public function findUserRoles($id)
    {
		$userRoles_db_result = $this->conn->select('*')->from('User')->where('[EID] = %s', $id)->fetchAll();
		$roles = array();
        foreach ($userRoles_db_result as $row)
        {
            $role = $this->loadUserRole($row);
            $roles[] = $role;
        }       
        return $roles;
    }
    
     /**
     * Saves UserRole.
     * 
     * @param UserRole $userRole
     * @return boolean Returns true if create successfull, otherwiste returns false.
     */
    public function save(UserRole $userRole)
    {
        try
        {          
            $array = array();
            $array['EID'] = $userRole->ID;
            $array['Role'] = $userRole->role;
            $user_db_result = $this->conn->insert('User', $array)->execute(); 
            return true;       
        }
        catch (DibiException $e)
        {
            Debugger::log("User role insert with id = " . $userRole->ID . " failed. ".$e->getMessage());
            return false;
        }    
    }
    
    /**
     * Deletes UserRole.
     * 
     * @param string $role
     * @param string $person_id
     * @return boolean Return true if delete successfull, otherwise returns false.
     */
    public function delete($person_id, $role)
    {
        try
        {
            $this->conn->delete('User')->where('[EID] = %s AND [Role] = %s', $person_id, $role)->execute();
            Debugger::log(print_r(dibi::$sql, true), Debugger::DEBUG);
            return true;
        }
        catch (DibiException $e)
        {
            Debugger::log("User role delete with id =" . $person_id . " failed. ".$e->getMessage(), Debugger::ERROR);
            return false;
        }
    } 
}
