<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011, 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * WorkableHour is count of workable hours for every mounths of company employee.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class WorkableHour extends Object
{
   
	
    /** @var string Employee identification code */
    private $id;

    /** @var int Year of workalbe hours */
    private $year;

    /** @var float Yield of working time */
    private $yield;
	
    /** @var float Contract of working time */
    private $contract;
	
	/** @var boolean Indicates from where are wh taken */
    private $isAOP;

    /** @var array Array with hours for months in year. */
    private $hours;
	
	/** @var string project remark */
    private $remark;
  
    public function  __construct() 
    {
    }
	
     /**
     * Sets person EID.
     * 
     * @param string $ID
     */
	public function setID($id)
	{
		$this->id = $id;
	}
    /**
     * Gets person EID.
     * 
     * @return string
     */
	public function getID()
	{
		return $this->id;
	}	

    /**
     * Sets year of workalbe hours.
     * 
     * @param int $year
     */
    public function setYear($year)
    {
		if (NumericUtils::isPositiveInteger($year))
			$this->year = 0 + $year;
		else
			throw new InvalidArgumentException("Year must be positive integer. Value: " . $year);
    }

    /**
     * Gets year of workalbe hours.
     * 
     * @return int
     */
	public function getYear()
	{
		return $this->year;
	}	
	
    /**
     * Sets yield of working time.
     * 
     * @param float $yield
     */
	public function setYield($yield)
	{
		$this->yield = $yield;
	}

    /**
     * Gets yield of working time.
     * 
     * @return float
     */
	public function getYield()
	{
		return $this->yield;
	}	
	
    /**
     * Sets contract of working time.
     * 
     * @param float $contract
     */
	public function setContract($contract)
	{
		$this->contract = $contract;
	}

    /**
     * Gets contract of working time.
     * 
     * @return float
     */
	public function getContract()
	{
		return $this->contract;
	}
    
	/**
	 * Sets isAOP flag.
     * @param boolean $isAOP
     */
    public function setIsAOP($isAOP)
    {
        $this->isAOP = ($isAOP) ? TRUE : FALSE;
    }

    /**
	 * Gets isAOP flag.
     * @return boolean
     */
    public function getIsAOP()
    {
        return $this->isAOP;
    }	
	
    /**
     * Sets hours for month in workable hour.
     * 
     * @param int $hours Hours for the month in workable hour.
     * @param int $month Month number <1, 12>
     */
    public function setMonthHours($hour, $month)
    {
		if($hour <> null)
			if (!NumericUtils::isNonNegativeInteger($hour))
				throw new InvalidArgumentException("Hours must be non-negative integer. Value: " . $hour);
		if (NumericUtils::isPositiveInteger($month)
			&& ($month >= 1) & ($month <= 12))
			$this->hours[0 + $month] = $hour;
		else
			throw new InvalidArgumentException("Month must be integer in range <1, 12> inclusively. Value: " . $month);
    }
    
    /**
     * Returns hours for month in workable hour.
     * 
     * @return int
     */
    public function getMonthHours($month)
    {
		if (NumericUtils::isPositiveInteger($month)
			&& ($month >= 1) & ($month <= 12))
			return $this->hours[0 + $month];
		else
			throw new InvalidArgumentException("Month must be integer in range <1, 12> inclusively. Value: " . $month);
    }    
	
/**
     * Sets remarks
     * 
     * @param string $remark
     */
	public function setRemark($remark)
	{
		$this->remark = $remark;
	}

    /**
     * Gets remarks
     * 
     * @return string
     */
	public function getRemark()
	{
		return $this->remark;
	}	
}
