<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011, 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package models
 */

/**
 * Workable hour repository access class.
 *
 * @author Jiri Pirochta <jiri.pirochta@honeywell.com>
 */
class WorkableHourRepository extends Object
{
    /** @var IWorkableHourMapper */
 	private $mapper;

	/** @var MultiLogger */
	private $multilog;
	
    public function __construct(IWorkableHourMapper $mapper)
    {
        $this->mapper = $mapper;
		$this->multilog = new MultiLogger();
		$batch_id = 'WorkableHour-'.time().'-'.rand(1, 9);
		$this->multilog->add(Environment::getContext()->createLogger($batch_id, "Workable Hours"));
    }	

    /**
     * Updates WorkableHour.
     * 
     * @param WorkableHour $workableHour
     * @return boolean Returns true if update successfull, otherwiste returns false.
     */
    public function update(WorkableHour $workableHour)
    {
		$oldObject = $this->find($workableHour->Year, $workableHour->ID);
		if($this->mapper->update($workableHour))
		{
			$this->multilog->log('Workable hours of person with EID: ' . $workableHour->ID . ' and for year: ' . $workableHour->Year . ' updated. ' . $this->multilog->differences($oldObject, $workableHour), ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
    }
    
     /**
     * Creates WorkableHour.
     * 
     * @param WorkableHour $workableHour
     * @return boolean Returns true if create successfull, otherwiste returns false.
     */
    public function create(WorkableHour $workableHour)
    {
		if($this->mapper->create($workableHour))
		{
			$this->multilog->log('Workable hours of person with EID: ' . $workableHour->ID . ' and for year: ' . $workableHour->Year . ' saved.', ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
    }
    
    /**
     * Deletes WorkableHour.
     * 
     * @param int $year
     * @param string $person_id
     * @return boolean Return true if delete successfull, otherwise returns false.
     */
    public function delete($year, $person_id)
    {
		if($this->mapper->delete($year, $person_id))
		{
			$this->multilog->log('Workable hours of person with EID: ' . $person_id . ' and for year: ' . $year . ' deleted.', ILogger::INFO);
			return true;
		}
		else
		{
			return false;
		}
    }
	
    /**
     * Get yield of workanle hours for user and for selected year.
     *
     * @param string $id
     * @param int $year
     * @return float
     */
    public function getYield ($id, $year)
    {
        return $this->mapper->getYield($id, $year);
    }
	
    /**
     * Get contract of workanle hours for user and for selected year.
     *
     * @param string $id
     * @param int $year
     * @return float
     */
    public function getContract ($id, $year)
    {
        return $this->mapper->getContract($id, $year);
    }
	
    /**
     * Get remark of workanle hours for user and for selected year.
     *
     * @param string $id
     * @param int $year
     * @return string
     */
    public function getRemark ($id, $year)
    {
        return $this->mapper->getRemark($id, $year);
    }
    
    /**
     * Search if workable hours of person for selected year exists.
     * 
     * @param int $year
     * @param string $person_id
     * @return Return true if search successfull, otherwise returns false. 
     */
    public function search($year, $person_id)
    {
        return $this->mapper->search($year, $person_id);
    }
    
    /**
	 * Returns AOP for selected year for selected user.
	 * 
	 * Returns whole budget of hours which doesn't mean it have to be vacant
	 * (depends on assignments of hours to worker).
	 * 
	 * @param int $year year
	 * @param string $person_id ID of employee.
	 * @return	AnnualOperationPlan of NULL if not found.
	 */
    public function findHours($year, $person_id)
    {
        return $this->mapper->findHours($year, $person_id);
    }
    
    /**
     * Search if workable hours of person for selected year is AOP.
     * 
     * @param int $year
     * @param string $person_id
     * @return Return true if search successfull, otherwise returns false. 
     */
    public function isAop($year, $preson_id)
    {
        return $this->mapper->isAop($year, $preson_id);
    }
	
    /**
     * Gets WH for person and given year.
     * 
     * @param int $year
     * @param string $person_id
     * @return Return WorkableHour or NULL if not found
     */
    public function find($year, $person_id)
    {     
		return $this->mapper->find($year, $person_id);
    }
}

