<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters
 */

/**
 * Error presenter for displaying system error and failure states.
 *
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 */
class ErrorPresenter extends Presenter
{

	/**
	 * @param  Exception
	 * @return void
	 */
	public function renderDefault($exception)
	{
		if ($this->isAjax()) { // AJAX request? Just note this error in payload.
			$this->payload->error = TRUE;
			$this->terminate();
		} elseif ($exception instanceof AuthenticationException) {
			$this->setView('401');
			// log to access.log
			Debugger::log("Auth fail: {$exception->getMessage()} in {$exception->getFile()}:{$exception->getLine()}", 'access');
		} elseif ($exception instanceof BadRequestException) {
			$code = $exception->getCode();
			// load template 403.latte or 404.latte or ... 4xx.latte
			$this->setView(in_array($code, array(401, 403, 404, 405, 410, 500)) ? $code : '4xx');
			// log to access.log
			Debugger::log("HTTP code $code: {$exception->getMessage()} in {$exception->getFile()}:{$exception->getLine()}", 'access');
		} else {
			$this->setView('500'); // load template 500.latte
			Debugger::log($exception, Debugger::ERROR); // and log exception
		}
	}

}