<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters
 */

/**
 * Predessor for presenters run by daemons and outer processes 
 * that authenticate by token (no user/password credentials).
 * 
 * Child classes are expected to implement methods getAuthTokenName() which
 * and getSettingsKey().
 *
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 */
abstract class TokenAccessPresenter extends BasePresenter
{
	
    /**
     * Returns http parameter name with authentication token.
     * 
     * @return string
     */
	protected abstract function getAuthTokenName();

    /**
     * Returns http parameter name with authentication token.
	 * 
     * @return string
     */
	protected abstract function getAuthTokenSettingsKey();
	
    /**
     * Checks if right token (http parameter) was sent for authentication.
     * 
     * @return string
     */
	protected function startup()
    {
        parent::startup();

		$auth_token_name = trim($this->getAuthTokenName());
		if (!is_string($auth_token_name) || ($auth_token_name == ''))
			throw InvalidStateException('Authentication token name is invalid. Cannot authenticate.');

		if (!$this->context->globalSetting->exists($this->getAuthTokenSettingsKey()))
			throw new InvalidStateException('Settings key "'.$this->getAuthTokenSettingsKey().'" is invalid. Cannot load token value.');
		else
			$auth_token_value = $this->context->globalSetting->get($this->getAuthTokenSettingsKey());
		if (!is_string($auth_token_value) || ($auth_token_value == ''))
			throw new BadRequestException('Authentication impossible. Authentication token value in settings is not set.', 500);
		
		$sent_auth_token = $this->getParameter($auth_token_name);
		if (($sent_auth_token === NULL) || ($auth_token_value != $sent_auth_token))
		{
			Debugger::log('Authentication via "'.$auth_token_name.'" token failed.', Debugger::INFO);
			throw new BadRequestException('Authentication via token failed.', 403);
		}
		
		Debugger::log('Authentication via "'.$auth_token_name.'" token (http parameter).', Debugger::DEBUG);
    }
	
}
