<?php
/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package utils
 */

/**
 * Locker is an interface for classes implementing locking mechanism
 * controlling concurrent access to resources.
 * 
 * Concrete implementation is to decide way of locking (actual)
 * key data.
 * 
 * Example of common usage:
 * <example>
 * $locker = new ConcreteLock('LONG_RUNNING_PROCESS');
 * if ($lock->lock()) {
 *      // here you put code you want to run on the server in one instance only
 *      $lock->unlock();
 * }
 * else
 * {
 *      throw new LockException('Process is locked. Cannot run right now');
 * }
 * </example> 
 * 
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 */
interface Lock {
    
	/**
	 * Returns true if it was possible to lock (gain the key to resources).
	 * 
	 * @return boolean
	 */
    public function lock();

	/**
	 * Returns true if it was possible to unlock (return the key to resources).
	 * 
	 * @return boolean
	 */
    public function unlock();

	/**
	 * Returns true if locker is locked.
	 * 
	 * @return boolean
	 */
    public function locked();
    
}



