<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2011 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package utils\Forms
 */

/**
 * Represents state of data of a form.
 * 
 * Three scenarios:
 * 1) remember & serialize (for saving form state into some repository)
 * 2) deserialize & populate (for reviving form from repository)
 * 3) remember & populate (for temporarily saving state of form)
 *
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 */
class FormState
{

	/** @var array */
	private $form_state = NULL;
	
	public function __contruct()
	{
	}

	/**
	 * Remembers data of given form (updates state).
	 * 
	 * @param Form $form Application form to populate with data.
	 * @return	boolean Returns TRUE on success and FALSE if state is not available.
	 */
	public function remember(Form $form)
	{
		$this->form_state = $form->getValues();
	}
	
	/**
	 * Populates data of given form (updates given object).
	 * 
	 * @param AppForm $form Application form to populate with data.
	 * @return	boolean Returns TRUE on success and FALSE if state is not available.
	 */
	public function populate(Form $form)
	{
		if ($this->form_state !== NULL)
			$form->setValues($this->form_state);
		else
			throw new ApplicationException('FormState is not initialized. Cannot populate form. Wrong object usage.');
	}

	/**
	 * Serializes current state into string.
	 * 
	 * @param AppForm $form Application form to populate with data.
	 * @return	string Returns state as string.
	 */
	public function serialize()
	{
		if ($this->form_state !== NULL)
			return serialize($this->form_state);
		else
			throw new ApplicationException('FormState is not initialized. Cannot serialize form state. Wrong object usage.');
	}
	
	/**
	 * Deserializes state from string.
	 * 
	 * @param string $source Source string.
	 * @return	boolean Returns TRUE on success and FALSE if deserialization failed.
	 */
	public function deserialize($source)
	{
		$this->form_state = unserialize($source);
	}
	
}
