<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package utils\Logging
 */

/**
 * DatabaseLogger is providing logging functionality into database.
 * 
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 */
class DatabaseLogger extends BatchLogger
{

	/** DibiConnection */
	private $connection = NULL;
	/** ID of responsible person/automat for logging action */
	private $responsible = NULL;
	/** table name */
	private $tableName = 'LogData';
	
	/**
	 * Creates new logfile object.
	 * 
	 * @param string $batch_id Path to file for logging.
	 */    
	public function __construct($batch_id = NULL)
    {
		$this->connection = dibi::getConnection();
		$this->responsible = '' . Environment::getUser()->getId();
		if (!$this->connection)
			throw new InvalidStateException ('Database connection is not available.');
		parent::__construct($batch_id);
	}

	/**
	 * Logs message into database.
	 * 
	 * @param string $message Message text.
	 * @param mixed $level message level. Default INFO.
	 * @param string $domain domain of logged message (can be used for grouping or filtering later).
	 * @param mixed $context variable logging context (useful for special log parameters).
	 * @return boolean Returns TRUE if message was written.
	 */
    public function performLog($message, $level = self::INFO, $domain = NULL, $context = NULL)
	{
		if ($this->connection !== NULL)
		{
			try
			{
				$array = array();
				$array['Responsible'] = $this->responsible;
				$array['Created'] = date('Y-m-d H:i:s');
				$array['Type'] = $level;
				$array['Batch'] = $this->getBatchID();
				$array['Group'] = $domain;
				//$array['ObjectType'] = NULL;
				//$array['ObjectID'] = NULL;
				$array['Message'] = $message;
				$log_result = $this->connection->insert($this->tableName, $array)->execute();
				return true;
			}
			catch (DibiException $e)
			{
				Debugger::log("Log of message failed. ".$e->getMessage(). " Logged data: ". var_export($array, TRUE), Debugger::ERROR);
				return false;
			}
			return ($log_result !== false);
		}
		else
			return false;
	}
	
	public function setTableName($table_name)
	{
		$this->tableName = $table_name;
	}
	
}

