<?php

/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2012 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package utils\Logging
 */

/**
 * Stores logs into memory.
 * 
 * @author Martin Kotlar <martin.kotlar@honeywell.com>
 */
class MemoryLogger implements ILogger
{

	private $prefix = NULL;
	private $suffix = NULL;
	private $messages = NULL;
	
	/**
	 * Creates new logfile object.
	 * 
	 * @param string $filepath Path to file for logging.
	 */    
	public function __construct($filepath = NULL)
    {
		$this->messages = array();
	}

	/**
	 * Sets prefix that will be prepended to every message text.
	 * 
	 * @param string $prefix Msg prefix.
	 */
    public function setPrefix($prefix)
	{
		$this->prefix = $prefix;
	}

	/**
	 * Sets suffix that will be added to every message text.
	 * 
	 * @param string $prefix Msg suffix.
	 */
    public function setSuffix($suffix)
	{
		$this->suffix = $suffix;
	}
	
	/**
	 * Logs message into log file (if opened).
	 * For $level only these values are processed:
	 * ILogger::[INFO|NOTICE|WARNING|ERROR|FATAL]
	 * 
	 * @param string $message Message text.
	 * @param mixed $level message level. Default INFO.
	 * @param string $domain domain of logged message (can be used for grouping or filtering later).
	 * @param mixed $context variable logging context (useful for special log parameters).
	 * @return boolean Returns TRUE if message was written.
	 */
    public function log($message, $level = self::INFO, $domain = NULL, $context = NULL)
	{
		$this->messages[] = array('msg' => $this->prefix . $message . $this->suffix, 'level' => $level, 'domain' => $domain, 'context' => $context);
	}
	
	/**
	 * Returns array of asociative arrays of message logs where
	 * every messge log has structure:
	 * array('msg' => "message text",
	 *		'level' => "message level",
	 *		'context' => message_context_data
	 * );
	 * @return array
	 */
    public function getMessages()
	{
		return $this->messages;
	}
		
	public function __destruct()
	{
		$this->messages = NULL;
	}
	
}

