
/**
 * Moves row number of TGRow to remove to hidden field, for later identification of this row.
 * @param row It should be positive integer. Identification of TGrow.
 */
function deleteTGRow(row)
{
   $('input[name=TGRowToRemove]').attr('value', row); 
}

/**
 * Moves row number of SUBRow to remove to hidden field, for later identification of this row.
 * @param row It should be positive integer. Identification of SUBrow.
 */
function deleteSUBRow(row)
{
   $('input[name=SUBRowToRemove]').attr('value', row); 
}

/**
 * Returns rate for technical group.
 * @param group Should be positive integer. ID of Technical group.
 * @return float Rate value or undefined in case that no rate for selected year was found.
 */
function getRate(group)
{
	var rate = 0;
    var year = $('.Year').val();    

    // Is defined global variable containing all labor rates?
    if (typeof labor_rates !== 'undefined')
    {
        var average = jQuery.parseJSON(labor_rates.average);
        var frozen = jQuery.parseJSON(labor_rates.frozen);

        if (frozen && (typeof frozen[group] !== 'undefined') && (typeof frozen[group][year] !== 'undefined'))
        	rate = frozen[group][year];
        else if (average && (typeof average[group] !== 'undefined') && (typeof average[group][year] !== 'undefined'))
        	rate = average[group][year];
    }

    return rate;
}

/**
 * Counts sum of values on a row. Writes the result into the target cell at the row.
 * @param source Object representing row.
 */
function countTotal(source)
{
    //
    var ownerTotal = 0;
    $(source).closest('tr').find('input[name*="owner"]').each(function(){
        var q = $(this).val();
        if (q == '') { $(this).val('0'); }
        if (!isNaN(q)) { ownerTotal += Number(q); $(this).closest('td').removeClass('badInput'); } else { $(this).closest('td').addClass('badInput'); }
    });
    $(source).closest('tr').find('td.totalOwnerTG, td.totalOwnerSUB, td.totalOwnerOther').text(Math.round(ownerTotal));
    
    //
    var managerTotal = 0;    
    $(source).closest('tr').find('input[name*="manager"]').each(function(){
        var q = $(this).val();
        if (q == '') { $(this).val('0'); }
        if (!isNaN(q)) { managerTotal += Number(q); $(this).closest('td').removeClass('badInput'); } else { $(this).closest('td').addClass('badInput'); }
    });
    $(source).closest('tr').find('td.totalManagerTG, td.totalManagerSUB, td.totalManagerOther').text(Math.round(managerTotal));
}

/**
 * Counts sum of totals. Writes the result into the target cell of table.
 * Totals expressed in HRS multiplies by rate according to technical group.
 */
function countSumOfTotals()
{
    var ownerSumOfTotals = 0;
    var managerSumOfTotals = 0;
    // Totals for technical groups
    $('.autoUpdateTotalTG').each(function(){
        var group = $(this).closest('tr').find('.TechnicalGroup').val();
        if (group)
        {
            var ownerTotal = Number($(this).closest('tr').find('td.totalOwnerTG').text());
            var managerTotal = Number($(this).closest('tr').find('td.totalManagerTG').text());
            var rate = Number(getRate(group));
            if (rate)
            {
                ownerSumOfTotals += ownerTotal * rate;
                managerSumOfTotals += managerTotal * rate;
            }

//            $(this).closest('tr').removeClass('emptyInput');
        }
        else
        {
//            $(this).closest('tr').addClass('emptyInput');
        }
    });
    // Totals for subcontractors
    $('.autoUpdateTotalSUB').each(function(){
        var subcontractor = $(this).closest('tr').find('.Subcontractor').val();
        if (subcontractor)
        {
            var ownerTotal = $(this).closest('tr').find('td.totalOwnerSUB').text();
            var managerTotal = $(this).closest('tr').find('td.totalManagerSUB').text();
            ownerSumOfTotals += Number(ownerTotal);
            managerSumOfTotals += Number(managerTotal);
            
//            $(this).closest('tr').removeClass('emptyInput');
        }
        else
        {
//            $(this).closest('tr').addClass('emptyInput');
        }   
    });
    // Totals for others
    $('.autoUpdateTotalOther').each(function(){
        var ownerTotal = $(this).closest('tr').find('td.totalOwnerOther').text();
        var managerTotal = $(this).closest('tr').find('td.totalManagerOther').text();
        ownerSumOfTotals += Number(ownerTotal);
        managerSumOfTotals += Number(managerTotal);
    });
    // Show total
    $('td.ownerSumOfTotals').text(Math.round(ownerSumOfTotals));
    $('td.managerSumOfTotals').text(Math.round(managerSumOfTotals));
}

/**
 * Highlights differences between values in owner field and in manager field.
 */
function highlightDifference()
{
	var owner, manager;
	
	// Comparison can't be done, because fields for proposal of manager are not on the page
	if (!$('td.managerSumOfTotals').text())
		return;
	
	var allSame = true;
	
	$('.autoUpdateTotalTG, .autoUpdateTotalSUB, .autoUpdateTotalOther').each(function(){
        // For each input where its value representing amount for year quarter
		for (var i = 1; i <= 4; i++)
		{
			var ownerInput = 'input[name*="ownerQ'+ i +'"]';
			var managerInput = 'input[name*="managerQ'+ i +'"]';
			owner = $(this).find(ownerInput).val();
			manager = $(this).find(managerInput).val();
			
//			if (owner != manager)
//			{				
//				allSame = false;
//				$(this).find(ownerInput).addClass('differentValue');
//				$(this).find(managerInput).addClass('differentValue');
//			}
//			else
//			{
//				$(this).find(ownerInput).removeClass('differentValue');
//				$(this).find(managerInput).removeClass('differentValue');
//			}
		}
		
		// All fields of budget has the same value and approve is not locked
		if (allSame && !$('input[name="ApproveLocked"]').attr('value'))
		{
		    $('input[name="approve"]').removeAttr('disabled');
			$('.approveDisabled').hide();
		}
		// There are differences and approve is not locked
		// ApproveBypassLock is used when charter owner is also its LM,
		// then the values don't have to be the same
		else if (!allSame && !$('input[name="ApproveLocked"]').attr('value') && !$('input[name="ApproveBypassLock"]').attr('value'))
		{
			$('input[name="approve"]').attr('disabled', 'disabled');
			$('.approveDisabled').show();
		}
		
		// Partial total
		owner = $(this).find('td[class*="totalOwner"]').text();
		manager = $(this).find('td[class*="totalManager"]').text();
		
//		if (owner != manager)
//		{
//			$(this).find('td[class*="totalOwner"]').addClass('differentValue');
//			$(this).find('td[class*="totalManager"]').addClass('differentValue');
//		}
//		else
//		{
//			$(this).find('td[class*="totalOwner"]').removeClass('differentValue');
//			$(this).find('td[class*="totalManager"]').removeClass('differentValue');
//		}		
	});
	// Sum of totals
	owner = $('td.ownerSumOfTotals').text();
	manager = $('td.managerSumOfTotals').text();
	
//	if (owner != manager)
//	{
//		$('td.ownerSumOfTotals').addClass('differentValue');
//		$('td.managerSumOfTotals').addClass('differentValue');
//	}
//	else
//	{
//		$('td.ownerSumOfTotals').removeClass('differentValue');
//		$('td.managerSumOfTotals').removeClass('differentValue');
//	}
}

$(document).ready(function(){
    // Recount on reload
    $('.autoUpdateTotalTG, .autoUpdateTotalSUB, .autoUpdateTotalOther').each(function(){
        countTotal(this);
        countSumOfTotals();
    });
	// Highlight differences
	//highlightDifference();
    // Recount on change of value
    $('.autoUpdateTotalTG input, .autoUpdateTotalSUB input, .autoUpdateTotalOther input').change(function(){
        countTotal(this);
        countSumOfTotals();
		//highlightDifference();
    });
    // Recount on change of technical group or year (different rate for Year / Technical group)
    $('.Year, .TechnicalGroup, .Subcontractor').change(function(){
        countSumOfTotals();
    });
	//Copy values from CL to PIPM
	$('#copyButtonCL').click(function(){
		$('.copyFrom').each(function(){
			$(this).find('input[name*="manager"]').each(function(){
				$(this).closest('td').prev('td').find('input[name*="owner"]').attr('value', $(this).val());
			});
		});
		// Recount needed
		$('.autoUpdateTotalTG, .autoUpdateTotalSUB, .autoUpdateTotalOther').each(function(){
			countTotal(this);
			countSumOfTotals();
		});
		// Highlight differences
		//highlightDifference();
	});
	//Copy values from CL to PIPM
	$('#copyButtonPIPM').click(function(){
		$('.copyFrom').each(function(){
			$(this).find('input[name*="owner"]').each(function(){
				$(this).closest('td').next('td').find('input[name*="manager"]').attr('value', $(this).val());
			});
		});
		// Recount needed
		$('.autoUpdateTotalTG, .autoUpdateTotalSUB, .autoUpdateTotalOther').each(function(){
			countTotal(this);
			countSumOfTotals();
		});
		// Highlight differences
		//highlightDifference();
	});
	// Show tip
	if ($('input[name="ApproveLocked"]').attr('value'))
		$('.approveDisabled').show();
		
});