/**
 * This file is part of the ATE Tool
 *
 * Copyright (c) 2009, 2016 Honeywell International spol. s r.o.
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 * @package presenters
 */

/**
 * This module avoid sessions being overwritten in case user creates/edits Charters,
 * PO Attributes and STRAP Pursuits in more windows than one.
 * It creates an illusion of mutual exclusion of browser's tabs.
 *
 * @author Leos Navratil <leos.navratil@honeywell.com>
 */

function beacon() {
	localStorage.setItem(localStorageName, new Date());

	// beacon mutex still acquired
	$.ajax({
		url: userRefreshShortcut,
		global: false,
		success: function () {
			return true;
		}
	});
}

$(document).ready(function (){
	var dateTime = new Date();
	var timeout = 2.0;
	// in miliseconds
	var timeToLetServerKnow = 1000;
	var beaconTimer;
	var editingFlag = localStorage.getItem(localStorageName);

	// it's still possible to open two windows at once, because editingFlag variable
	// is not a real mutex with atomic properties, but so far it's sufficient
	if(editingFlag === null || ((dateTime - new Date(editingFlag)) / 1000 > timeout))
	{
		beacon();
		beaconTimer = setInterval(beacon, timeToLetServerKnow);

		$(window).on('beforeunload', function(){
			clearInterval(beaconTimer);
			localStorage.removeItem(localStorageName);

			$.ajax({
				url: userRefreshShortcut,
				global: false,
				data: { removeFlag: 1 },
				async: false,
				success: function () {
					return true;
				}
			});
		});
	}
});